@@ -2,7 +2,7 @@
  * @file   adinrec.c
  * 
  * <JA>
- * @brief  ޥȯäեصϿ
+ * @brief  マイクから一発話をファイルへ記録する
  * </JA>
  * 
  * <EN>
@@ -36,7 +36,7 @@ static boolean stout = FALSE;	///< True if output to stdout
 static boolean use_raw = FALSE;	///< Output in RAW format if TRUE
 
 /** 
- * <JA>إפɽƽλ</JA>
+ * <JA>ヘルプを表示して終了する</JA>
  * <EN>Print help and exit</EN>
  */
 static boolean
@@ -52,6 +52,10 @@ opt_help(Jconf *jconf, char *arg[], int argnum)
   fprintf(stderr, "    [-headmargin msec]    head margin length          (%d)\n", jconf->detect.head_margin_msec);
   fprintf(stderr, "    [-tailmargin msec]    tail margin length          (%d)\n", jconf->detect.tail_margin_msec);
   fprintf(stderr, "    [-chunksize sample]   chunk size for processing   (%d)\n", jconf->detect.chunk_size);
+#ifdef HAVE_LIBFVAD
+  fprintf(stderr, "    [-fvad]               FVAD sw (-1=off, 0 - 3)     (%d)\n", jconf->detect.fvad_mode);
+  fprintf(stderr, "    [-fvad_param i f]     FVAD parameter (dur/thres)  (%d %.2f)\n", jconf->detect.fvad_smoothnum, jconf->detect.fvad_thres);
+#endif /* HAVE_LIBFVAD */
   fprintf(stderr, "    [-nostrip]            not strip off zero samples\n");
   fprintf(stderr, "    [-zmean]              remove DC by zero mean\n");
   fprintf(stderr, "    [-nocutsilence]       disable VAD, record all stream\n");
@@ -81,12 +85,12 @@ opt_freq(Jconf *jconf, char *arg[], int argnum)
 
 /** 
  * <JA>
- * Ͽ줿ץ륳Хåؿ
+ * 録音されたサンプル列を処理するコールバック関数
  * 
- * @param now [in] Ͽ줿ץ
- * @param len [in] Ĺʥץ
+ * @param now [in] 録音されたサンプル列
+ * @param len [in] 長さ（サンプル数）
  * 
- * @return 顼 -1 0ֽܶüл 1 ֤
+ * @return エラー時 -1，処理成功時 0，処理成功＋区間終端検出時 1 を返す．
  * </JA>
  * <EN>
  * Callback handler of recorded sample fragments
@@ -194,13 +198,13 @@ interrupt_record(int signum)
 
 /** 
  * <JA>
- * ᥤؿ
+ * メイン関数
  * 
- * @param argc [in] Ĺ
- * @param argv [in] 
+ * @param argc [in] 引数列の長さ
+ * @param argv [in] 引数列
  * 
  * @return 
- * </JA>顼 1̾ｪλ 0 ֤
+ * </JA>エラー時 1，通常終了時 0 を返す．
  * <EN>
  * Main function.
  * 
