@@ -1,6 +1,36 @@
 /* A Bison parser, made from gram.y
    by GNU bison 1.35.  */
 
+/* added to avoid implicit declaration warning of yyerror */
+int yyerror( char *mes );
+
+/* added from lex.yy.c to avoid implicit declaration warning of yylex */
+#ifdef c_plusplus
+#ifndef __cplusplus
+#define __cplusplus
+#endif
+#endif
+#ifdef __cplusplus
+#define YY_USE_PROTOS
+#else	/* ! __cplusplus */
+#if __STDC__
+#define YY_USE_PROTOS
+#endif	/* __STDC__ */
+#endif	/* ! __cplusplus */
+#ifdef __TURBOC__
+#define YY_USE_PROTOS
+#endif
+#ifdef YY_USE_PROTOS
+#define YY_PROTO(proto) proto
+#else
+#define YY_PROTO(proto) ()
+#endif
+#ifndef YY_DECL
+#define YY_DECL int yylex YY_PROTO(( void ))
+#endif
+YY_DECL;
+
+
 #define YYBISON 1  /* Identify Bison output.  */
 
 # define	CTRL_ASSIGN	257
@@ -1415,7 +1445,7 @@ char *getNewClassName( char *keyname )
 
     sprintf( classname, "%s#%d", keyname , tmpClassNo++ );
     if( !SW_SemiQuiet ){
-	fprintf( stderr, "\rNow modifying grammar to minimize states[%d]", GramModifyNum );
+	fprintf( stderr, "\rNow modifying grammar to reduce states[%d]", GramModifyNum );
 	NoNewLine = 1;
     }
     GramModifyNum++;
@@ -1444,7 +1474,7 @@ void setGram( void )
     if( !SW_Quiet ) fputs( "Now parsing grammar file\n", stderr );
     yyparse();
     if( !SW_Quiet ){
-	fprintf( stderr, "\rNow modifying grammar to minimize states[%d]\n", GramModifyNum - 1 );
+	fprintf( stderr, "\rNow modifying grammar to reduce states[%d]\n", GramModifyNum - 1 );
 	NoNewLine = 0;
     }
     if( StartSymbol == NULL ) StartSymbol = ClassList;
@@ -1485,7 +1515,7 @@ char *chkNoInstantClass( void )
 
 int yyerror( char *mes )
 {
-    errMes(mes );
+    errMes("%s: Line %d: %s", GramFile, yylineno, mes);
     ErrParse++;
     return( 0 );
 }
