@@ -8,7 +8,7 @@
 #include <julius/juliuslib.h>
 
 #if defined(_WIN32) && !defined(__CYGWIN32__) && !defined(__MINGW32__)
-#include <config-msvc-julius.h>
+#include "config-msvc-julius.h"
 #else
 #include "config.h"
 #endif
@@ -37,6 +37,7 @@ void module_disconnect();
 void decode_output_selection(char *str);
 void send_gram_info(RecogProcess *r);
 void setup_output_msock(Recog *recog, void *data);
+void escape_xml(char *originstr, char *outbuf);
 
 /* output_stdout.c */
 void print_all_gram(Recog *recog);
@@ -50,3 +51,6 @@ void outfile_set_fname(char *input_filename);
 void record_add_option();
 void record_setup(Recog *recog, void *data);
 
+
+
+
