@@ -1,12 +1,12 @@
 /* 
- *  libjcode.c -- Ѵ饤֥    1.0 
+ *  libjcode.c -- 漢字変換ライブラリ    1.0 版
  *                (C) Kuramitsu Kimio, Tokyo Univ. 1996-97
  *
- *  Υ饤֥ϡCGI Programming with C and Perl Τ
- *  Ken Lunde  ܸ (O'llery) 򻲹ͤˤơ
- *  ȥ꡼Ѥäjconv.c 򡢥ȥбˤƥ饤֥경
- *  ޤ 
- *  CGI (INTERNET)ǤѤͤơѹƤޤ
+ *  このライブラリは、CGI Programming with C and Perl のために
+ *  Ken Lunde 著 「日本語情報処理」 (O'llery) を参考にして、
+ *  ストリーム用だったjconv.c を、ストリング対応にしてライブラリ化
+ *  しました。 
+ *  ただし、CGI (INTERNET)での利用を考えて、変更してあります。
  */
 
 /* modified by ri to avoid may malloc */
@@ -39,7 +39,7 @@ static void _seven2euc(unsigned char *str, unsigned char *str2);
 
 #define CHAROUT(ch) *str2 = (unsigned char)(ch); str2++;
 
-/* --------------------------------------- JIS(ISO-2022) ɤڤؤ -- */
+/* --------------------------------------- JIS(ISO-2022) コードへ切り替え -- */
 
 static unsigned char *_to_jis(unsigned char *str) {
   *str = (unsigned char)ESC; str++;
@@ -48,12 +48,12 @@ static unsigned char *_to_jis(unsigned char *str) {
   return str;
 }
 
-/* ----------------------------------------------- ASCII ɤڤؤ -- */
+/* ----------------------------------------------- ASCII コードへ切り替え -- */
 
-/* ESC ( B  ESC ( J ΰ㤤
-   ϡ ESC ( J JIS-Roman ηϤǤ뤬
-   󥿡ͥåȤξǤϡѿASCII Ȼפ롣
-   \  ~椬㤦Ǥ롣 */
+/* ESC ( B と ESC ( J の違い。
+   本来は、 ESC ( J が正しいJIS-Roman 体系であるが、
+   インターネットの上では、英数字はASCII の方が自然かと思われる。
+   \ 記号と ~記号が違うだけである。 */
 
 static unsigned char *_to_ascii(unsigned char *str) {
   *str = (unsigned char)ESC; str++;
@@ -62,7 +62,7 @@ static unsigned char *_to_ascii(unsigned char *str) {
   return str;
 }
 
-/* -------------------------------------- JIS   SJISȤƥե -- */
+/* -------------------------------------- JIS コード を SJISとしてシフト -- */
 
 static void _jis_shift(int *p1, int *p2)
 {
@@ -75,7 +75,7 @@ static void _jis_shift(int *p1, int *p2)
   *p2 += cellOffset;
 }
 
-/* --------------------------------- SJIS ɤJIS ɤȤƥե -- */
+/* --------------------------------- SJIS コードをJIS コードとしてシフト -- */
 
 static void _sjis_shift(int *p1, int *p2)
 {
@@ -89,7 +89,7 @@ static void _sjis_shift(int *p1, int *p2)
   *p2 -= cellOffset;
 }
 
-/* ---------------------------------------------- SJIS ȾѤѤѴ -- */
+/* ---------------------------------------------- SJIS 半角を全角に変換 -- */
 #define HANKATA(a)  (a >= 161 && a <= 223)
 #define ISMARU(a)   (a >= 202 && a <= 206)
 #define ISNIGORI(a) ((a >= 182 && a <= 196) || (a >= 202 && a <= 206) || (a == 179))
@@ -114,7 +114,7 @@ static unsigned char *_sjis_han2zen(unsigned char *str, int *p1, int *p2)
   *p1 = stable[c1 - 161][0];
   *p2 = stable[c1 - 161][1];
 
-  /* Ⱦν */
+  /* 濁音、半濁音の処理 */
   c2 = (int)*str;
   if (c2 == 222 && ISNIGORI(c1)) {
     if ((*p2 >= 74 && *p2 <= 103) || (*p2 >= 110 && *p2 <= 122))
@@ -131,7 +131,7 @@ static unsigned char *_sjis_han2zen(unsigned char *str, int *p1, int *p2)
   return str++;
 }
 
-/* -------------------------------------------------- SJIS ɤѴ -- */
+/* -------------------------------------------------- SJIS コードを変換 -- */
 
 #define SJIS1(A)    ((A >= 129 && A <= 159) || (A >= 224 && A <= 239))
 #define SJIS2(A)    (A >= 64 && A <= 252)
@@ -158,7 +158,7 @@ static void _shift2seven(unsigned char *str, unsigned char *str2)
     }
 
 #ifdef NO_HANKAKU_SJIS
-    /* Ⱦ SJIS ϡŪѤѤ */
+    /* 半角 SJIS は、強制的に全角に変える */
     if (HANKATA(p1)) {
       str = _sjis_han2zen(str, &p1, &p2);
       _sjis_shift(&p1,&p2);
@@ -173,7 +173,7 @@ static void _shift2seven(unsigned char *str, unsigned char *str2)
 #endif
 
     if (esc_in) {
-      /* LF / CR ξϡ˥ץȤ */
+      /* LF / CR の場合は、正常にエスケープアウトされる */
       esc_in = FALSE;
       str2 = _to_ascii(str2);
     }
@@ -186,7 +186,7 @@ static void _shift2seven(unsigned char *str, unsigned char *str2)
   *str2='\0';
 }
 
-/* --------------------------------------------- SJIS  EUC Ѵ -- */
+/* --------------------------------------------- SJIS を EUC に変換する -- */
 
 static void _shift2euc(unsigned char *str, unsigned char *str2)
 {
@@ -207,7 +207,7 @@ static void _shift2euc(unsigned char *str, unsigned char *str2)
     }
 
 #ifdef NO_HANKAKU_SJIS
-    /* Ⱦ SJIS ϡŪѤѤ */
+    /* 半角 SJIS は、強制的に全角に変える */
     if (HANKATA(p1)) {
       str = _sjis_han2zen(str,&p1,&p2);
       _sjis_shift(&p1,&p2);
@@ -224,7 +224,7 @@ static void _shift2euc(unsigned char *str, unsigned char *str2)
   *str2='\0';
 }
 
-/* ------------------------------------------------- Ⱦ SJIS  -- */
+/* ------------------------------------------------- 半角 SJIS を取り除く -- */
 
 static void _shift_self(unsigned char *str, unsigned char *str2)
 {
@@ -232,7 +232,7 @@ static void _shift_self(unsigned char *str, unsigned char *str2)
   
   while ((p1 = (int)*str) != '\0') {
 #ifdef NO_HANKAKU_SJIS
-    /* Ⱦ SJIS ϡŪѤѤ */
+    /* 半角 SJIS は、強制的に全角に変える */
     if (HANKATA(p1)) {
       str = _sjis_han2zen(str, &p1, &p2);
       CHAROUT(p1);
@@ -246,7 +246,7 @@ static void _shift_self(unsigned char *str, unsigned char *str2)
   *str2='\0';
 }
 
-/* ------------------------------------------------------EUC  JIS  -- */
+/* ------------------------------------------------------EUC から JIS へ -- */
 
 #define ISEUC(A)    (A >= 161 && A <= 254)
 
@@ -292,7 +292,7 @@ static void _euc2seven(unsigned char *str, unsigned char *str2)
   *str2='\0';
 }
 
-/* ------------------------------------------------ EUC  SJIS Ѵ -- */
+/* ------------------------------------------------ EUC から SJIS に変換 -- */
  
 static void _euc2shift(unsigned char *str, unsigned char *str2)
 {
@@ -318,7 +318,7 @@ static void _euc2shift(unsigned char *str, unsigned char *str2)
   *str2='\0';
 }
 
-/* -------------------------------------- ESC 󥹤򥹥åפ ----- */
+/* -------------------------------------- ESC シーケンスをスキップする ----- */
 
 static unsigned char *_skip_esc(unsigned char *str, int *esc_in) {
   int c;
@@ -333,7 +333,7 @@ static unsigned char *_skip_esc(unsigned char *str, int *esc_in) {
 }
 
 
-/* ----------------------------------------------- JIS  SJIS Ѵ -- */
+/* ----------------------------------------------- JIS を SJIS に変換する -- */
 
 static void _seven2shift(unsigned char *str, unsigned char *str2)
 {
@@ -341,7 +341,7 @@ static void _seven2shift(unsigned char *str, unsigned char *str2)
 
   while ((p1 = (int)*str) != '\0') {
 
-    /* ESC󥹤򥹥åפ */
+    /* ESCシーケンスをスキップする */
     if (p1 == ESC) {
       str = _skip_esc(str, &esc_in);
       continue;
@@ -351,14 +351,14 @@ static void _seven2shift(unsigned char *str, unsigned char *str2)
       if (esc_in) esc_in = FALSE;
     }
 
-    if(esc_in) { /* ISO-2022-JP  */
+    if(esc_in) { /* ISO-2022-JP コード */
       if((p2 = (int)*(++str)) == '\0') break;
 
       _jis_shift(&p1, &p2);
 
       CHAROUT(p1);
       CHAROUT(p2);
-    }else{       /* ASCII  */
+    }else{       /* ASCII コード */
       CHAROUT(p1);
     }
     str++;
@@ -366,7 +366,7 @@ static void _seven2shift(unsigned char *str, unsigned char *str2)
   *str2 = '\0';
 }
 
-/* ------------------------------------------------ JIS  EUC Ѵ -- */
+/* ------------------------------------------------ JIS を EUC に変換する -- */
 
 static void _seven2euc(unsigned char *str, unsigned char *str2)
 {
@@ -374,7 +374,7 @@ static void _seven2euc(unsigned char *str, unsigned char *str2)
 
   while ((p1 = (int)*str) != '\0') {
 
-    /* ESC󥹤򥹥åפ */
+    /* ESCシーケンスをスキップする */
     if (p1 == ESC) {
       str = _skip_esc(str, &esc_in);
       continue;
@@ -384,12 +384,12 @@ static void _seven2euc(unsigned char *str, unsigned char *str2)
       if (esc_in) esc_in = FALSE;
     }
 
-    if(esc_in) { /* ISO-2022-JP  */
+    if(esc_in) { /* ISO-2022-JP コード */
       CHAROUT(p1 + 128); 
       
       if((p1 = (int)*(++str)) == '\0') break;
       CHAROUT(p1 + 128);
-    }else{       /* ASCII  */
+    }else{       /* ASCII コード */
       CHAROUT(p1);
     }
     str++;
@@ -398,7 +398,7 @@ static void _seven2euc(unsigned char *str, unsigned char *str2)
 }
 
 /* ------------------------------------------------------------------------ */
-/* --------------------------------------------------------- Public ؿ -- */
+/* --------------------------------------------------------- Public 関数 -- */
 char *toStringJIS(char *str, char *buf, int maxlen) {
   int detected;
 
