@@ -2,7 +2,7 @@
  * @file   main.c
  * 
  * <JA>
- * @brief  Julius/Julian ᥤ
+ * @brief  Julius/Julian メイン
  * </JA>
  * 
  * <EN>
@@ -27,6 +27,7 @@
 
 boolean separate_score_flag = FALSE;
 boolean outfile_enabled = FALSE;
+boolean noxmlescape_enabled = FALSE;
 
 static char *logfile = NULL;
 static boolean nolog = FALSE;
@@ -69,6 +70,12 @@ opt_outfile(Jconf *jconf, char *arg[], int argnum)
   outfile_enabled = TRUE;
   return TRUE;
 }
+static boolean
+opt_noxmlescape(Jconf *jconf, char *arg[], int argnum)
+{
+  noxmlescape_enabled = TRUE;
+  return TRUE;
+}
    
 /**********************************************************************/
 int
@@ -97,6 +104,7 @@ main(int argc, char *argv[])
   module_add_option();
   charconv_add_option();
   j_add_option("-separatescore", 0, 0, "output AM and LM scores separately", opt_separatescore);
+  j_add_option("-noxmlescape", 0, 0, "disable XML escape", opt_noxmlescape);
   j_add_option("-logfile", 1, 1, "output log to file", opt_logfile);
   j_add_option("-nolog", 0, 0, "not output any log", opt_nolog);
   j_add_option("-outfile", 0, 0, "save result in separate .out file", opt_outfile);
@@ -208,8 +216,8 @@ main(int argc, char *argv[])
   callback_add(recog, CALLBACK_DEBUG_PASS2_PUSH, visual2_next_word, NULL);
   /* below should be called at result */
   visual2_best(now, winfo);
-  /* ߤϥХåǿ */
-  /* 2ѥǧ̽ϻ˰ʲ¹ */
+  /* 音声取り込みはコールバックで新規作成 */
+  /* 第2パスで認識結果出力時に以下を実行 */
   visual2_best(now, recog->model->winfo);
 #endif
   
