@@ -169,16 +169,16 @@ send_current_process(RecogProcess *r)
 
 /** 
  * <JA>
- * @brief  ⥸塼륳ޥɤ. 
+ * @brief  モジュールコマンドを処理する. 
  *
- * 饤ȤͿ줿ޥɤ. δؿϥ饤Ȥ
- * ޥɤƤ뤿Ӥ˲ǧ˳ǸƤФ. 
- * ơˤĤƤϤǤ˱å뤬
- * ʸˡɲäʤɤϡǤϼΤ߹Ԥºݤѹ
- * ʳʸˡΥХʸˡκƹۤʤɡˤǧι֤˼¹Ԥ. 
- * ʸˡƹ۽ºݤ˹ԤΤ multigram_update() Ǥ. 
+ * クライアントより与えられたコマンドを処理する. この関数はクライアントから
+ * コマンドが送られてくるたびに音声認識処理に割り込んで呼ばれる. 
+ * ステータス等についてはここですぐに応答メッセージを送るが，
+ * 文法の追加や削除などは，ここでは受信のみ行い，実際の変更処理
+ * （各文法からのグローバル文法の再構築など）は認識処理の合間に実行される. 
+ * この文法再構築処理を実際に行うのは multigram_update() である. 
  * 
- * @param command [in] ޥʸ
+ * @param command [in] コマンド文字列
  * </JA>
  * <EN>
  * @brief  Process a module command.
@@ -280,7 +280,7 @@ msock_exec_command(char *command, Recog *recog)
 	/* delete all existing grammars */
 	multigram_delete_all(cur->lm);
 	/* register the new grammar to multi-gram tree */
-	multigram_add(new_dfa, new_winfo, p, cur->lm);
+	multigram_add(new_dfa, new_winfo, p, cur->lm, NULL);
 	/* need to rebuild the global lexicon */
 	/* tell engine to update at requested timing */
 	schedule_grammar_update(recog);
@@ -312,7 +312,7 @@ msock_exec_command(char *command, Recog *recog)
     } else {
       if (cur->lmtype == LM_DFA) {
 	/* add it to multi-gram tree */
-	multigram_add(new_dfa, new_winfo, p, cur->lm);
+	multigram_add(new_dfa, new_winfo, p, cur->lm, NULL);
 	/* need to rebuild the global lexicon */
 	/* make sure this process will be activated */
 	cur->active = 1;
@@ -675,8 +675,8 @@ msock_exec_command(char *command, Recog *recog)
 
 /** 
  * <JA>
- * ߥ饤ȥ⥸塼뤫̿᤬Хåեˤ뤫Ĵ١
- * ⤷н. ʤФΤޤ޽λ. 
+ * 現在クライアントモジュールからの命令がバッファにあるか調べ，
+ * もしあれば処理する. なければそのまま終了する. 
  * 
  * </JA>
  * <EN>
@@ -723,11 +723,11 @@ msock_check_and_process_command(Recog *recog, void *dummy)
 
 /** 
  * <JA>
- * 饤ȥ⥸塼뤫̿ɤ߹ǽ. 
- * ̿᤬̵硤ΥޥɤޤԤ. 
- * msock_exec_command()  j_request_resume() ƤФ
- * recog->process_active  TRUE ˤʤޤǷ֤. 
- * δؿäȤץ resume |!. |
+ * クライアントモジュールからの命令を読み込んで処理する. 
+ * 命令が無い場合，次のコマンドが来るまで待つ. 
+ * msock_exec_command() 内で j_request_resume() が呼ばれて
+ * recog->process_active が TRUE になるまで繰り返す. 
+ * この関数が終わったときプロセスは resume |!する. |
  * 
  * </JA>
  * <EN>
