@@ -10,13 +10,16 @@
 #include <time.h>
 
 extern boolean separate_score_flag;
+extern boolean noxmlescape_enabled;
+
+#define MAXSTRLEN 2048
 
 /**********************************************************************/
 /* process online/offline status  */
 
 /** 
  * <JA>
- * ǧǽʾ֤ˤʤäȤ˸ƤФ
+ * 認識可能な状態になったときに呼ばれる
  * 
  * </JA>
  * <EN>
@@ -31,7 +34,7 @@ status_process_online(Recog *recog, void *dummy)
 }
 /** 
  * <JA>
- * ǧǾ֤ˤʤäȤ˸ƤФ
+ * 認識を一時中断状態になったときに呼ばれる
  * 
  * </JA>
  * <EN>
@@ -57,9 +60,9 @@ static boolean out2_cm = TRUE;
 
 /** 
  * <JA>
- * ǧ̤ȤƤɤäñϤ뤫򥻥åȤ롣
+ * 認識結果としてどういった単語情報を出力するかをセットする。
  * 
- * @param str [in] Ϲܻʸ ("WLPSCwlps"ΰ)
+ * @param str [in] 出力項目指定文字列 ("WLPSCwlps"の一部)
  * </JA>
  * <EN>
  * Setup which word information to be output as a recognition result.
@@ -105,10 +108,10 @@ decode_output_selection(char *str)
 
 /** 
  * <JA>
- * ǧñξϤ륵֥롼1ѥѡ. 
+ * 認識単語の情報を出力するサブルーチン（第1パス用）. 
  * 
- * @param w [in] ñID
- * @param winfo [in] ñ켭
+ * @param w [in] 単語ID
+ * @param winfo [in] 単語辞書
  * </JA>
  * <EN>
  * Subroutine to output information of a recognized word at 1st pass.
@@ -122,22 +125,26 @@ msock_word_out1(WORD_ID w, RecogProcess *r)
 {
   int j;
   static char buf[MAX_HMMNAME_LEN];
+  static char exbuf[MAXSTRLEN];
   WORD_INFO *winfo;
 
   winfo = r->lm->winfo;
 
   if (out1_word) {
-    module_send(" WORD=\"%s\"", winfo->woutput[w]);
+    escape_xml(winfo->woutput[w], exbuf);
+    module_send(" WORD=\"%s\"", exbuf);
   }
   if (out1_lm) {
-    module_send(" CLASSID=\"%s\"", winfo->wname[w]);
+    escape_xml(winfo->wname[w], exbuf);
+    module_send(" CLASSID=\"%s\"", exbuf);
   }
   if (out1_phone) {
     module_send(" PHONE=\"");
     for(j=0;j<winfo->wlen[w];j++) {
       center_name(winfo->wseq[w][j]->name, buf);
-      if (j == 0) module_send("%s", buf);
-      else module_send(" %s", buf);
+      escape_xml(buf, exbuf);
+      if (j == 0) module_send("%s", exbuf);
+      else module_send(" %s", exbuf);
     }
     module_send("\"");
   }
@@ -145,10 +152,10 @@ msock_word_out1(WORD_ID w, RecogProcess *r)
 
 /** 
  * <JA>
- * ǧñξϤ륵֥롼2ѥѡ. 
+ * 認識単語の情報を出力するサブルーチン（第2パス用）. 
  * 
- * @param w [in] ñID
- * @param winfo [in] ñ켭
+ * @param w [in] 単語ID
+ * @param winfo [in] 単語辞書
  * </JA>
  * <EN>
  * Subroutine to output information of a recognized word at 2nd pass.
@@ -162,22 +169,26 @@ msock_word_out2(WORD_ID w, RecogProcess *r)
 {
   int j;
   static char buf[MAX_HMMNAME_LEN];
+  static char exbuf[MAXSTRLEN];
   WORD_INFO *winfo;
 
   winfo = r->lm->winfo;
 
   if (out2_word) {
-    module_send(" WORD=\"%s\"", winfo->woutput[w]);
+    escape_xml(winfo->woutput[w], exbuf);
+    module_send(" WORD=\"%s\"", exbuf);
   }
   if (out2_lm) {
-    module_send(" CLASSID=\"%s\"", winfo->wname[w]);
+    escape_xml(winfo->wname[w], exbuf);
+    module_send(" CLASSID=\"%s\"", exbuf);
   }
   if (out2_phone) {
     module_send(" PHONE=\"");
     for(j=0;j<winfo->wlen[w];j++) {
       center_name(winfo->wseq[w][j]->name, buf);
-      if (j == 0) module_send("%s", buf);
-      else module_send(" %s", buf);
+      escape_xml(buf, exbuf);
+      if (j == 0) module_send("%s", exbuf);
+      else module_send(" %s", exbuf);
     }
     module_send("\"");
   }
@@ -189,7 +200,7 @@ msock_word_out2(WORD_ID w, RecogProcess *r)
 
 /** 
  * <JA>
- * 1ѥǧ򳫻Ϥݤνϡʲϳϻ˸ƤФ. 
+ * 第1パス：音声認識を開始する際の出力（音声入力開始時に呼ばれる）. 
  * 
  * </JA>
  * <EN>
@@ -205,14 +216,14 @@ status_pass1_begin(Recog *recog, void *dummy)
 
 /** 
  * <JA>
- * 1ѥ̤Ϥ1ѥΰ֤Ȥ˸ƤФ
+ * 第1パス：途中結果を出力する（第1パスの一定時間ごとに呼ばれる）
  * 
- * @param t [in] ߤλ֥ե졼
- * @param seq [in] ߤΰ̸ñ
- * @param num [in] @a seq Ĺ
- * @param score [in] 嵭ΤޤǤѥ
- * @param LMscore [in] 嵭κǸñο
- * @param winfo [in] ñ켭
+ * @param t [in] 現在の時間フレーム
+ * @param seq [in] 現在の一位候補単語列
+ * @param num [in] @a seq の長さ
+ * @param score [in] 上記のこれまでの累積スコア
+ * @param LMscore [in] 上記の最後の単語の信頼度
+ * @param winfo [in] 単語辞書
  * </JA>
  * <EN>
  * 1st pass: output current result while search (called periodically while 1st pass).
@@ -234,6 +245,7 @@ result_pass1_current(Recog *recog, void *dummy)
   int num;
   RecogProcess *r;
   boolean multi;
+  static char exbuf[MAXSTRLEN];
 
   if (out1_never) return;	/* no output specified */
 
@@ -249,14 +261,15 @@ result_pass1_current(Recog *recog, void *dummy)
     num = r->result.pass1.word_num;
 
     if (multi) {
-      module_send("<RECOGOUT ID=\"SR%02d\" NAME=\"%s\">\n", r->config->id, r->config->name);
+      escape_xml(r->config->name, exbuf);
+      module_send("<RECOGOUT ID=\"SR%02d\" NAME=\"%s\">\n", r->config->id, exbuf);
     } else {
       module_send("<RECOGOUT>\n");
     }
     if (out1_score) {
-      module_send("  <PHYPO PASS=\"1\" SCORE=\"%f\" FRAME=\"%d\" TIME=\"%ld\"/>\n", r->result.pass1.score, r->result.num_frame, time(NULL));
+      module_send("  <PHYPO PASS=\"1\" SCORE=\"%f\" FRAME=\"%d\" TIME=\"%ld\">\n", r->result.pass1.score, r->result.num_frame, time(NULL));
     } else {
-      module_send("  <PHYPO PASS=\"1\" FRAME=\"%d\" TIME=\"%ld\"/>\n", r->result.num_frame, time(NULL));
+      module_send("  <PHYPO PASS=\"1\" FRAME=\"%d\" TIME=\"%ld\">\n", r->result.num_frame, time(NULL));
     }
     for (i=0;i<num;i++) {
       module_send("    <WHYPO");
@@ -269,14 +282,14 @@ result_pass1_current(Recog *recog, void *dummy)
 
 /** 
  * <JA>
- * 1ѥλ1ѥη̤Ϥ1ѥλ塢2ѥ
- * Ϥޤ˸ƤФ. ǧ˼ԤϸƤФʤ. 
+ * 第1パス：終了時に第1パスの結果を出力する（第1パス終了後、第2パスが
+ * 始まる前に呼ばれる. 認識に失敗した場合は呼ばれない）. 
  * 
- * @param seq [in] 1ѥ1̸ñ
- * @param num [in] 嵭Ĺ
- * @param score [in] 1̤Ѳ⥹
- * @param LMscore [in] @a score Τ쥹
- * @param winfo [in] ñ켭
+ * @param seq [in] 第1パスの1位候補の単語列
+ * @param num [in] 上記の長さ
+ * @param score [in] 1位の累積仮説スコア
+ * @param LMscore [in] @a score のうち言語スコア
+ * @param winfo [in] 単語辞書
  * </JA>
  * <EN>
  * 1st pass: output final result of the 1st pass (will be called just after
@@ -296,6 +309,7 @@ result_pass1_final(Recog *recog, void *dummy)
   int i;
   RecogProcess *r;
   boolean multi;
+  static char exbuf[MAXSTRLEN];
 
   if (out1_never) return;	/* no output specified */
 
@@ -307,7 +321,8 @@ result_pass1_final(Recog *recog, void *dummy)
     if (r->result.status < 0) continue;	/* search already failed  */
 
     if (multi) {
-      module_send("<RECOGOUT ID=\"SR%02d\" NAME=\"%s\">\n", r->config->id, r->config->name);
+      escape_xml(r->config->name, exbuf);
+      module_send("<RECOGOUT ID=\"SR%02d\" NAME=\"%s\">\n", r->config->id, exbuf);
     } else {
       module_send("<RECOGOUT>\n");
     }
@@ -327,7 +342,7 @@ result_pass1_final(Recog *recog, void *dummy)
 
 /** 
  * <JA>
- * 1ѥλνϡ1ѥνλɬƤФ
+ * 第1パス：終了時の出力（第1パスの終了時に必ず呼ばれる）
  * 
  * </JA>
  * <EN>
@@ -346,11 +361,11 @@ status_pass1_end(Recog *recog, void *dummy)
 
 /** 
  * <JA>
- * 2ѥ줿ʸ1ĽϤ. 
+ * 第2パス：得られた文仮説候補を1つ出力する. 
  * 
- * @param hypo [in] 줿ʸ
- * @param rank [in] @a hypo ν
- * @param winfo [in] ñ켭
+ * @param hypo [in] 得られた文仮説
+ * @param rank [in] @a hypo の順位
+ * @param winfo [in] 単語辞書
  * </JA>
  * <EN>
  * 2nd pass: output a sentence hypothesis found in the 2nd pass.
@@ -371,6 +386,7 @@ result_pass2(Recog *recog, void *dummy)
   RecogProcess *r;
   boolean multi;
   SentenceAlign *align;
+  static char exbuf[MAXSTRLEN];
 
   if (recog->process_list->next != NULL) multi = TRUE;
   else multi = FALSE;
@@ -403,7 +419,8 @@ result_pass2(Recog *recog, void *dummy)
 	break;
       }
       if (multi) {
-	module_send(" ID=\"SR%02d\" NAME=\"%s\"", r->config->id, r->config->name);
+	escape_xml(r->config->name, exbuf);
+	module_send(" ID=\"SR%02d\" NAME=\"%s\"", r->config->id, exbuf);
       }
       module_send("/>\n.\n");
       continue;
@@ -415,7 +432,8 @@ result_pass2(Recog *recog, void *dummy)
     num = r->result.sentnum;
 
     if (multi) {
-      module_send("<RECOGOUT ID=\"SR%02d\" NAME=\"%s\">\n", r->config->id, r->config->name);
+      escape_xml(r->config->name, exbuf);
+      module_send("<RECOGOUT ID=\"SR%02d\" NAME=\"%s\">\n", r->config->id, exbuf);
     } else {
       module_send("<RECOGOUT>\n");
     }
@@ -486,10 +504,10 @@ result_pass2(Recog *recog, void *dummy)
 
 /** 
  * <JA>
- * 줿ñ쥰ΤϤ. 
+ * 得られた単語グラフ全体を出力する. 
  * 
- * @param root [in] ñ콸ƬǤؤΥݥ
- * @param winfo [in] ñ켭
+ * @param root [in] グラフ単語集合の先頭要素へのポインタ
+ * @param winfo [in] 単語辞書
  * </JA>
  * <EN>
  * Output the whole word graph.
@@ -508,6 +526,7 @@ result_graph(Recog *recog, void *dummy)
   WordGraph *root;
   RecogProcess *r;
   boolean multi;
+  static char exbuf[MAXSTRLEN];
 
   if (recog->process_list->next != NULL) multi = TRUE;
   else multi = FALSE;
@@ -525,7 +544,10 @@ result_graph(Recog *recog, void *dummy)
     }
 
     module_send("<GRAPHOUT");
-    if (multi) module_send(" ID=\"SR%02d\" NAME=\"%s\"", r->config->id, r->config->name);
+    if (multi) {
+      escape_xml(r->config->name, exbuf);
+      module_send(" ID=\"SR%02d\" NAME=\"%s\"", r->config->id, exbuf);
+    }
     module_send(" NODENUM=\"%d\" ARCNUM=\"%d\">\n", nodenum, arcnum);
     for(wg=root;wg;wg=wg->next) {
       module_send("    <NODE GID=\"%d\"", wg->id);
@@ -545,7 +567,7 @@ result_graph(Recog *recog, void *dummy)
 
 /** 
  * <JA>
- * λơǧǽ֡Ԥ֡ˤäȤν
+ * 準備が終了して、認識可能状態（入力待ち状態）に入ったときの出力
  * 
  * </JA>
  * <EN>
@@ -561,7 +583,7 @@ status_recready(Recog *recog, void *dummy)
 
 /** 
  * <JA>
- * ϤγϤ򸡽ФȤν
+ * 入力の開始を検出したときの出力
  * 
  * </JA>
  * <EN>
@@ -576,7 +598,7 @@ status_recstart(Recog *recog, void *dummy)
 }
 /** 
  * <JA>
- * Ͻλ򸡽ФȤν
+ * 入力終了を検出したときの出力
  * 
  * </JA>
  * <EN>
@@ -591,9 +613,9 @@ status_recend(Recog *recog, void *dummy)
 }
 /** 
  * <JA>
- * Ĺʤɤϥѥ᡼. 
+ * 入力長などの入力パラメータ情報を出力. 
  * 
- * @param param [in] ϥѥ᡼¤
+ * @param param [in] 入力パラメータ構造体
  * </JA>
  * <EN>
  * Output input parameter status such as length.
@@ -626,7 +648,7 @@ status_param(Recog *recog, void *dummy)
 /********************* RESULT OUTPUT FOR GMM *************************/
 /** 
  * <JA>
- * GMMη׻̤⥸塼Υ饤Ȥ ("-result msock" )
+ * GMMの計算結果をモジュールのクライアントに送信する ("-result msock" 用)
  * </JA>
  * <EN>
  * Send the result of GMM computation to module client.
@@ -636,7 +658,9 @@ status_param(Recog *recog, void *dummy)
 static void
 result_gmm(Recog *recog, void *dummy)
 {
-  module_send("<GMM RESULT=\"%s\"", recog->gc->max_d->name);
+  static char exbuf[MAXSTRLEN];
+  escape_xml(recog->gc->max_d->name, exbuf);
+  module_send("<GMM RESULT=\"%s\"", exbuf);
 #ifdef CONFIDENCE_MEASURE
   module_send(" CMSCORE=\"%f\"", recog->gc->gmm_max_cm);
 #endif
@@ -645,7 +669,7 @@ result_gmm(Recog *recog, void *dummy)
 
 /** 
  * <JA>
- * ߤݻƤʸˡΥꥹȤ⥸塼. 
+ * 現在の保持している文法のリストをモジュールに送信する. 
  * 
  * </JA>
  * <EN>
@@ -704,7 +728,7 @@ send_gram_info(RecogProcess *r)
 /* register functions for module output */
 /** 
  * <JA>
- * ⥸塼ϤԤ褦ؿϿ. 
+ * モジュール出力を行うよう関数を登録する. 
  * 
  * </JA>
  * <EN>
@@ -738,3 +762,65 @@ setup_output_msock(Recog *recog, void *data)
   //callback_add(recog, CALLBACK_EVENT_RESUME, status_resume, data);
 
 }
+
+static int
+set_escape_string(char* outstr, char* afterescape, int startindex)
+{
+  int endindex = strlen(afterescape);
+  int i;
+  
+  for(i = 0; i < endindex; i++) {
+    if (i + startindex < MAXSTRLEN)
+      outstr[i + startindex] = afterescape[i];
+  }
+  return endindex;
+}
+
+/**
+ * <JA>
+ * XMLの属性の値に使う文字をエスケープし、それを返す。
+ * </JA>
+ * <EN>
+ * Escaped character for xml attribute. And return it.
+ * </EN>
+ */
+void
+escape_xml(char* originstr, char* outbuf)
+{
+  int outi = 0;
+  int origin_len =strlen(originstr);
+  int i;
+  
+  if (noxmlescape_enabled == TRUE) {
+    strncpy(outbuf, originstr, MAXSTRLEN);
+    outbuf[MAXSTRLEN-1] = '\0';
+    return;
+  }
+  
+  for(i = 0; i < origin_len; i++) {
+    switch(originstr[i]) {
+      case '<':
+        outi += set_escape_string(outbuf, "&lt;", outi);
+	break;
+      case '>':
+        outi += set_escape_string(outbuf, "&gt;", outi);
+	break;
+      case '"':
+        outi += set_escape_string(outbuf, "&quot;", outi);
+	break;
+      case '&':
+        outi += set_escape_string(outbuf, "&amp;", outi);
+	break;
+      case '\'':
+        outi += set_escape_string(outbuf, "&apos;", outi);
+	break;
+      default:
+	if (outi < MAXSTRLEN - 1) {
+	  outbuf[outi] = originstr[i];
+	  outi++;
+	}
+	break;
+    }
+  }
+  outbuf[outi] = '\0';
+}
