@@ -2,12 +2,12 @@
  * @file   visual.c
  * 
  * <JA>
- * @brief  õ֤βĻ벽 (GTK/X11 )
+ * @brief  探索空間の可視化 (GTK/X11 を使用)
  *
- * õֲĻ벽ǽ Linux ǥݡȤƤޤ. 
- * "--enable-visualize"  ON ˤƥѥǤޤ. 
- * ʤѤˤ gtk ΥС 1.x ɬפǤ. 
- * ưǧ gtk-1.2 ǹԤޤ. 
+ * 探索空間可視化機能は Linux でサポートされています. 
+ * "--enable-visualize" で ON にしてコンパイルできます. 
+ * なお，使用には gtk のバージョン 1.x が必要です. 
+ * 動作確認は gtk-1.2 で行いました. 
  * </JA>
  * 
  * <EN>
@@ -104,7 +104,7 @@ static GdkGC *dgc = NULL;		///< gc for drawing
 
 /** 
  * <JA>
- * γ
+ * 色の割付
  * </JA>
  * <EN>
  * Assign color.
@@ -136,9 +136,9 @@ static LOGPROB maxrange2;	///< Maximum distance from normalization line
 
 /** 
  * <JA>
- * Ѥ˺祹ȺǾ. 
+ * スケーリング用に最大スコアと最小スコアを得る. 
  * 
- * @param bt [in] ñȥꥹ
+ * @param bt [in] 単語トレリス
  * </JA>
  * <EN>
  * Get the top and bottom scores for scaling.
@@ -190,11 +190,11 @@ get_max_frame_score(BACKTRELLIS *bt)
 
 /** 
  * <JA>
- * ֥ե졼 X ɸͤѴ. 
+ * 時間フレームを X 座標値に変換する. 
  * 
- * @param t [in] ֥ե졼
+ * @param t [in] 時間フレーム
  * 
- * @return б X ɸ֤ͤ. 
+ * @return 対応する X 座標値を返す. 
  * </JA>
  * <EN>
  * Scale X axis by time to fullfill in the canvas width.
@@ -212,12 +212,12 @@ scale_x(int t)
 
 /** 
  * <JA>
- *  Y ɸͤѴ. 
+ * スコアを Y 座標値に変換する. 
  * 
- * @param s [in] 
- * @param t [in] б֥ե졼
+ * @param s [in] スコア
+ * @param t [in] 対応する時間フレーム
  * 
- * @return Y ɸ֤ͤ. 
+ * @return Y 座標値を返す. 
  * </JA>
  * <EN>
  * Scale Y axis from score to fulfill in the canvas height.
@@ -261,11 +261,11 @@ scale_y(LOGPROB s, int t)
 
 /** 
  * <JA>
- * ñID Y ɸͤѴ. 
+ * 単語IDを Y 座標値に変換する. 
  * 
- * @param wid [in] ñID
+ * @param wid [in] 単語ID
  * 
- * @return Y ɸ֤ͤ. 
+ * @return Y 座標値を返す. 
  * </JA>
  * <EN>
  * Scale Y axis from word id.
@@ -299,11 +299,11 @@ static SP16 max_level;		///< Maximum level of input waveform
 
 /** 
  * <JA>
- * ȷɽѤ˻֤XɸѴ. 
+ * 波形表示用に時間をX座標に変換する. 
  * 
- * @param t [in] ֥ե졼
+ * @param t [in] 時間フレーム
  * 
- * @return Ѵ X ɸ֤. 
+ * @return 変換後の X 座標を返す. 
  * </JA>
  * <EN>
  * Scale time to X position.
@@ -321,11 +321,11 @@ scale_x_wave(int t)
 
 /** 
  * <JA>
- * ȷɽѤ˿YɸѴ. 
+ * 波形表示用に振幅をY座標に変換する. 
  * 
- * @param x [in] ȷο
+ * @param x [in] 波形の振幅
  * 
- * @return Ѵ X ɸ֤. 
+ * @return 変換後の X 座標を返す. 
  * </JA>
  * <EN>
  * Scale wave level to Y position
@@ -343,7 +343,7 @@ scale_y_wave(SP16 x)
 
 /** 
  * <JA>
- * κͤ speech[] . 
+ * 振幅の最大値を speech[] より求める. 
  * 
  * </JA>
  * <EN>
@@ -372,9 +372,9 @@ get_max_waveform_level()
 
 /** 
  * <JA>
- * ȷ speech[] 褹. 
+ * 入力波形 speech[] を描画する. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Draw input waveform in speech[].
@@ -447,14 +447,14 @@ draw_waveform(GtkWidget *widget)
 
 /** 
  * <JA>
- * 褹. 
+ * アークを描画する. 
  * 
- * @param widget [in] 襦å
- * @param x1 [in] 1Xɸ
- * @param y1 [in] 1Yɸ
- * @param x2 [in] 2Xɸ
- * @param y2 [in] 2Yɸ
- * @param sw [in] ٥λ
+ * @param widget [in] 描画ウィジェット
+ * @param x1 [in] 第1点のX座標
+ * @param y1 [in] 第1点のY座標
+ * @param x2 [in] 第2点のX座標
+ * @param y2 [in] 第2点のY座標
+ * @param sw [in] 描画レベルの指定
  * </JA>
  * <EN>
  * Draw an arc.
@@ -539,12 +539,12 @@ mygdk_draw_arc(GtkWidget *widget, int x1, int y1, int x2, int y2, int sw)
 
 /** 
  * <JA>
- * ȥꥹñ褹륵ִؿ. 
+ * トレリス単語を描画するサブ関数. 
  * 
- * @param widget [in] 襦å
- * @param tre [in] 褹ȥꥹñ
- * @param last_tre [in] @a tre ľΥȥꥹñ
- * @param sw [in] ζ
+ * @param widget [in] 描画ウィジェット
+ * @param tre [in] 描画するトレリス単語
+ * @param last_tre [in] @a tre の直前のトレリス単語
+ * @param sw [in] 描画の強さ
  * </JA>
  * <EN>
  * Sub-function to draw a trellis word.
@@ -596,11 +596,11 @@ draw_atom_sub(GtkWidget *widget, TRELLIS_ATOM *tre, TRELLIS_ATOM *last_tre, int
 
 /** 
  * <JA>
- * 1ѥΤȥꥹñ褹
+ * 第1パスのあるトレリス単語を描画する
  * 
- * @param widget [in] 襦å
- * @param tre [in] ȥꥹñ
- * @param sw [in] ζ
+ * @param widget [in] 描画ウィジェット
+ * @param tre [in] トレリス単語
+ * @param sw [in] 描画の強さ
  * </JA>
  * <EN>
  * Draw a trellis word at the 1st pass.
@@ -619,11 +619,11 @@ draw_atom(GtkWidget *widget, TRELLIS_ATOM *tre, int sw)
 /* draw word output text */
 /** 
  * <JA>
- * ȥꥹññɤߤ褹. 
+ * トレリス単語の単語読みを描画する. 
  * 
- * @param widget [in] 襦å
- * @param tre [in] ȥꥹñ
- * @param sw [in] ζ
+ * @param widget [in] 描画ウィジェット
+ * @param tre [in] トレリス単語
+ * @param sw [in] 描画の強さ
  * </JA>
  * <EN>
  * Draw a word output string of a trellis word.
@@ -690,11 +690,11 @@ static WORD_ID wordlistnum = 0;	///< Length of @a wordlist
 
 /** 
  * <JA>
- * ñꥹȤñ줬뤫ɤ. 
+ * 描画単語リストの中に単語があるかどうか検索する. 
  * 
- * @param wid [in] ñID
+ * @param wid [in] 単語ID
  * 
- * @return ꥹȤ˸Ĥ TRUEĤʤ FALSE ֤. 
+ * @return リストに見つかれば TRUE，見つからなければ FALSE を返す. 
  * </JA>
  * <EN>
  * Check if the given word exists in the drawn word list.
@@ -733,11 +733,11 @@ wordlist_find(WORD_ID wid)
 
 /** 
  * <JA>
- * ñ褹ñꥹȤˤΤΤߡ. 
+ * 単語を描画する（描画単語リストにあるもののみ）. 
  * 
- * @param widget [in] 襦å
- * @param tre [in] 褹ȥꥹñ
- * @param sw [in] ζ
+ * @param widget [in] 描画ウィジェット
+ * @param tre [in] 描画するトレリス単語
+ * @param sw [in] 描画の強さ
  * </JA>
  * <EN>
  * Draw a word on canvas (only words in wordlist).
@@ -757,15 +757,15 @@ draw_atom_top(GtkWidget *widget, TRELLIS_ATOM *tre, int sw)
 
 /** 
  * <JA>
- * ñ褹ñꥹȤˤΤΤߡ. 
- * ñΥƥȤ褹ʥꥹȤˤʤ褷ʤ. 
+ * 単語を描画する（描画単語リストにあるもののみ）. 
+ * 単語のテキストを描画する（リストになければ描画しない）. 
  * 
- * @param widget [in] 襦å
- * @param tre [in] 褹ȥꥹñ
- * @param sw [in] ζ
+ * @param widget [in] 描画ウィジェット
+ * @param tre [in] 描画するトレリス単語
+ * @param sw [in] 描画の強さ
  * </JA>
  * <EN>
- * ñΥƥȤ褹ñꥹȤˤΤΤߡ. 
+ * 単語のテキストを描画する（描画単語リストにあるもののみ）. 
  * Draw text of a word on canvas (only words in wordlist).
  * 
  * @param widget [in] drawing widget
@@ -788,9 +788,9 @@ draw_atom_text_top(GtkWidget *widget, TRELLIS_ATOM *tre, int sw)
 
 /** 
  * <JA>
- * ƤΥȥꥹñ褹. 
+ * 全てのトレリス単語を描画する. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Draw all survived words in trellis.
@@ -822,9 +822,9 @@ draw_all_atom(GtkWidget *widget)
 
 /** 
  * <JA>
- * 1ѥˤƤμñ줬ĤäȥꥹñΤ褹. 
+ * 第1パスにおいてその次単語が生き残ったトレリス単語のみ描画する. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Draw words whose next word was survived on the 1st pass.
@@ -861,9 +861,9 @@ draw_context_valid_atom(GtkWidget *widget)
 #ifdef WORD_GRAPH
 /** 
  * <JA>
- * ñ쥰դȤ褹
+ * 単語グラフとして描画する
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Draw words as word graph.
@@ -903,9 +903,9 @@ draw_word_graph(GtkWidget *widget)
 
 /** 
  * <JA>
- * 1ѥΰʸ褹. 
+ * 第1パスの一位文仮説を描画する. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Draw the best path at the 1st pass.
@@ -970,9 +970,9 @@ draw_best_path(GtkWidget *widget)
 
 /** 
  * <JA>
- * 2ѥĻ벽ΤνԤ. 
+ * 第2パス可視化のための初期化を行う. 
  * 
- * @param maxhypo [in] 2ѥˤƥݥåפ줿κ
+ * @param maxhypo [in] 第2パスにおいてポップされた仮説の最大数
  * </JA>
  * <EN>
  * Initialize for visualization of the 2nd pass.
@@ -1017,10 +1017,10 @@ visual2_init(int maxhypo)
 
 /** 
  * <JA>
- * åФ¸. 
+ * スタックから取り出した仮説をローカルに保存する. 
  * 
- * @param n [in] 
- * @param popctr [in] ߤΥݥå׿
+ * @param n [in] 仮説
+ * @param popctr [in] 現在のポップ数カウント
  * </JA>
  * <EN>
  * Store popped nodes to local buffer.
@@ -1044,11 +1044,11 @@ visual2_popped(NODE *n, int popctr)
   
 /** 
  * <JA>
- * 줿ΥΡɤ¸. 
+ * 生成された仮説のノードを保存する. 
  * 
- * @param next [in] 줿ñ첾
- * @param prev [in] Ÿβ
- * @param popctr [in] ߤ
+ * @param next [in] 生成された次単語仮説
+ * @param prev [in] 展開元の仮説
+ * @param popctr [in] 現在の生成仮説数カウンタ
  * </JA>
  * <EN>
  * Store generated nodes.
@@ -1077,16 +1077,16 @@ visual2_next_word(NODE *next, NODE *prev, int popctr)
 
 /** 
  * <JA>
- * ݥåפ줿¸. 
+ * ポップされた仮説候補を保存する. 
  * 
- * @param now [in] ʸ
- * @param winfo [in] ñ켭
+ * @param now [in] 文仮説
+ * @param winfo [in] 単語辞書
  * </JA>
  * <EN>
  * Store last popped hypothesis of best hypothesis.
  * 
- * @param now [in] ʸ
- * @param winfo [in] ñ켭
+ * @param now [in] 文仮説
+ * @param winfo [in] 単語辞書
  * </EN>
  */
 void
@@ -1109,14 +1109,14 @@ visual2_best(NODE *now, WORD_INFO *winfo)
 /* draw 2nd pass results */
 /** 
  * <JA>
- * 2ѥõˡåФ줿Ȥμñ콸褹. 
+ * 第2パス探索中に，スタックから取り出された仮説とその次単語集合を描画する. 
  * 
- * @param widget 襦å
+ * @param widget 描画ウィジェット
  * </JA>
  * <EN>
  * Draw popped hypotheses and their next candidates appeared while search.
  * 
- * @param widget 襦å
+ * @param widget 描画ウィジェット
  * </EN>
  */
 static void
@@ -1143,7 +1143,7 @@ static LOGPROB maxscore;	///< Maximum score of popped hypotheses while search
 static LOGPROB minscore;	///< Minimum score of popped hypotheses while search
 /** 
  * <JA>
- * 2ѥǽиŸΥκͤȺǾͤ. 
+ * 第2パスで出現した展開元仮説のスコアの最大値と最小値を求める. 
  * 
  * </JA>
  * <EN>
@@ -1167,11 +1167,11 @@ get_max_hypo_score()
 
 /** 
  * <JA>
- * ɽ⥹ Y ɸͤѴ. 
+ * 仮説表示時，仮説スコアを Y 座標値に変換する. 
  * 
- * @param s [in] ⥹
+ * @param s [in] 仮説スコア
  * 
- * @return бYɸ֤
+ * @return 対応するY座標を返す
  * </JA>
  * <EN>
  * Scale hypothesis score to Y position.
@@ -1196,13 +1196,13 @@ scale_hypo_y(LOGPROB s)
 /* draw popped words */
 /** 
  * <JA>
- * åФ줿褹. 
+ * スタックから取り出された仮説を描画する. 
  * 
- * @param widget [in] 襦å
- * @param p [in] åФ줿ξ
- * @param c [in] ο
- * @param width [in] 
- * @param style [in] Υ
+ * @param widget [in] 描画ウィジェット
+ * @param p [in] スタックから取り出された仮説の情報
+ * @param c [in] 線の色
+ * @param width [in] 線の幅
+ * @param style [in] 線のスタイル
  * </JA>
  * <EN>
  * Draw a popped hypothesis.
@@ -1276,10 +1276,10 @@ static int old_popctr;		///< popctr of previously popped hypo.
 
 /** 
  * <JA>
- * 2ѥñŸͻҤ褹. 
+ * 第2パスの単語展開の様子を描画する. 
  * 
- * @param widget [in] 襦å
- * @param popctr [in] Ÿֹ
+ * @param widget [in] 描画ウィジェット
+ * @param popctr [in] 展開仮説の番号
  * </JA>
  * <EN>
  * Draw a popped word and their expanded candidates for 2nd pass replay.
@@ -1315,9 +1315,9 @@ draw_popnodes(GtkWidget *widget, int popctr)
 }
 /** 
  * <JA>
- * ľ draw_popnodes() 褷Τ񤭤ƾä. 
+ * 直前に draw_popnodes() で描画したのを上書きして消す. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Erase previous one drawn at draw_popnodes(), by overwriting.
@@ -1348,13 +1348,13 @@ draw_popnodes_old(GtkWidget *widget)
 /* GTK TopLevel draw/redraw functions */
 /* will be called for each exposure/configure event */
 /**********************************************************************/
-static boolean fitscreen = TRUE; ///< եåȥ꡼ TRUE
+static boolean fitscreen = TRUE; ///< フィットスクリーン指定時 TRUE
 
 /** 
  * <JA>
- * Хطʤ pixmap ˺
+ * キャンバスの背景を pixmap に作成する
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Make the white background to the pixmap of the given canvas widget.
@@ -1392,7 +1392,7 @@ draw_background(GtkWidget *widget)
 
 /** 
  * <JA>
- * 襭ѥɽ٤Ƥñ pixmap 褹. 
+ * 描画キャンパス内に表示すべき全ての単語情報を pixmap に描画する. 
  * 
  * @param widget 
  * </JA>
@@ -1438,9 +1438,9 @@ drawarea_draw(GtkWidget *widget)
 
 /** 
  * <JA>
- * Expose ٥ȤȯԤ. 
+ * Expose イベントを発行する. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Tell X to issue expose event on this window.
@@ -1462,13 +1462,13 @@ drawarea_expose(GtkWidget *widget)
 
 /** 
  * <JA>
- * Expose ٥Ƚ餫褵줿 pixmap ̤ɽ. 
+ * Expose イベント処理：あらかじめ描画された pixmap を画面に表示する. 
  * 
- * @param widget [in] 襦å
- * @param event [in] ٥Ⱦ
- * @param user_data [in] 桼ǡ̤ѡ
+ * @param widget [in] 描画ウィジェット
+ * @param event [in] イベント情報
+ * @param user_data [in] ユーザデータ（未使用）
  * 
- * @return gboolean ֤. 
+ * @return gboolean を返す. 
  * </JA>
  * <EN>
  * Expose event handler: show the already drawn pixmap to the screen.
@@ -1495,13 +1495,13 @@ event_drawarea_expose(GtkWidget *widget, GdkEventExpose *event, gpointer user_da
 
 /** 
  * <JA>
- * Configure ٥Ƚresize ޤ map ˺褹. 
+ * Configure イベント処理：resize または map 時に再描画する. 
  * 
- * @param widget [in] 襦å
- * @param event [in] ٥Ⱦ
- * @param user_data [in] 桼ǡ̤ѡ
+ * @param widget [in] 描画ウィジェット
+ * @param event [in] イベント情報
+ * @param user_data [in] ユーザデータ（未使用）
  * 
- * @return gboolean ֤. 
+ * @return gboolean を返す. 
  * </JA>
  * <EN>
  * Configure event handler: redraw objects when resized or mapped.
@@ -1533,10 +1533,10 @@ event_drawarea_configure(GtkWidget *widget, GdkEventExpose *event, gpointer user
 
 /** 
  * <JA>
- * [show threshold] ܥ󥯥å callback: ȥꥬ
- *  ON/ OFF. 
+ * [show threshold] ボタンクリック時の callback: トリガしきい値線の描画
+ * の ON/ OFF. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when [show threshold] button is clicked: toggle trigger
@@ -1564,9 +1564,9 @@ action_toggle_thres(GtkWidget *widget)
 #ifdef PLAYCOMMAND
 /** 
  * <JA>
- * [play] ܥ󥯥å callback: . 
+ * [play] ボタンクリック時の callback: 音声を再生する. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when [play] button is clicked: play waveform.
@@ -1605,10 +1605,10 @@ action_play_waveform(GtkWidget *widget)
 
 /** 
  * <JA>
- * [Word view] ܥ󥯥å callback: YñIDˤ. 
+ * [Word view] ボタンクリック時の callback: Y軸を単語IDにする. 
  * 
- * @param button [in] ܥ󥦥å
- * @param widget [in] 襦å
+ * @param button [in] ボタンウィジェット
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when [Word view] button is clicked: set Y axis to word ID.
@@ -1635,10 +1635,10 @@ action_view_wid(GtkWidget *button, GtkWidget *widget)
 
 /** 
  * <JA>
- * [Score view] ܥ󥯥å callback: Y򥹥ˤ. 
+ * [Score view] ボタンクリック時の callback: Y軸をスコアにする. 
  * 
- * @param button [in] ܥ󥦥å
- * @param widget [in] 襦å
+ * @param button [in] ボタンウィジェット
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when [Score view] button is clicked: set Y axis to score.
@@ -1663,11 +1663,11 @@ action_view_score(GtkWidget *button, GtkWidget *widget)
 
 /** 
  * <JA>
- * [Beam view] ܥ󥯥å callback: Yե졼ऴȤκ祹
- * κʬˤ. 
+ * [Beam view] ボタンクリック時の callback: Y軸をフレームごとの最大スコア
+ * からの差分にする. 
  * 
- * @param button [in] ܥ󥦥å
- * @param widget [in] 襦å
+ * @param button [in] ボタンウィジェット
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when [Beam view] button is clicked: set Y axis to offsets
@@ -1693,11 +1693,11 @@ action_view_beam(GtkWidget *button, GtkWidget *widget)
 
 /** 
  * <JA>
- * [Arc on/off] ܥ󥯥å callback: ñƬñ콪üδ֤
- *  on/off . 
+ * [Arc on/off] ボタンクリック時の callback: 単語先頭と単語終端の間の線の
+ * 描画を on/off する. 
  * 
- * @param button [in] ܥ󥦥å
- * @param widget [in] 襦å
+ * @param button [in] ボタンウィジェット
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when [Arc on/off] button is clicked: toggle lines between
@@ -1725,11 +1725,11 @@ action_toggle_arc(GtkWidget *button, GtkWidget *widget)
 
 /** 
  * <JA>
- * ƥȥåȤñ̾Ϥ줿Ȥcallback: ñꥹȤ
- * . 
+ * テキストウィジェットに単語名が入力されたときのcallback: 描画単語リストを
+ * 更新する. 
  * 
- * @param widget [in] ƥȥå
- * @param draw [in] 襦å
+ * @param widget [in] テキストウィジェット
+ * @param draw [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when a word string is entered on the text widget: update the
@@ -1778,10 +1778,10 @@ action_set_wid(GtkWidget *widget, GtkWidget *draw)
 
 /** 
  * <JA>
- * [x2] ܥ󥯥åcallback: X2ܤ˿ĥ. ʤFITSCREEN
- * OFFˤʤ. 
+ * [x2] ズームボタンクリック時のcallback: X軸を2倍に伸張する. なおFITSCREENは
+ * OFFになる. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when [x2] zoom button is clicked: expand X axis to "x2".
@@ -1805,10 +1805,10 @@ action_zoom(GtkWidget *widget)
 
 /** 
  * <JA>
- * [x4] ܥ󥯥åcallback: X4ܤ˿ĥ. ʤFITSCREEN
- * OFFˤʤ. 
+ * [x4] ズームボタンクリック時のcallback: X軸を4倍に伸張する. なおFITSCREENは
+ * OFFになる. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when [x4] zoom button is clicked: expand X axis to "x4".
@@ -1832,10 +1832,10 @@ action_zoom_4(GtkWidget *widget)
 
 /** 
  * <JA>
- * [x8] ܥ󥯥åcallback: X8ܤ˿ĥ. ʤFITSCREEN
- * OFFˤʤ. 
+ * [x8] ズームボタンクリック時のcallback: X軸を8倍に伸張する. なおFITSCREENは
+ * OFFになる. 
  * 
- * @param widget [in] 襦å
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback when [x8] zoom button is clicked: expand X axis to "x8".
@@ -1859,8 +1859,8 @@ action_zoom_8(GtkWidget *widget)
 
 /** 
  * <JA>
- * [Fit] ܥ󥯥åΥХåѥ򥦥ɥ
- * ưŪ˹碌褦ˤ. ¾ zoom  off ˤ. 
+ * [Fit] ボタンクリック時のコールバック：キャンパスサイズをウィンドウサイズに
+ * 自動的に合わせるようにする. 他の zoom 指定時，それらを off にする. 
  * 
  * @param widget 
  * </JA>
@@ -1884,10 +1884,10 @@ action_fit_screen(GtkWidget *widget)
 
 /** 
  * <JA>
- * 2ѥƸѤ [start] ܥcallback: 2ѥƸѤ˽. 
+ * 第2パス再現用の [start] ボタンのcallback: 第2パス再現用に準備する. 
  * 
- * @param button [in] ܥ󥦥å
- * @param widget [in] 襦å
+ * @param button [in] ボタンウィジェット
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback for [start] button for pass2 replay: prepare flag and canvas
@@ -1911,11 +1911,11 @@ action_toggle_popctr(GtkWidget *button, GtkWidget *widget)
 
 /** 
  * <JA>
- * 2ѥƸѤΥcallback: ͤ N ѹ줿Ȥˡ
- * N ܤñŸͻҤ褹. 
+ * 第2パス再現用のスケールのcallback: 値が N に変更されたときに，
+ * N 番目の単語展開の様子を描画する. 
  * 
- * @param adj [in] 㥹
- * @param widget [in] 襦å
+ * @param adj [in] アジャスタ
+ * @param widget [in] 描画ウィジェット
  * </JA>
  * <EN>
  * Callback for pop counter scale for pass2 replay: when the scale value
@@ -1945,13 +1945,13 @@ action_change_popctr(GtkAdjustment *adj, GtkWidget *widget)
 
 /** 
  * <JA>
- * GTKκ٥ȥϥɥ
+ * GTKの削除イベントハンドラ
  * 
- * @param widget [in] å
- * @param event [in] ٥
- * @param data [in] 桼ǡ
+ * @param widget [in] ウィジェット
+ * @param event [in] イベント
+ * @param data [in] ユーザデータ
  * 
- * @return FALSE֤destroy signalȯԤ뤿. 
+ * @return FALSEを常に返す（destroy signalを発行するため）. 
  * </JA>
  * <EN>
  * GTK delete event handler.
@@ -1971,10 +1971,10 @@ delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 
 /** 
  * <JA>
- * GTKνλ٥ȥϥɥ. ץꥱλ. 
+ * GTKの終了イベントハンドラ. アプリケーションを終了する. 
  * 
- * @param widget [in] å
- * @param data [in] 桼ǡ
+ * @param widget [in] ウィジェット
+ * @param data [in] ユーザデータ
  * </JA>
  * <EN>
  * GTK destroy event handler.  Quit application here.
@@ -1995,7 +1995,7 @@ destroy(GtkWidget *widget, gpointer data)
 
 /** 
  * <JA>
- * ưĻ벽ǽ. 
+ * 起動時，可視化機能を初期化する. 
  * </JA>
  * <EN>
  * Initialize visualization functions at startup.
@@ -2035,9 +2035,9 @@ visual_init(Recog *recog)
 
 /** 
  * <JA>
- * ǧ̤򸵤ˡõ֤βĻ벽¹Ԥ. 
+ * 認識結果を元に，探索空間の可視化を実行する. 
  * 
- * @param bt [in] ñȥꥹ
+ * @param bt [in] 単語トレリス
  * </JA>
  * <EN>
  * Start visualization of recognition result.
