@@ -6,7 +6,7 @@
  * </EN>
  * 
  * <JA>
- * @brief  Ƽ磻󥹥󥹤γդӳ
+ * @brief  各種インスタンスの割り付けおよび開放
  * </JA>
  * 
  * @author Akinobu Lee
@@ -29,7 +29,7 @@
  * Allocate a new MFCC calculation instance
  * </EN>
  * <JA>
- * MFCC׻󥹥󥹤򿷤˳դ. 
+ * MFCC計算インスタンスを新たに割り付ける. 
  * </JA>
  * 
  * @param amconf [in] acoustic model configuration parameters
@@ -71,6 +71,7 @@ j_mfcccalc_new(JCONF_AM *amconf)
     mfcc->cmn.update = amconf->analysis.cmn_update;
     mfcc->cmn.save_filename = amconf->analysis.cmnsave_filename;
     mfcc->cmn.map_weight = amconf->analysis.cmn_map_weight;
+    mfcc->cmn.static_cvn_only = amconf->analysis.cmn_static_cvn_only;
     mfcc->frontend.ss_alpha = amconf->frontend.ss_alpha;
     mfcc->frontend.ss_floor = amconf->frontend.ss_floor;
     mfcc->frontend.sscalc = amconf->frontend.sscalc;
@@ -86,7 +87,7 @@ j_mfcccalc_new(JCONF_AM *amconf)
  * Free an MFCC calculation instance.
  * </EN>
  * <JA>
- * MFCC׻󥹥󥹤
+ * MFCC計算インスタンスを開放する
  * </JA>
  * 
  * @param mfcc [i/o] MFCC calculation instance
@@ -116,7 +117,7 @@ j_mfcccalc_free(MFCCCalc *mfcc)
  * Allocate a new acoustic model processing instance.
  * </EN>
  * <JA>
- * ǥ׻󥹥󥹤򿷤˳դ. 
+ * 音響モデル計算インスタンスを新たに割り付ける. 
  * </JA>
  *
  * @param recog [i/o] engine instance
@@ -156,7 +157,7 @@ j_process_am_new(Recog *recog, JCONF_AM *amconf)
  * Free an acoustic model processing instance.
  * </EN>
  * <JA>
- * ǥ׻󥹥󥹤. 
+ * 音響モデル計算インスタンスを開放する. 
  * </JA>
  * 
  * @param am [i/o] AM process instance
@@ -181,7 +182,7 @@ j_process_am_free(PROCESS_AM *am)
  * Allocate a new language model processing instance.
  * </EN>
  * <JA>
- * ǥ׻󥹥󥹤򿷤˳դ. 
+ * 言語モデル計算インスタンスを新たに割り付ける. 
  * </JA>
  *
  * @param recog [i/o] engine instance
@@ -227,7 +228,7 @@ j_process_lm_new(Recog *recog, JCONF_LM *lmconf)
  * Free a language model processing instance.
  * </EN>
  * <JA>
- * ǥ׻󥹥󥹤. 
+ * 言語モデル計算インスタンスを開放する. 
  * </JA>
  * 
  * @param lm [i/o] LM process instance
@@ -242,6 +243,7 @@ j_process_lm_free(PROCESS_LM *lm)
   if (lm->ngram) ngram_info_free(lm->ngram);
   if (lm->grammars) multigram_free_all(lm->grammars);
   if (lm->dfa) dfa_info_free(lm->dfa);
+  if (lm->dfa_forward) dfa_info_free(lm->dfa_forward);
   /* not free lm->jconf  */
   free(lm);
 }
@@ -251,7 +253,7 @@ j_process_lm_free(PROCESS_LM *lm)
  * Allocate a new recognition process instance.
  * </EN>
  * <JA>
- * ǧ󥹥󥹤򿷤. 
+ * 認識処理インスタンスを新たに生成する. 
  * </JA>
  *
  * @param recog [i/o] engine instance
@@ -294,7 +296,7 @@ j_recogprocess_new(Recog *recog, JCONF_SEARCH *sconf)
  * Free a recognition process instance
  * </EN>
  * <JA>
- * ǧ󥹥󥹤. 
+ * 認識処理インスタンスを開放する. 
  * </JA>
  * 
  * @param process [i/o] recognition process instance
@@ -327,8 +329,8 @@ j_recogprocess_free(RecogProcess *process)
  * Default parameter values are set to it.
  * </EN>
  * <JA>
- * ǥ(AM)ѥ᡼¤Τ򿷤˳դ.
- * ФˤϥǥեͤǼ.
+ * 音響モデル(AM)パラメータ構造体を新たに割り付ける.
+ * 内部メンバにはデフォルト値が格納される.
  * </JA>
  * 
  * @return the newly allocated AM parameter structure
@@ -354,8 +356,8 @@ j_jconf_am_new()
  * Default parameter values are set to it.
  * </EN>
  * <JA>
- * ǥ(AM)ѥ᡼¤Τ. 
- * ФˤϥǥեͤǼ. 
+ * 音響モデル(AM)パラメータ構造体を解放する. 
+ * 内部メンバにはデフォルト値が格納される. 
  * </JA>
  * 
  * @param amconf [in] AM configuration
@@ -391,6 +393,8 @@ j_jconf_am_free(JCONF_AM *amconf)
     free(amconf->dnn.output_bfile);
   if (amconf->dnn.priorfile)
     free(amconf->dnn.priorfile);
+  if (amconf->dnn.cuda_mode)
+    free(amconf->dnn.cuda_mode);
   free(amconf);
 }
 
@@ -400,8 +404,8 @@ j_jconf_am_free(JCONF_AM *amconf)
  * Returns error if the same name already exist in the jconf.
  * </EN>
  * <JA>
- * ǥ(AM)ѥ᡼¤Τ jconf Ͽ롥
- * jconfƱ̾Υ⥸塼뤬ϿƤϥ顼Ȥʤ롥
+ * 音響モデル(AM)パラメータ構造体を jconf に登録する．
+ * jconf内に同じ名前のモジュールが既に登録されている場合はエラーとなる．
  * </JA>
  * 
  * @param jconf [i/o] global jconf
@@ -455,8 +459,8 @@ j_jconf_am_regist(Jconf *jconf, JCONF_AM *amconf, char *name)
  * Default parameter values are set to it.
  * </EN>
  * <JA>
- * ǥ (LM) ѥ᡼¤Τ򿷤˳դ
- * ФˤϥǥեͤǼ. 
+ * 言語モデル (LM) パラメータ構造体を新たに割り付ける
+ * 内部メンバにはデフォルト値が格納される. 
  * </JA>
  * 
  * @return the newly allocated LM parameter structure.
@@ -481,7 +485,7 @@ j_jconf_lm_new()
  * Release a language model (LM) parameter structure
  * </EN>
  * <JA>
- * ǥ (LM) ѥ᡼¤Τ
+ * 言語モデル (LM) パラメータ構造体を解放する
  * </JA>
  * 
  * @param lmconf [in] LM parameter structure
@@ -518,8 +522,8 @@ j_jconf_lm_free(JCONF_LM *lmconf)
  * Returns error if the same name already exist in the jconf.
  * </EN>
  * <JA>
- * ǥ(LM)ѥ᡼¤Τ jconf Ͽ롥
- * jconfƱ̾Υ⥸塼뤬ϿƤϥ顼Ȥʤ롥
+ * 言語モデル(LM)パラメータ構造体を jconf に登録する．
+ * jconf内に同じ名前のモジュールが既に登録されている場合はエラーとなる．
  * </JA>
  * 
  * @param jconf [i/o] global jconf
@@ -573,8 +577,8 @@ j_jconf_lm_regist(Jconf *jconf, JCONF_LM *lmconf, char *name)
  * Default parameter values are set to it.
  * </EN>
  * <JA>
- * õѥ᡼(SEARCH)¤Τ򿷤˳դ. 
- * ФˤϥǥեͤǼ. 
+ * 探索パラメータ(SEARCH)構造体を新たに割り付ける. 
+ * 内部メンバにはデフォルト値が格納される. 
  * </JA>
  * 
  * @return the newly allocated SEARCH parameter structure.
@@ -599,7 +603,7 @@ j_jconf_search_new()
  * Release a search (SEARCH) parameter structure
  * </EN>
  * <JA>
- * õѥ᡼(SEARCH)¤Τ
+ * 探索パラメータ(SEARCH)構造体を解放する
  * </JA>
  * 
  * @param sconf [in] SEARCH parameter structure
@@ -621,8 +625,8 @@ j_jconf_search_free(JCONF_SEARCH *sconf)
  * Returns error if the same name already exist in the jconf.
  * </EN>
  * <JA>
- * õ(SEARCH)ѥ᡼¤Τ jconf Ͽ롥
- * jconfƱ̾Υ⥸塼뤬ϿƤϥ顼Ȥʤ롥
+ * 探索(SEARCH)パラメータ構造体を jconf に登録する．
+ * jconf内に同じ名前のモジュールが既に登録されている場合はエラーとなる．
  * </JA>
  * 
  * @param jconf [i/o] global jconf
@@ -677,11 +681,11 @@ j_jconf_search_regist(Jconf *jconf, JCONF_SEARCH *sconf, char *name)
  * 
  * </EN>
  * <JA>
- * @brief  ΤΥѥ᡼¤Τ򿷤˳դ. 
+ * @brief  全体のパラメータ構造体を新たに割り付ける. 
  *
- * JCONF_AM, JCONF_LM, JCONF_SEARCH⣱ĤŤĳƤ. 
- *  -AM λޤޤʤ 3.x  jconf ɤ߹Ȥˡ
- * ΤޤѤ. 
+ * JCONF_AM, JCONF_LM, JCONF_SEARCHも１つづつ割り当てられる. 
+ * これらは -AM 等の指定を含まない 3.x 以前の jconf を読み込んだときに，
+ * そのまま用いられる. 
  * 
  * </JA>
  * 
@@ -734,9 +738,9 @@ j_jconf_new()
  * 
  * </EN>
  * <JA>
- * @brief  ΤΥѥ᡼¤Τ. 
+ * @brief  全体のパラメータ構造体を開放する. 
  *
- * JCONF_AM, JCONF_LM, JCONF_SEARCH⤹٤Ƴ. 
+ * JCONF_AM, JCONF_LM, JCONF_SEARCHもすべて開放される. 
  * 
  * </JA>
  * 
@@ -786,7 +790,7 @@ j_jconf_free(Jconf *jconf)
  * Allocate memory for a new engine instance.
  * </EN>
  * <JA>
- * 󥸥󥤥󥹥󥹤򿷤˥դ. 
+ * エンジンインスタンスを新たにメモリ割り付けする. 
  * </JA>
  * 
  * @return the newly allocated engine instance.
@@ -838,9 +842,9 @@ j_recog_new()
  * All allocated memories in the instance will be also released.
  * </EN>
  * <JA>
- * @brief  󥸥󥤥󥹥󥹤
+ * @brief  エンジンインスタンスを開放する
  *
- * 󥹥ǤޤǤ˥Ȥ줿ƤΥⳫ. 
+ * インスタンス内でこれまでにアロケートされた全てのメモリも開放される. 
  * </JA>
  * 
  * @param recog [in] engine instance.
