@@ -2,10 +2,10 @@
  * @file   m_chkparam.c
  * 
  * <JA>
- * @brief  ѥ᡼θ.
+ * @brief  パラメータ設定の後処理.
  *
- * jconf ե뤪ӥޥɥץˤäͿ줿
- * ѥ᡼ˤĤƸԤǽŪǧǻѤͤꤹ. 
+ * jconf ファイルおよびコマンドオプションによって与えられた
+ * パラメータについて後処理を行い，最終的に認識処理で使用する値を確定する. 
  * </JA>
  * 
  * <EN>
@@ -34,9 +34,9 @@
 
 /** 
  * <JA>
- * ե뤬¸ߤɤ߹߲ǽå. 
+ * ファイルが存在して読み込み可能かチェックする. 
  * 
- * @param filename [in] եѥ̾
+ * @param filename [in] ファイルパス名
  * </JA>
  * <EN>
  * Check if a file actually exist and is readable.
@@ -57,16 +57,16 @@ checkpath(char *filename)
 
 /** 
  * <JA>
- * @brief  jconfѥ᡼ǽŪ˷ꤹ
+ * @brief  jconf設定パラメータを最終的に決定する
  *
- * δؿϡjconf ե䥳ޥɥץˤäͿ줿
- * jconf Υѥ᡼ˤĤԤ. ŪˤϡͤϰϤΥ
- * 䡤Υå꤫黻ФƼѥ᡼η׻
- * ǥФͭʤɤå. 
+ * この関数は，jconf ファイルやコマンドオプションによって与えられた
+ * jconf 内のパラメータについて精査を行う. 具体的には，値の範囲のチェッ
+ * クや，競合のチェック，設定から算出される各種パラメータの計算，使用
+ * するモデルに対する指定の有効性などをチェックする. 
  *
- * δؿϡץꥱˤä jconf γͤλ꤬λľ塤
- * 󥸥󥤥󥹥󥹤κǥΥɤԤ˸ƤӽФ
- * ٤Ǥ. 
+ * この関数は，アプリケーションによって jconf の各値の指定が終了した直後，
+ * エンジンインスタンスの作成やモデルのロードが行われる前に呼び出される
+ * べきである. 
  * 
  * </JA>
  * <EN>
@@ -233,14 +233,30 @@ j_jconf_finalize(Jconf *jconf)
   }
 
   /* check for cmn */
-  if (jconf->decodeopt.realtime_flag) {
-    for(am = jconf->am_root; am; am = am->next) {
-      if (am->analysis.cmn_update == FALSE && am->analysis.cmnload_filename == NULL) {
-	jlog("ERROR: m_chkparam: when \"-cmnnoupdate\", initial cepstral normalisation data should be given by \"-cmnload\"\n");
-	ok_p = FALSE;
+  for(am = jconf->am_root; am; am = am->next) {
+    if (am->analysis.map_cmn == FALSE && am->analysis.cmnload_filename == NULL) {
+      /* cmnstatic, no cmnload : error */
+      jlog("ERROR: m_chkparam: with \"-cmnstatic\", the static cepstral mean (and variance) should be given by \"-cmnload\"\n");
+      ok_p = FALSE;
+    }
+    if (am->analysis.cmn_static_cvn_only == TRUE && am->analysis.cmnload_filename == NULL) {
+      /* cvnstatic, no cmnload : error */
+      jlog("ERROR: m_chkparam: with \"-cvnstatic\", the static cepstral variance (and mean) should be given by \"-cmnload\"\n");
+      ok_p = FALSE;
+    }
+    if (jconf->decodeopt.realtime_flag == FALSE) {
+      if (am->analysis.map_cmn == TRUE && am->analysis.cmnload_filename != NULL) {
+	/* no cmnstatic, cmnload on buffered input : assume cmnstatic */
+	jlog("WARNING: m_chkparam: \"-cmnstatic\" was automatically enabled because you have specified \"-cmnload\" at buffered input.  To avoid confusion in the future release, please explicitly set \"-cmnstatic\" for static CMN.\n");
       }
-      if (am->analysis.map_cmn == FALSE && am->analysis.cmnload_filename == NULL) {
-	jlog("ERROR: m_chkparam: with \"-cmnstatic\", the static cepstral mean (and variance) should be given by \"-cmnload\"\n");
+      if (am->analysis.map_cmn == TRUE && am->analysis.cmn_update == FALSE) {
+	/* cmnnoupdate on buffered input : no operation */
+	jlog("WARNING: m_chkparam: CMN updates will not occur on buffered input, \"-cmnnoupdate\" is ignored\n");
+      }
+    } else {
+      if (am->analysis.map_cmn == TRUE && am->analysis.cmn_update == FALSE && am->analysis.cmnload_filename == NULL) {
+	/* cmnnoupdate without cmnload on stream input : error */
+	jlog("ERROR: m_chkparam: when \"-cmnnoupdate\", initial cepstral normalisation data should be given by \"-cmnload\"\n");
 	ok_p = FALSE;
       }
     }
@@ -330,6 +346,30 @@ j_jconf_finalize(Jconf *jconf)
     }
   }
 
+#ifdef HAVE_LIBFVAD
+  /* check parameter to be passed to libfvad */
+  if (jconf->detect.fvad_mode < -1) jconf->detect.fvad_mode = -1;
+  if (jconf->detect.fvad_mode > 3) {
+    jlog("WARNING: m_chkparam: invalud value for \"-fvad\": %d\n", jconf->detect.fvad_mode);
+    jlog("WARNING: m_chkparam: maximum aggressiveness is 3, use 3 now\n");
+    jconf->detect.fvad_mode = 3;
+  }
+  if (jconf->detect.fvad_smoothnum < 1) {
+    jlog("WARNING: m_chkparam: invalud value for 1st arg of \"-fvad_param\": %d\n", jconf->detect.fvad_smoothnum);
+    jlog("WARNING: m_chkparam: num should be >= 1, use 1 now\n");
+    jconf->detect.fvad_smoothnum = 1;
+  }
+  if (jconf->detect.fvad_thres < 0.0) {
+    jlog("WARNING: m_chkparam: invalud value for 2nd arg of \"-fvad_param\": %f\n", jconf->detect.fvad_thres);
+    jlog("WARNING: m_chkparam: thres should be >= 0.0, use 0.0 now\n");
+    jconf->detect.fvad_thres = 0.0;
+  }
+  if (jconf->detect.fvad_thres > 1.0) {
+    jlog("WARNING: m_chkparam: invalud value for 2nd arg of \"-fvad_param\": %f\n", jconf->detect.fvad_thres);
+    jlog("WARNING: m_chkparam: thres should be <= 1.0, use 1.0 now\n");
+    jconf->detect.fvad_thres = 1.0;
+  }
+#endif /* HAVE_LIBFVAD */
 
 
   if (!ok_p) {
@@ -347,14 +387,14 @@ j_jconf_finalize(Jconf *jconf)
 
 /** 
  * <JA>
- * @brief  餫줿1ѥΥǥեȥӡ֤. 
+ * @brief  あらかじめ定められた第1パスのデフォルトビーム幅を返す. 
  *
- * ǥեȤΥӡϡǧ󥸥Υѥ
- * Ѥ벻ǥ˽ä򤵤. ͤϡ20k 
- * IPA ɾåȤ줿Ŭ͡٤ݤĤĺ®٤͡
- * Ǥ. 
+ * デフォルトのビーム幅は，認識エンジンのコンパイル時設定や
+ * 使用する音響モデルに従って選択される. これらの値は，20k の
+ * IPA 評価セットで得られた最適値（精度を保ちつつ最大速度が得られる値）
+ * である. 
  * 
- * @return ¹Իξˤä򤵤줿ӡ
+ * @return 実行時の条件によって選択されたビーム幅
  * </JA>
  * <EN>
  * @brief  Returns the pre-defined default beam width on 1st pass of
@@ -412,17 +452,17 @@ default_width(HTK_HMM_INFO *hmminfo)
 
 /** 
  * <JA>
- * @brief  1ѥΥӡꤹ. 
+ * @brief  第1パスのビーム幅を決定する. 
  *
- * 桼 "-b" ץǥӡꤷʤäϡ
- * ΤӡȤƺѤ. 
- *   - default_width() 
- *   - sqrt(ÿ) * 15
+ * ユーザが "-b" オプションでビーム幅を指定しなかった場合は，
+ * 下記のうち小さい方がビーム幅として採用される. 
+ *   - default_width() の値
+ *   - sqrt(語彙数) * 15
  * 
- * @param wchmm [in] ڹ¤
- * @param specified [in] 桼ӡ(0: õ -1: ̤)
+ * @param wchmm [in] 木構造化辞書
+ * @param specified [in] ユーザ指定ビーム幅(0: 全探索 -1: 未指定)
  * 
- * @return Ѥ줿ӡ. 
+ * @return 採用されたビーム幅. 
  * </JA>
  * <EN>
  * @brief  Determine beam width on the 1st pass.
