@@ -2,10 +2,10 @@
  * @file   m_fusion.c
  * 
  * <JA>
- * @brief  ǧκǽ򤹤. 
+ * @brief  認識の最終準備をする. 
  *
- * ˽ǥɤ߹ߡڹ¤ʤɤΥǡ¤ιۡ
- * ꥢγݤʤɡǧϤɬפʴĶιۤԤʤ. 
+ * 設定に従い，モデルの読み込み・木構造化辞書などのデータ構造の構築・
+ * ワークエリアの確保など，認識開始に必要な環境の構築を行なう. 
  * </JA>
  * 
  * <EN>
@@ -34,16 +34,16 @@
 
 /** 
  * <JA>
- * @brief  HMMե뤫ɤ߹ߡǧѤ˥åȥåפ. 
+ * @brief  音響HMMをファイルから読み込み，認識用にセットアップする. 
  *
- * ե뤫HMMɤ߹ߡHMMList եɤ߹ߡ
- * ѥ᡼Υåޥѥ on/off, ݡǥʤ
- * Ԥ졤ǧΤνԤ. 
+ * ファイルからのHMM定義の読み込み，HMMList ファイルの読み込み，
+ * パラメータ型のチェック，マルチパス扱いの on/off, ポーズモデルの設定など
+ * が行われ，認識のための準備が行われる. 
  *
- * βǥϤȤʤ벻ѥ᡼μѥ᡼⤳
- * ǽꤵ. ˤϡHMMΥإåʥХʥHMMξ硤¸
- * ߤС˥ХʥHMMޤ줿ħ̾jconf ʤФ
- * ˡ뤤 -htkconf ѻˤʤɤξѤ. 
+ * この音響モデルの入力となる音響パラメータの種類やパラメータもここで
+ * 最終決定される. 決定には，音響HMMのヘッダ，（バイナリHMMの場合，存
+ * 在すれば）バイナリHMMに埋め込まれた特徴量情報，jconf の設定（ばらば
+ * らに，あるいは -htkconf 使用時）などの情報が用いられる. 
  * </JA>
  * <EN>
  * @brief  Read in an acoustic HMM from file and setup for recognition.
@@ -89,17 +89,6 @@ initialize_HMM(JCONF_AM *amconf, Jconf *jconf)
     hmminfo_free(hmminfo);
     return NULL;
   }
-  if (debug2_flag) {
-    HTK_HMM_Data *dtmp;
-    int i;
-    for (dtmp = hmminfo->start; dtmp; dtmp = dtmp->next) {
-      printf("***\nname: %s\n", dtmp->name);
-      for (i=0;i<dtmp->state_num;i++) {
-	if (dtmp->s[i] == NULL) continue;
-	printf("state %d: id=%d   %s\n", i + 1, dtmp->s[i]->id, (dtmp->s[i]->name) ? dtmp->s[i]->name : "");
-      }
-    }
-  }
 
   /* set multipath mode flag */
   if (amconf->force_multipath) {
@@ -179,7 +168,7 @@ initialize_HMM(JCONF_AM *amconf, Jconf *jconf)
 
 /** 
  * <JA>
- * Gaussian Mixture Selection ΤξѥΥեHMMɤ߹. 
+ * Gaussian Mixture Selection のための状態選択用モノフォンHMMを読み込む. 
  * </JA>
  * <EN>
  * Initialize context-independent HMM for state selection with Gaussian
@@ -208,7 +197,7 @@ initialize_GSHMM(JCONF_AM *amconf)
 
 /** 
  * <JA>
- * ȯøڡѤ1 GMM ɤ߹ǽ. 
+ * 発話検証・棄却用の1状態 GMM を読み込んで初期化する. 
  * 
  * </JA>
  * <EN>
@@ -283,14 +272,14 @@ initialize_GMM(Jconf *jconf)
 
 /** 
  * <JA>
- * @brief  ñ켭ե뤫ɤ߹ǥåȥåפ. 
+ * @brief  単語辞書をファイルから読み込んでセットアップする. 
  *
- * ΥΥեɽȥ饤եؤη׻ init_voca() 
- * ɤ߹߻˹Ԥ. Τᡤɤ߹߻ˤϡǧǻѤ
- * ͽHMMͿɬפ. 
+ * 辞書上のモノフォン表記からトライフォンへの計算は init_voca() で
+ * 読み込み時に行われる. このため，辞書読み込み時には，認識で使用する
+ * 予定のHMM情報を与える必要がある. 
  *
- * N-gram ѻϡʸƬ̵ñ줪ʸ̵ñ򤳤ꤹ. 
- * ޤ"-iwspword" ϡݡñ򼭽κǸ. 
+ * N-gram 使用時は，文頭無音単語およぶ文末無音単語をここで設定する. 
+ * また，"-iwspword" 指定時は，ポーズ単語を辞書の最後に挿入する. 
  * 
  * </JA>
  * <EN>
@@ -421,14 +410,14 @@ initialize_dict(JCONF_LM *lmconf, HTK_HMM_INFO *hmminfo)
 
 /** 
  * <JA>
- * @brief  ñN-gramե뤫ɤ߹ǥåȥåפ. 
+ * @brief  単語N-gramをファイルから読み込んでセットアップする. 
  *
- * ARPA եޥåȤǻϡLRե RL եȹ礻
- * ưۤʤ. LR Τߡ뤤 RL Τ߻ϡ򤽤Τޤɤ߹. 
- * ȤꤵƤϡRLޤǥȤɤ߹塤
- * LR  2-gram 1ѥѤ˼ǥɲɤ߹ߤ. 
+ * ARPA フォーマットで指定時は，LRファイルと RL ファイルの組合せで
+ * 動作が異なる. LR のみ，あるいは RL のみ指定時は，それをそのまま読み込む. 
+ * 双方とも指定されている場合は，RLをまず主モデルとして読み込んだ後，
+ * LR の 2-gram だけを第1パス用に主モデルに追加読み込みする. 
  *
- * ޤɤ߹߽λ塤N-gramȥȤΥޥå󥰤. 
+ * また，読み込み終了後，辞書上のN-gramエントリとのマッチングを取る. 
  * 
  * </JA>
  * <EN>
@@ -518,12 +507,12 @@ initialize_ngram(JCONF_LM *lmconf, WORD_INFO *winfo)
  * </EN>
  *
  * <JA>
- * @brief ǥɤ߹ࡥ
+ * @brief 音響モデルを読み込む．
  *
- * δؿϡͿ줿 AM ˽ä AM 󥹥󥹤
- * ˲ǥɤޤθ塤AM󥹥󥹤
- * ˥󥸥󥤥󥹥󥹤ϿޤAMϤδؿ
- * Ƥˤ餫recog->jconfϿƤɬפޤ
+ * この関数は，与えられた AM 設定に従って AM 処理インスタンスを生成し，
+ * その中に音響モデルをロードします．その後，そのAM処理インスタンスは
+ * 新たにエンジンインスタンスに登録されます．AM設定はこの関数を
+ * 呼ぶ前にあらかじめ全体設定recog->jconfに登録されている必要があります．
  * 
  * </JA>
  * 
@@ -581,7 +570,10 @@ j_load_am(Recog *recog, JCONF_AM *amconf)
 		  amconf->dnn.output_bfile,
 		  amconf->dnn.priorfile,
 		  amconf->dnn.prior_factor,
-		  amconf->dnn.batchsize) == FALSE) {
+		  amconf->dnn.prior_factor_log10nize,
+		  amconf->dnn.batchsize,
+		  amconf->dnn.num_threads,
+      amconf->dnn.cuda_mode) == FALSE) {
       jlog("ERROR: m_fusion: failed to initialize DNN\n");
       dnn_free(am->dnn);
       am->dnn = NULL;
@@ -633,16 +625,16 @@ j_load_am(Recog *recog, JCONF_AM *amconf)
  * </EN>
  *
  * <JA>
- * @brief ǥɤ߹ࡥ
+ * @brief 言語モデルを読み込む．
  *
- * δؿϡͿ줿 LM ˽ä LM 󥹥󥹤
- * ˸ǥɤޤθ塤LM󥹥󥹤
- * ˥󥸥󥤥󥹥󥹤ϿޤLMϤδؿ
- * Ƥˤ餫recog->jconfϿƤɬפޤ
+ * この関数は，与えられた LM 設定に従って LM 処理インスタンスを生成し，
+ * その中に言語モデルをロードします．その後，そのLM処理インスタンスは
+ * 新たにエンジンインスタンスに登録されます．LM設定はこの関数を
+ * 呼ぶ前にあらかじめ全体設定recog->jconfに登録されている必要があります．
  *
- * ɤ߹߻˥ȥ饤եؤѴӲǥȤΥ󥯤
- * Ʊ˹ԤޤΤᡤθǥ뤬Ѥ벻ǥ
- * 󥹥󥹤 am Ȥƻꤹɬפޤ
+ * 辞書の読み込み時にトライフォンへの変換および音響モデルとのリンクが
+ * 同時に行われます．このため，この言語モデルが使用する音響モデルの
+ * インスタンスを引数 am として指定する必要があります．
  * 
  * </JA>
  * 
@@ -728,12 +720,12 @@ j_load_lm(Recog *recog, JCONF_LM *lmconf)
 /**********************************************************************/
 /** 
  * <JA>
- * @brief  ƤΥǥɤ߹ߡǧνԤʤ. 
+ * @brief  全てのモデルを読み込み，認識の準備を行なう. 
  *
- * δؿǤϡjconf ˤʣΡ AM ѥ᡼¤ΤLM 
- * ѥ᡼¤ΤΤ줾ФơAM/LM󥹥󥹤
- * . Ƥ줾Υ󥹥󥹤ˤĤƤ˥ǥɤ߹ߡ
- * ǧѤ˥åȥåפ. GMM⤳ɤ߹ޤ. 
+ * この関数では，jconf 内にある（複数の） AM 設定パラメータ構造体やLM 
+ * 設定パラメータ構造体のそれぞれに対して，AM/LM処理インスタンスを生成
+ * する. そしてそれぞれのインスタンスについてその中にモデルを読み込み，
+ * 認識用にセットアップする. GMMもここで読み込まれる. 
  * 
  * </JA>
  * <EN>
@@ -861,8 +853,8 @@ j_load_all(Recog *recog, Jconf *jconf)
  * configuration and a MFCC instance.
  * </EN>
  * <JA>
- * AMѥ᡼ȴ˺줿MFCC׻󥹥󥹴֤ǡѥ᡼Ф
- * ꤬ƱǤ뤫ɤå. 
+ * AM設定パラメータと既に作られたMFCC計算インスタンス間で，パラメータ抽出の
+ * 設定が同一であるかどうかをチェックする. 
  * 
  * </JA>
  * 
@@ -888,6 +880,7 @@ mfcc_config_is_same(JCONF_AM *amconf, MFCCCalc *mfcc)
       if (s1 == s2 || (s1 && s2 && strmatch(s1, s2))) {
 	if (amconf->analysis.cmn_update == mfcc->cmn.update
 	    && amconf->analysis.map_cmn == mfcc->cmn.map_cmn
+	    && amconf->analysis.cmn_static_cvn_only == mfcc->cmn.static_cvn_only
 	    && amconf->analysis.cmn_map_weight == mfcc->cmn.map_weight) {
 	  if (amconf->frontend.ss_alpha == mfcc->frontend.ss_alpha
 	      && amconf->frontend.ss_floor == mfcc->frontend.ss_floor
@@ -924,10 +917,10 @@ mfcc_config_is_same(JCONF_AM *amconf, MFCCCalc *mfcc)
  * </EN>
  * <JA>
  *
- * @brief  ƤAM󥹥󥹤GMMѤˡMFCC׻󥹥󥹤. 
+ * @brief  全てのAM処理インスタンスおよびGMM用に，MFCC計算インスタンスを生成する. 
  *
- * İʾAM󥹥󥹡ʤGMMˤƱħ̷׻
- * ľ硤Υ󥹥󥹤ϤҤȤĤ MFCC ׻󥹥󥹤ͭ. 
+ * ２つ以上のAM処理インスタンス（およびGMM）が同一の特徴量計算条件を持
+ * つ場合，それらのインスタンスはひとつの MFCC 計算インスタンスを共有する. 
  * 
  * </JA>
  * 
@@ -1012,12 +1005,12 @@ create_mfcc_calc_instances(Recog *recog)
  * </EN>
  *
  * <JA>
- * @brief ǧ󥹥󥹤Ω夲롥
+ * @brief 認識処理インスタンスを立ち上げる．
  *
- * δؿϡͿ줿 SEARCH ˽ä ǧ󥹥󥹤
- * б벻ǧۤޤθ塤줿ǧ󥹥󥹤
- * ˥󥸥󥤥󥹥󥹤ϿޤSEARCHϤδؿ
- * Ƥˤ餫jconfϿƤɬפޤ
+ * この関数は，与えられた SEARCH 設定に従って 認識処理インスタンスを生成し，
+ * 対応する音声認識器を構築します．その後，その生成された認識処理インスタンスは
+ * 新たにエンジンインスタンスに登録されます．SEARCH設定はこの関数を
+ * 呼ぶ前にあらかじめ全体設定jconfに登録されている必要があります．
  * 
  * </JA>
  * 
@@ -1215,7 +1208,7 @@ j_launch_recognition_instance(Recog *recog, JCONF_SEARCH *sconf)
       }
     }
 
-    /* ư -check ǥå⡼ɤ */
+    /* 起動時 -check でチェックモードへ */
     if (p->config->sw.wchmm_check_flag) {
       wchmm_check_interactive(p->wchmm);
     }
@@ -1278,24 +1271,24 @@ j_launch_recognition_instance(Recog *recog, JCONF_SEARCH *sconf)
 
  * </EN>
  * <JA>
- * @brief  ƤΥɤ줿ǥ꤫饨󥸥󥤥󥹥󥹤
- * ǽ. 
+ * @brief  全てのロードされたモデルと設定からエンジンインスタンスを
+ * 最終構成する. 
  *
- * δؿϡǧΤκǽԤ. Ǥϡ
+ * この関数は，認識準備のための最終処理を行う. 内部では，
  *
- *  - ɬפ MFCC ׻󥹥󥹤
- *  - ꤵ줿 LM/AM Ȥǧ󥹥
- *  - ǥ˰¸ǧѥѥ᡼
- *  - 1ѥѤڹ¤ǧ󥹥󥹤Ȥ˹
- *  - ǧѥꥢȥå奨ꥢ
- *  - եȥɽΤΤĤͤȥꥢγ
+ *  - 必要な MFCC 計算インスタンスの生成
+ *  - 指定された LM/AM の組からの認識処理インスタンス生成
+ *  - モデルに依存する認識用パラメータの設定
+ *  - 第1パス用の木構造化辞書を認識処理インスタンスごとに構築
+ *  - 認識処理用ワークエリアとキャッシュエリアを確保
+ *  - フロントエンド処理のためのいくつかの値とワークエリアの確保
  *
- *  Ԥ. δؿλ塤󥸥󥤥󥹥ƤΥåȥå
- *  ϽλǧϤǤ֤Ȥʤ. 
+ *  を行う. この関数が終了後，エンジンインスタンス内の全てのセットアップ
+ *  は終了し，認識が開始できる状態となる. 
  *
- *  δؿϡj_jconf_finalize()  j_load_all() ä֤
- *  ƤӽФɬפ. ƽФˤϡrecog->jconf  (j_load_all ǤȤ
- *  Ѥ) jconf ǼƤ. 
+ *  この関数は，j_jconf_finalize() と j_load_all() が終わった状態で
+ *  呼び出す必要がある. 呼出し前には，recog->jconf に (j_load_all でともに
+ *  使用した) jconf を格納しておくこと. 
  * 
  * </JA>
  * 
@@ -1443,6 +1436,7 @@ j_final_fusion(Recog *recog)
 	      jlog("ERROR: m_fusion: failed to read initial cepstral mean from \"%s\"\n", mfcc->cmn.load_filename);
 	      return FALSE;
 	    }
+	    mfcc->cmn.wrk->static_cvn_only = mfcc->cmn.static_cvn_only;
 	  } else {
 	    jlog("WARNING: m_fusion: CMN load file specified but AM not require it, ignored\n");
 	  }
