@@ -2,7 +2,7 @@
  * @file   m_info.c
  * 
  * <JA>
- * @brief  ƥν
+ * @brief  システム情報の出力
  * </JA>
  * 
  * <EN>
@@ -29,7 +29,7 @@
  * Output module overview in a global configuration variables to log.
  * </EN>
  * <JA>
- * ѥ᡼Υ⥸塼빽γפ˽Ϥ. 
+ * 全体設定パラメータ内のモジュール構成の概要をログに出力する. 
  * </JA>
  * 
  * @param jconf [in] global configuration variables
@@ -188,7 +188,7 @@ print_mfcc_info(FILE *fp, MFCCCalc *mfcc, Jconf *jconf)
 	jlog("   beginning data weight = %6.2f\n", mfcc->cmn.map_weight);
       }
     } else {
-      if (mfcc->cmn.loaded) {
+      if (mfcc->cmn.loaded && mfcc->cmn.static_cvn_only == FALSE) {
 	jlog("with a static mean\n");
 	jlog("   static mean from file = %s\n", mfcc->cmn.load_filename);
       } else {
@@ -245,7 +245,7 @@ print_mfcc_info(FILE *fp, MFCCCalc *mfcc, Jconf *jconf)
 
 /** 
  * <JA>
- * 󥸥󥤥󥹥󥹤˽Ϥ. 
+ * エンジンインスタンスの全情報をログに出力する. 
  * </JA>
  * <EN>
  * Output all informations of an engine instance to log.
@@ -407,7 +407,13 @@ print_engine_info(Recog *recog)
       jlog("      # of hidden layers = %d\n", am->dnn->hnum);
       jlog("       hidden layer dim. = %d\n", am->dnn->hiddennodenum);
       jlog("      state prior factor = %f\n", am->dnn->prior_factor);
+      if (am->config->dnn.prior_factor_log10nize) {
+	jlog("   state prior log10nize = on\n");
+      } else {
+	jlog("   state prior log10nize = off\n");
+      }
       jlog("              batch size = %d\n", am->dnn->batch_size);
+      jlog("       number of threads = %d\n", am->dnn->num_threads);
     }
     jlog("\n");
   }
@@ -447,6 +453,10 @@ print_engine_info(Recog *recog)
 	    print_dfa_cp(fp, lm->dfa);
 	    jlog("\n");
 	  }
+	  if (lm->dfa_forward) {
+	    jlog(" additional forward");
+	    print_dfa_info(fp, lm->dfa_forward); jlog("\n");
+	  }
 	}
       } else if (lm->lmvar == LM_DFA_WORD) {
 	jlog(" type=word\n\n");
@@ -946,6 +956,15 @@ print_engine_info(Recog *recog)
       jlog("\t             head margin = %d msec.\n", jconf->detect.head_margin_msec);
       jlog("\t             tail margin = %d msec.\n", jconf->detect.tail_margin_msec);
       jlog("\t              chunk size = %d samples\n", jconf->detect.chunk_size);
+#ifdef HAVE_LIBFVAD
+      if (jconf->detect.fvad_mode < 0) {
+	jlog("\t       FVAD switch value = %d (disabled)\n", jconf->detect.fvad_mode);
+      } else {
+	jlog("\t       FVAD switch value = %d (0: moderate - 3: very aggressive to regist to noise\n", jconf->detect.fvad_mode);
+	jlog("\t    FVAD param smoothlen = %d (%dms)\n", jconf->detect.fvad_smoothnum, jconf->detect.fvad_smoothnum * 10);
+	jlog("\t    FVAD param threshold = %.2f\n", jconf->detect.fvad_thres);
+      }
+#endif /* HAVE_LIBFVAD */
     } else {
       jlog("\t         silence cutting = off\n");
     }
