@@ -2,19 +2,19 @@
  * @file   m_jconf.c
  * 
  * <JA>
- * @brief  եɤ߹. 
+ * @brief  設定ファイルの読み込み. 
  *
- * ץ򵭽Ҥ jconf եɤ߹ߤޤ. 
- * jconf եǤϡ֥륯ơˤʸ
- * ꡤХååˤʸΥפǤޤ. 
- * ޤƹԤˤ '#' ʹߤϥåפޤ. 
+ * オプション指定を記述した jconf 設定ファイルを読み込みます. 
+ * jconf 設定ファイル内では，ダブルクォーテーションによる文字列の
+ * 指定，バックスラッシュによる文字のエスケープができます. 
+ * また，各行において '#' 以降はスキップされます. 
  *
- * jconf եǤϡƤХѥϡץꥱ
- * ȥǥ쥯ȥǤϤʤ jconf ¸ߤǥ쥯ȥ꤫
- * ХѥȤƲᤵޤ. 
+ * jconf 設定ファイル内では，全ての相対パスは，アプリケーションの
+ * カレントディレクトリではなく，その jconf の存在するディレクトリからの
+ * 相対パスとして解釈されます. 
  *
- * ޤ$HOME, ${HOME}, $(HOME), ηǻꤵ줿ʬˤĤ
- * ĶѿŸǤޤ. 
+ * また，$HOME, ${HOME}, $(HOME), の形で指定された部分について
+ * 環境変数を展開できます. 
  * 
  * </JA>
  * 
@@ -58,16 +58,16 @@
 
 /** 
  * <JA>
- * @brief  jconf Ѥιɤ߹ߥ롼
+ * @brief  jconf 用の行読み込みルーチン
  *
- * Хååˤ륨׽ Mac/Win βԥɤ
- * б. Ԥϥåפ졤ԥɤϾä. 
+ * バックスラッシュによるエスケープ処理，および Mac/Win の改行コードに
+ * 対応する. 空行はスキップされ，改行コードは消される. 
  * 
- * @param buf [out] ɤ߹1ʬΥƥȤǼХåե
- * @param size [in] @a buf 礭ʥХȿ
- * @param fp [in] եݥ
+ * @param buf [out] 読み込んだ1行分のテキストを格納するバッファ
+ * @param size [in] @a buf の大きさ（バイト数）
+ * @param fp [in] ファイルポインタ
  * 
- * @return @a buf ֤. EOF ǤʾϤʤ NULL ֤. 
+ * @return @a buf を返す. EOF でこれ以上入力がなければ NULL を返す. 
  * </JA>
  * <EN>
  * @brief  line reading function for jconf file.
@@ -137,11 +137,11 @@ fgets_jconf(char *buf, int size, FILE *fp)
 
 /** 
  * <JA>
- * @brief  եΥѥ̾ǥ쥯ȥ̾ȴФ. 
+ * @brief  ファイルのパス名からディレクトリ名を抜き出す. 
  *
- * Ǹ '/' ϻĤ. 
+ * 最後の '/' は残される. 
  * 
- * @param path [i/o] եΥѥ̾ʴؿѹ
+ * @param path [i/o] ファイルのパス名（関数内で変更される）
  * </JA>
  * <EN>
  * @brief  Get directory name from a path name of a file.
@@ -172,19 +172,19 @@ get_dirname(char *path)
 
 /** 
  * <JA>
- * @brief  ĶѿŸ
+ * @brief  環境変数の展開
  * 
- * ĶѿŸ. $HOME ηʸĶѿȤߤʤͤ
- * ִ. ִäݤˤϡͿ줿ʸХåե
- * 餿˳դ줿Хåե֤. 
+ * 環境変数を展開する. $HOME の形の文字列を環境変数とみなし，その値で
+ * 置換する. 置換が起こった際には，与えられた文字列バッファを内部で
+ * 解放し，あらたに割り付けられたバッファを返す. 
  *
- * ѿλ $HOME, ${HOME}, $(HOME), ηǻǤ. 
- * $ ŸʤϥХåå "\" ǥפǤ. 
- * ޤ󥰥륯 "'" ǳ줿ϰϤŸԤʤ. 
+ * 変数の指定は $HOME, ${HOME}, $(HOME), の形で指定できる. 
+ * $ を展開したくない場合はバックスラッシュ "\" でエスケープできる. 
+ * またシングルクォート "'" で括られた範囲は展開を行わない. 
  * 
- * @param str [in] оʸŸȯ free Τա
+ * @param str [in] 対象文字列（展開発生時は内部で free されるので注意）
  * 
- * @return Ÿ٤оݤʤä硤str Τޤ֤. ŸԤ줿硤餿˳դ줿ŸʸޤХåե֤. 
+ * @return 展開すべき対象がなかった場合，str がそのまま返される. 展開が行われた場合，あらたに割り付けられた展開後の文字列を含むバッファが返される. 
  * </JA>
  * <EN>
  * @brief  Envronment valuable expansion for a string
@@ -360,12 +360,12 @@ expand_env(char *str)
 /* read-in and parse jconf file and process those using m_options */
 /** 
  * <JA>
- * @brief  ץʸʬ򤷤ɲóǼ.
+ * @brief  オプション文字列を分解して追加格納する.
  *
- * @param buf [in] ʸ
- * @param argv [i/o] ץؤΥݥ
- * @param argc [i/o] ץοؤΥݥ
- * @param maxnum [i/o] ץγպ
+ * @param buf [in] 文字列
+ * @param argv [i/o] オプション列へのポインタ
+ * @param argc [i/o] オプション列の数へのポインタ
+ * @param maxnum [i/o] オプション列の割付最大数
  * </JA>
  * <EN>
  * @brief  Divide option string into option arguments and append to array.
@@ -436,11 +436,11 @@ add_to_arglist(char *buf, char ***argv_ret, int *argc_ret, int *maxnum_ret)
 
 /** 
  * <JA>
- * ץޤʸϤͤ򥻥åȤ.
- * Хѥ̾ϥȤФȤư.
+ * オプション指定を含む文字列を解析して値をセットする.
+ * 相対パス名はカレントからの相対として扱われる.
  * 
- * @param str [in] ץޤʸ
- * @param jconf [out] ͤ򥻥åȤ jconf ǡ
+ * @param str [in] オプション指定を含む文字列
+ * @param jconf [out] 値をセットする jconf 設定データ
  * </JA>
  * <EN>
  * Parse a string and set the specified option values.
@@ -454,7 +454,14 @@ add_to_arglist(char *buf, char ***argv_ret, int *argc_ret, int *maxnum_ret)
  * @callergraph
  */
 boolean
-config_string_parse(char *str, Jconf *jconf)
+config_string_parse(char *str, Jconf *jconf) {
+  /* relative paths in string are relative to current */
+  return(config_string_parse_basedir(str, jconf, NULL));
+}
+
+/* config_string_parse with base dir */
+boolean
+config_string_parse_basedir(char *str, Jconf *jconf, char *dir)
 {
   int c_argc;
   char **c_argv;
@@ -475,8 +482,7 @@ config_string_parse(char *str, Jconf *jconf)
     c_argv[i] = expand_env(c_argv[i]);
   }
   /* now that options are in c_argv[][], call opt_parse() to process them */
-  /* relative paths in string are relative to current */
-  ret = opt_parse(c_argc, c_argv, NULL, jconf);
+  ret = opt_parse(c_argc, c_argv, dir, jconf);
 
   /* free arguments */
   while (c_argc-- > 0) {
@@ -489,11 +495,11 @@ config_string_parse(char *str, Jconf *jconf)
 
 /** 
  * <JA>
- * jconf եɤ߹ǲϤб륪ץꤹ.
- * ץХѥϡ jconf ե뤫ФȤʤ.
+ * jconf 設定ファイルを読み込んで解析し，対応するオプションを設定する.
+ * オプション内の相対パスは、その jconf 設定ファイルからの相対となる.
  * 
- * @param conffile [in] jconf եΥѥ̾
- * @param jconf [out] ͤ򥻥åȤ jconf ǡ
+ * @param conffile [in] jconf ファイルのパス名
+ * @param jconf [out] 値をセットする jconf 設定データ
  * </JA>
  * <EN>
  * Read and parse a jconf file, and set the specified option values.
@@ -570,7 +576,7 @@ config_file_parse(char *conffile, Jconf *jconf)
 
 /* parse DNN config file */
 boolean
-dnn_config_file_parse(char *filename, JCONF_AM *am)
+dnn_config_file_parse(char *filename, JCONF_AM *am, Jconf *jconf)
 {
   FILE *fp;
   char buf[BUFLEN];
@@ -578,6 +584,7 @@ dnn_config_file_parse(char *filename, JCONF_AM *am)
   char *v;
   int i, n;
   boolean error_flag;
+  char *cdir;
 
   if (am->dnn.wfile != NULL) {
     jlog("ERROR: dnn_config_file_parse: duplicated loading: %s\n", filename);
@@ -588,6 +595,14 @@ dnn_config_file_parse(char *filename, JCONF_AM *am)
     jlog("ERROR: dnn_config_file_parse: failed to open %s\n", filename);
     return FALSE;
   }
+
+  cdir = strcpy((char *)mymalloc(strlen(filename)+1), filename);
+  get_dirname(cdir);
+  if (cdir[0] == '\0') {
+    free(cdir);
+    cdir = NULL;
+  }
+
   while (fgets_jconf(buf, BUFLEN, fp) != NULL) {
     if ((p = strchr(buf, '#')) != NULL) {
       *p = '\0';
@@ -598,6 +613,7 @@ dnn_config_file_parse(char *filename, JCONF_AM *am)
     p = strchr(pp, ' ');
     if (p == NULL) {
       jlog("ERROR: dnn_config_file_parse: wrong file format: %s\n", buf);
+      if (cdir) free(cdir);
       fclose(fp);
       return FALSE;
     }
@@ -625,39 +641,58 @@ dnn_config_file_parse(char *filename, JCONF_AM *am)
       n = atoi(&(pp[1]));
       if (n > am->dnn.hiddenlayernum) {
 	jlog("ERROR: dnn_config_file_parse: W%d > # of hidden_layers (%d)\n", n, am->dnn.hiddenlayernum);
+	if (cdir) free(cdir);
 	fclose(fp);
 	return FALSE;
       } else if (n <= 0) {
 	jlog("ERROR: dnn_config_file_parse: layer id should begin with 1\n");
+	if (cdir) free(cdir);
 	fclose(fp);
 	return FALSE;
       }
-      am->dnn.wfile[n-1] = strdup(v);
+      am->dnn.wfile[n-1] = filepath(v, cdir);
     } else if (pp[0] == 'B') {
       n = atoi(&(pp[1]));
       if (n > am->dnn.hiddenlayernum) {
 	jlog("ERROR: dnn_config_file_parse: B%d > # of hidden_layers (%d)\n", n, am->dnn.hiddenlayernum);
+	if (cdir) free(cdir);
 	fclose(fp);
 	return FALSE;
       } else if (n <= 0) {
 	jlog("ERROR: dnn_config_file_parse: layer id should begin with 1\n");
+	if (cdir) free(cdir);
 	fclose(fp);
 	return FALSE;
       }
-      am->dnn.bfile[n-1] = strdup(v);
-    } else if (strmatch(pp, "output_W")) am->dnn.output_wfile = strdup(v);
-    else if (strmatch(pp, "output_B")) am->dnn.output_bfile = strdup(v);
-    else if (strmatch(pp, "state_prior")) am->dnn.priorfile = strdup(v);
+      am->dnn.bfile[n-1] = filepath(v, cdir);
+    } else if (strmatch(pp, "output_W")) am->dnn.output_wfile = filepath(v, cdir);
+    else if (strmatch(pp, "output_B")) am->dnn.output_bfile = filepath(v, cdir);
+    else if (strmatch(pp, "state_prior")) am->dnn.priorfile = filepath(v, cdir);
     else if (strmatch(pp, "state_prior_factor")) am->dnn.prior_factor = atof(v);
-    else if (strmatch(pp, "batch_size")) am->dnn.batchsize = atoi(v);
+    else if (strmatch(pp, "state_prior_log10nize")) {
+      if (strmatch(v, "yes") || strmatch(v, "true")) {
+	am->dnn.prior_factor_log10nize = TRUE;
+      } else if (strmatch(v, "no") || strmatch(v, "false")) {
+	am->dnn.prior_factor_log10nize = FALSE;
+      } else {
+	jlog("ERROR: dnn_config_file_parse: value of state_prior_log10nize must be \"true\" or \"false\"\n");
+	if (cdir) free(cdir);
+	fclose(fp);
+	return FALSE;
+      }
+    } else if (strmatch(pp, "batch_size")) am->dnn.batchsize = atoi(v);
+    else if (strmatch(pp, "num_threads")) am->dnn.num_threads = atoi(v);
+    else if (strmatch(pp, "cuda_mode")) am->dnn.cuda_mode = strdup(v);
     else {
       jlog("ERROR: dnn_config_file_parse: unknown spec: %s %s\n", pp, v);
+      if (cdir) free(cdir);
       fclose(fp);
       return FALSE;
     }
   }
   if (fclose(fp) == -1) {
     jlog("ERROR: dnn_config_file_parse: failed to close file\n");
+    if (cdir) free(cdir);
     return FALSE;
   }
 
@@ -674,10 +709,22 @@ dnn_config_file_parse(char *filename, JCONF_AM *am)
     }
   }
   if (error_flag == TRUE) {
+    if (cdir) free(cdir);
     return FALSE;
   }
 
   am->dnn.enabled = TRUE;
+
+  /* load options */
+  if (am->dnn.optionstring) {
+    if (config_string_parse_basedir(jconf->amnow->dnn.optionstring, jconf, cdir) == FALSE) {
+      if (cdir) free(cdir);
+      return FALSE;
+    }
+  }
+
+  if (cdir) free(cdir);
+
   return TRUE;
 }
 
