@@ -2,10 +2,10 @@
  * @file   m_options.c
  * 
  * <JA>
- * @brief  ץ
+ * @brief  オプション処理
  *
- * ˤؿϡjconfե뤪ӥޥɥ饤󤫤Υץ
- * ɤ߹ߡͤǼ. 
+ * ここにある関数は，jconfファイルおよびコマンドラインからのオプション指定を
+ * 順に読み込み，値を格納する. 
  * </JA>
  * 
  * <EN>
@@ -32,15 +32,15 @@
 
 /** 
  * <JA>
- * @brief  ХѥեѥѴ. 
+ * @brief  相対パスをフルパスに変換する. 
  * 
- * եΥѥ̾ХѥǤСȥǥ쥯ȥĤ
- * եѥѴ֤. ХѥǤСΤޤ֤. 
+ * ファイルのパス名が相対パスであれば，カレントディレクトリをつけた
+ * フルパスに変換して返す. 絶対パスであれば，そのまま返す. 
  * 
- * @param filename [in] եΥѥ̾
- * @param dirname [in] ȥǥ쥯ȥΥѥ̾
+ * @param filename [in] ファイルのパス名
+ * @param dirname [in] カレントディレクトリのパス名
  * 
- * @return Хѥ̾ä˳դ줿Хåե
+ * @return 絶対パス名の入った，新たに割り付けられたバッファ
  * </JA>
  * <EN>
  * @brief  Change relative path to full path.
@@ -77,7 +77,7 @@ filepath(char *filename, char *dirname)
  * Returns next argument string.
  * </EN>
  * <JA>
- * ΰʸ֤. 
+ * 次の引数の文字列を返す. 
  * </JA>
  * 
  * @param cur [i/o] pointer to current point of the argment array
@@ -133,9 +133,9 @@ check_section(Jconf *jconf, char *optname, short sec)
 
 /** 
  * <JA>
- * ΰ NULL . 
- * @param p [i/o] ΰƬؤݥѿؤΥݥ
- * @note @a p  NULL ξϲⵯʤ
+ * メモリ領域を解放し NULL で埋める. 
+ * @param p [i/o] メモリ領域の先頭を指すポインタ変数へのポインタ
+ * @note @a p が NULL の場合は何も起こらない。
  * </JA>
  * <EN>
  * Free memory and fill it with NULL.
@@ -148,12 +148,12 @@ check_section(Jconf *jconf, char *optname, short sec)
 
 /**
  * <JA>
- * ץ.
+ * オプション解析.
  *
- * @param argc [in] @a argv ˴ޤޤο
- * @param argv [in] ͡ʸˤ
- * @param cwd [in] ȥǥ쥯ȥ
- * @param jconf [out] ͤǼjconf¤
+ * @param argc [in] @a argv に含まれる引数の数
+ * @param argv [in] 引数値（文字列）の配列
+ * @param cwd [in] カレントディレクトリ
+ * @param jconf [out] 値を格納するjconf構造体
  * 
  * </JA>
  * <EN>
@@ -1152,6 +1152,11 @@ opt_parse(int argc, char *argv[], char *cwd, Jconf *jconf)
       if (!check_section(jconf, argv[i], JCONF_OPT_AM)) return FALSE; 
       jconf->amnow->analysis.map_cmn = FALSE;
       jconf->amnow->analysis.cmn_update = FALSE;
+      jconf->amnow->analysis.cmn_static_cvn_only = FALSE;
+      continue;
+    } else if (strmatch(argv[i],"-cvnstatic")) { /* static variance but left mean dynamic on buffered input  */
+      if (!check_section(jconf, argv[i], JCONF_OPT_AM)) return FALSE; 
+      jconf->amnow->analysis.cmn_static_cvn_only = TRUE;
       continue;
     } else if (strmatch(argv[i],"-cmnmapweight")) { /* CMN weight for MAP */
       if (!check_section(jconf, argv[i], JCONF_OPT_AM)) return FALSE; 
@@ -1338,18 +1343,27 @@ opt_parse(int argc, char *argv[], char *cwd, Jconf *jconf)
       if (!check_section(jconf, argv[i], JCONF_OPT_AM)) return FALSE; 
       GET_TMPARG;
       tmparg = filepath(tmparg, cwd);
-      if (dnn_config_file_parse(tmparg, jconf->amnow) == FALSE) {
+      if (dnn_config_file_parse(tmparg, jconf->amnow, jconf) == FALSE) {
 	jlog("ERROR: m_options: failed to read %s\n", tmparg);
 	free(tmparg);
 	return FALSE;
       }
-      if (jconf->amnow->dnn.optionstring) {
-	if (config_string_parse(jconf->amnow->dnn.optionstring, jconf) == FALSE) {
-	  return FALSE;
-	}
-      }
       free(tmparg);
       continue;
+#ifdef HAVE_LIBFVAD
+    } else if (strmatch(argv[i],"-fvad")) { /* fvad switch */
+      if (!check_section(jconf, argv[i], JCONF_OPT_GLOBAL)) return FALSE;
+      GET_TMPARG;
+      jconf->detect.fvad_mode = atoi(tmparg);
+      continue;
+    } else if (strmatch(argv[i],"-fvad_param")) { /* set fvad parameter */
+      if (!check_section(jconf, argv[i], JCONF_OPT_GLOBAL)) return FALSE;
+      GET_TMPARG;
+      jconf->detect.fvad_smoothnum = atoi(tmparg);
+      GET_TMPARG;
+      jconf->detect.fvad_thres = (float)atof(tmparg);
+      continue;
+#endif /* HAVE_LIBFVAD */
     }
     if (argv[i][0] == '-' && strlen(argv[i]) == 2) {
       /* 1-letter options */
@@ -1496,7 +1510,7 @@ opt_parse(int argc, char *argv[], char *cwd, Jconf *jconf)
 
 /** 
  * <JA>
- * ץϢΥΰ. 
+ * オプション関連のメモリ領域を解放する. 
  * </JA>
  * <EN>
  * Free memories of variables allocated by option arguments.
