@@ -2,24 +2,24 @@
  * @file   multi-gram.c
  * 
  * <JA>
- * @brief  ǧʸˡδ
+ * @brief  認識用文法の管理
  *
- * Υեˤϡǧʸˡɤ߹ߤȴԤؿޤޤƤޤ. 
- * δؿϡʸˡեɤ߹ߡӳƼǡ
- * åȥåפԤޤ. 
+ * このファイルには，認識用文法の読み込みと管理を行う関数が含まれています. 
+ * これらの関数は，文法ファイルの読み込み，および各種データの
+ * セットアップを行います. 
  *
- * ʣʸˡƱǧбƤޤ. ʣʸˡ٤ɤ߹ǡ
- * ǧԤޤ. ޤ⥸塼⡼ɤǤϡ饤Ȥ
- * ǧ¹ʸˡưŪɲáꡤʬʸˡ̵
- * ͭǤޤ. ޤͿ줿ġʸˡȤǧ̤
- * ФȤǤޤ. 
+ * 複数文法の同時認識に対応しています. 複数の文法を一度に読み込んで，
+ * 並列に認識を行えます. また，モジュールモードでは，クライアントから
+ * 認識実行中に文法を動的に追加・削除したり，一部分の文法を無効化・
+ * 有効化したりできます. また与えられた個々の文法ごとに認識結果を
+ * 出すことができます. 
  *
- * Ϳ줿ʣΡʸˡϰĤΥХʸˡȤƷ礵,
- * ʸˡɤ߹ߤʤɤξѹԤäȤޤ. 
- * 礵줿ʸ§ (DFA)  global_dfa ˡü global_winfo 
- * 줾˳Ǽޤ. Ŭڤʥߥ󥰤
- * multigram_build() ƤӽФ줿Ȥˡglobal.h ѿ dfa
- *  winfo ˥ԡ졤ǧˤƻѤ褦ˤʤޤ. 
+ * 与えられた（複数の）文法は一つのグローバル文法として結合され,
+ * 文法の読み込みや削除などの状態変更を行ったとき，更新されます. 
+ * 結合された構文規則 (DFA) が global_dfa に，語彙辞書が global_winfo に
+ * それぞれローカルに格納されます. これらは適切なタイミングで
+ * multigram_build() が呼び出されたときに，global.h 内の大域変数 dfa
+ * および winfo にコピーされ，認識処理において使用されるようになります. 
  * </JA>
  * 
  * <EN>
@@ -47,13 +47,13 @@
  * @author Akinobu Lee
  * @date   Sat Jun 18 23:45:18 2005
  *
- * $Revision: 1.11 $
+ * $Revision: 1.12 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -65,14 +65,14 @@
 
 /** 
  * <JA>
- * @brief  Хʸˡڹ¤ۤ. 
+ * @brief  グローバル文法から木構造化辞書を構築する. 
  *
- * Ϳ줿ʸˡǧԤˡǧ󥹥󥹤߻
- * Хʸˡڹ¤ʺơ˹ۤޤ. ޤ 
- * ư˥ӡŪ˻ؼƤʤե륵ξ硤
- * ӡκԤޤ.
+ * 与えられた文法で認識を行うために，認識処理インスタンスが現在持つ
+ * グローバル文法から木構造化辞書を（再）構築します. また， 
+ * 起動時にビーム幅が明示的に指示されていない場合やフルサーチの場合，
+ * ビーム幅の再設定も行います.
  * 
- * @param r [i/o] ǧ󥹥
+ * @param r [i/o] 認識処理インスタンス
  * </JA>
  * <EN>
  * @brief  Build tree lexicon from global grammar.
@@ -102,6 +102,7 @@ multigram_rebuild_wchmm(RecogProcess *r)
   r->wchmm->hmmwrk = &(r->am->hmmwrk);
   /* assign models */
   r->wchmm->dfa = r->lm->dfa;
+  r->wchmm->dfa_forward = r->lm->dfa_forward;
   r->wchmm->winfo = r->lm->winfo;
   r->wchmm->hmminfo = r->am->hmminfo;
   if (r->wchmm->category_tree) {
@@ -114,7 +115,7 @@ multigram_rebuild_wchmm(RecogProcess *r)
     ret = build_wchmm2(r->wchmm, r->lm->config);
   }
 
-  /* ư -check ǥå⡼ɤ */
+  /* 起動時 -check でチェックモードへ */
   if (r->config->sw.wchmm_check_flag) {
     wchmm_check_interactive(r->wchmm);
   }
@@ -153,10 +154,10 @@ multigram_rebuild_wchmm(RecogProcess *r)
  * from the updated global grammar.
  * </EN>
  * <JA>
- * @brief  ХʸˡĴ١ɬפڹ¤ʺơ˹ۤ. 
+ * @brief  グローバル文法を調べ，必要があれば木構造化辞書を（再）構築する. 
  * 
- * Х뼭ѹСι줿Х
- * 񤫤ڹ¤ʤɤβǧѥǡ¤ƹۤ. 
+ * グローバル辞書に変更があれば，その更新されたグローバル
+ * 辞書から木構造化辞書などの音声認識用データ構造を再構築する. 
  * 
  * </JA>
  * 
@@ -187,14 +188,14 @@ multigram_build(RecogProcess *r)
 
 /** 
  * <JA>
- * @brief  Хʸˡʸˡɲä. 
+ * @brief  グローバル文法の末尾に文法を追加する. 
  *
- * Ȥʸˡ¤ΤˤϡХʸˡΤɤΰ֤ˤʸˡɲ
- * 줿ΥƥֹȼֹϰϤϿ. 
+ * もとの文法構造体には，グローバル文法のどの位置にその文法が追加
+ * されたか，そのカテゴリ番号と辞書番号の範囲が記録される. 
  * 
- * @param gdfa [i/o] ʸˡDFA
- * @param gwinfo [i/o] ʸˡμ
- * @param m [i/o] 礹ʸˡ. 
+ * @param gdfa [i/o] 結合先の文法のDFA情報
+ * @param gwinfo [i/o] 結合先の文法の辞書情報
+ * @param m [i/o] 結合する文法情報. 
  * </JA>
  * <EN>
  * @brief  Append a grammar to the tail of global grammar.
@@ -208,17 +209,21 @@ multigram_build(RecogProcess *r)
  * </EN>
  */
 static boolean
-multigram_append_to_global(DFA_INFO *gdfa, WORD_INFO *gwinfo, MULTIGRAM *m)
+multigram_append_to_global(DFA_INFO *gdfa, WORD_INFO *gwinfo, DFA_INFO *gdfa_forward, MULTIGRAM *m)
 {
   /* the new grammar 'm' will be appended to the last of gdfa and gwinfo */
   m->state_begin = gdfa->state_num;	/* initial state ID */
   m->cate_begin = gdfa->term_num;	/* initial terminal ID */
   m->word_begin = gwinfo->num;	/* initial word ID */
+  m->state_begin_forward = gdfa_forward ? gdfa_forward->state_num : 0;
   
   /* append category ID and node number of src DFA */
   /* Julius allow multiple initial states: connect each initial node
      is not necesarry. */
   dfa_append(gdfa, m->dfa, m->state_begin, m->cate_begin);
+  /* if forward DFA is given, also append DFA states to global forward DFA, offsetting the same category ID as normal DFA */
+  if (m->dfa_forward != NULL)
+    dfa_append(gdfa_forward, m->dfa_forward, m->state_begin_forward, m->cate_begin);
   /* append words of src vocabulary to global winfo */
   if (voca_append(gwinfo, m->winfo, m->cate_begin, m->word_begin) == FALSE) {
     return FALSE;
@@ -242,17 +247,17 @@ multigram_append_to_global(DFA_INFO *gdfa, WORD_INFO *gwinfo, MULTIGRAM *m)
 
 /** 
  * <JA>
- * ʸˡʸˡꥹȤɲä.
- * ߥ󥹥󥹤ݻƤʸˡΥꥹȤ lm->grammars ¸. 
- * ɲäʸˡˤϡnewbie  inactive Υե饰åȤ졤
- * ʸˡå˹оݤȤʤ. 
+ * 新たな文法を，文法リストに追加する.
+ * 現在インスタンスが保持している文法のリストは lm->grammars に保存される. 
+ * 追加した文法には，newbie と inactive のフラグがセットされ，次回の
+ * 文法更新チェック時に更新対象となる. 
  * 
- * @param dfa [in] ɲϿʸˡDFA
- * @param winfo [in] ɲϿʸˡμ
- * @param name [in] ɲϿʸˡ̾
- * @param lm [i/o] 󥹥
+ * @param dfa [in] 追加登録する文法のDFA情報
+ * @param winfo [in] 追加登録する文法の辞書情報
+ * @param name [in] 追加登録する文法の名称
+ * @param lm [i/o] 言語処理インスタンス
  *
- * @return ʸˡID֤. 
+ * @return 文法IDを返す. 
  * </JA>
  * <EN>
  * Add a new grammar to the current list of grammars.
@@ -274,7 +279,7 @@ multigram_append_to_global(DFA_INFO *gdfa, WORD_INFO *gwinfo, MULTIGRAM *m)
  * @ingroup grammar
  */
 int
-multigram_add(DFA_INFO *dfa, WORD_INFO *winfo, char *name, PROCESS_LM *lm)
+multigram_add(DFA_INFO *dfa, WORD_INFO *winfo, char *name, PROCESS_LM *lm, DFA_INFO *dfa_forward)
 {
   MULTIGRAM *new;
 
@@ -288,6 +293,7 @@ multigram_add(DFA_INFO *dfa, WORD_INFO *winfo, char *name, PROCESS_LM *lm)
 
   new->id = lm->gram_maxid;
   new->dfa = dfa;
+  new->dfa_forward = dfa_forward;
   new->winfo = winfo;
   /* will be setup and activated after multigram_update() is called once */
   new->hook = MULTIGRAM_DEFAULT | MULTIGRAM_ACTIVATE;
@@ -306,15 +312,15 @@ multigram_add(DFA_INFO *dfa, WORD_INFO *winfo, char *name, PROCESS_LM *lm)
 
 /** 
  * <JA>
- * ʸˡ. 
+ * 文法を削除する. 
  *
- * ʸˡꥹΤʸˡˤĤơޡդ. 
- * ºݤκ multigram_exec_delete() ǹԤ. 
+ * 文法リスト中のある文法について，削除マークを付ける. 
+ * 実際の削除は multigram_exec_delete() で行われる. 
  * 
- * @param delid [in] ʸˡʸˡID
- * @param lm [i/o] 󥹥
+ * @param delid [in] 削除する文法の文法ID
+ * @param lm [i/o] 言語処理インスタンス
  * 
- * @return ̾ TRUE ֤. ꤵ줿IDʸˡ̵ FALSE ֤. 
+ * @return 通常時 TRUE を返す. 指定されたIDの文法が無い場合は FALSE を返す. 
  * </JA>
  * <EN>
  * Mark a grammar in the grammar list to be deleted at the next grammar update.
@@ -349,9 +355,9 @@ multigram_delete(int delid, PROCESS_LM *lm)
 
 /** 
  * <JA>
- * ٤Ƥʸˡ򼡲󹹿˺褦ޡ.
+ * すべての文法を次回更新時に削除するようマークする.
  * 
- * @param lm [i/o] 󥹥
+ * @param lm [i/o] 言語処理インスタンス
  * </JA>
  * <EN>
  * Mark all grammars to be deleted at next grammar update.
@@ -373,11 +379,11 @@ multigram_delete_all(PROCESS_LM *lm)
 
 /** 
  * <JA>
- * ޡΤĤʸˡꥹȤ. 
+ * 削除マークのついた文法をリストから削除する. 
  * 
- * @param lm [i/o] 󥹥
+ * @param lm [i/o] 言語処理インスタンス
  * 
- * @return ХʸˡκƹۤɬפʤȤ TRUE ɬפʤȤ FALSE ֤. 
+ * @return グローバル文法の再構築が必要なときは TRUE を，不必要なときは FALSE を返す. 
  * </JA>
  * <EN>
  * Purge grammars marked as delete.
@@ -402,6 +408,7 @@ multigram_exec_delete(PROCESS_LM *lm)
       /* if any grammar is deleted, we need to rebuild lexicons etc. */
       /* so tell it to the caller */
       if (! m->newbie) ret_flag = TRUE;
+      if (m->dfa_forward) dfa_info_free(m->dfa_forward);
       if (m->dfa) dfa_info_free(m->dfa);
       word_info_free(m->winfo);
       jlog("STAT: Gram #%d %s: purged\n", m->id, m->name);
@@ -422,11 +429,11 @@ multigram_exec_delete(PROCESS_LM *lm)
 
 /** 
  * <JA>
- * ʸˡͭ. Ǥϼ󹹿
- * ȿǤ褦˥ޡĤΤߤǤ. 
+ * 文法を有効化する. ここでは次回更新時に
+ * 反映されるようにマークをつけるのみである. 
  * 
- * @param gid [in] ͭʸˡ ID
- * @param lm [i/o] 󥹥
+ * @param gid [in] 有効化したい文法の ID
+ * @param lm [i/o] 言語処理インスタンス
  * </JA>
  * <EN>
  * Activate a grammar in the grammar list.  The specified grammar
@@ -478,14 +485,14 @@ multigram_activate(int gid, PROCESS_LM *lm)	/* only mark */
 
 /** 
  * <JA>
- * ʸˡ̵. ̵줿ʸˡ
- * ǧˤƲŸʤ. ˤäơХ뼭
- * ƹۤ뤳ȤʤŪ˸ġʸˡON/OFFǤ. ̵
- * ʸˡ multigram_activate() ǺƤͭǤ. ʤǤ
- * ʸˡߥ󥰤ȿǤ褦˥ޡĤΤߤǤ. 
+ * 文法を無効化する. 無効化された文法は
+ * 認識において仮説展開されない. これによって，グローバル辞書を
+ * 再構築することなく，一時的に個々の文法をON/OFFできる. 無効化した
+ * 文法は multigram_activate() で再び有効化できる. なおここでは
+ * 次回の文法更新タイミングで反映されるようにマークをつけるのみである. 
  * 
- * @param gid [in] ̵ʸˡID
- * @param lm [i/o] 󥹥
+ * @param gid [in] 無効化したい文法のID
+ * @param lm [i/o] 言語処理インスタンス
  * </JA>
  * <EN>
  * Deactivate a grammar in the grammar list.  The words of the de-activated
@@ -540,12 +547,12 @@ multigram_deactivate(int gid, PROCESS_LM *lm)	/* only mark */
 
 /** 
  * <JA>
- * ʸˡ̵ͭ¹Ԥ. 
+ * 文法の有効化・無効化を実行する. 
  * 
- * @param lm [i/o] 󥹥
+ * @param lm [i/o] 言語処理インスタンス
  * 
- * @return ̵ͭء뤤̵ͭؾ֤ѲʸˡĤǤ
- * TRUE, ֤Ѳʤä FALSE ֤. 
+ * @return 無効から有効へ，あるいは有効から無効へ状態が変化した文法が一つでも
+ * あればTRUE, 状態が全く変化しなかった場合は FALSE を返す. 
  * </JA>
  * <EN>
  * Execute (de)activation of grammars.
@@ -585,16 +592,16 @@ multigram_exec_activate(PROCESS_LM *lm)
  
 /** 
  * <JA>
- * @brief  Хʸˡι
+ * @brief  グローバル文法の更新
  * 
- * ƽФʸˡꥹȤѹå. 
- * ꥹ˺ޡĤ줿ʸˡϡʸˡ
- * Х뼭ƹۤ. ɲä줿ʸˡϡ
- * ʸˡ򸽺ߤΥХ뼭ɲä. 
+ * 前回呼出しからの文法リストの変更をチェックする. 
+ * リスト中に削除マークがつけられた文法がある場合は，その文法を削除し，
+ * グローバル辞書を再構築する. 新たに追加された文法がある場合は，
+ * その文法を現在のグローバル辞書の末尾に追加する. 
  *
- * @param lm [i/o] 󥹥
+ * @param lm [i/o] 言語処理インスタンス
  * 
- * @return  TRUE ֤. 
+ * @return 常に TRUE を返す. 
  * </JA>
  * <EN>
  * @brief  Update  global grammar if needed.
@@ -673,15 +680,23 @@ multigram_update(PROCESS_LM *lm)
       dfa_info_free(lm->dfa);
       lm->dfa = NULL;
     }
+    if (lm->dfa_forward != NULL) {
+      dfa_info_free(lm->dfa_forward);
+      lm->dfa_forward = NULL;
+    }
     if (lm->winfo != NULL) {
       word_info_free(lm->winfo);
       lm->winfo = NULL;
     }
+    if (lm->lmvar == LM_DFA_GRAMMAR && lm->dfa == NULL) {
+      lm->dfa = dfa_info_new();
+      dfa_state_init(lm->dfa);
+    }
     /* concatinate all existing grammars to global */
     for(m=lm->grammars;m;m=m->next) {
-      if (lm->lmvar == LM_DFA_GRAMMAR && lm->dfa == NULL) {
-	lm->dfa = dfa_info_new();
-	dfa_state_init(lm->dfa);
+      if (lm->lmvar == LM_DFA_GRAMMAR && lm->dfa_forward == NULL && m->dfa_forward != NULL) {
+	lm->dfa_forward = dfa_info_new();
+	dfa_state_init(lm->dfa_forward);
       }
       if (lm->winfo == NULL) {
 	lm->winfo = word_info_new();
@@ -697,7 +712,7 @@ multigram_update(PROCESS_LM *lm)
 	  m->hook |= MULTIGRAM_DELETE;
 	}
       } else {
-	if (multigram_append_to_global(lm->dfa, lm->winfo, m) == FALSE) {
+	if (multigram_append_to_global(lm->dfa, lm->winfo, lm->dfa_forward, m) == FALSE) {
 	  jlog("ERROR: multi-gram: failed to add grammar #%d to recognition network\n", m->id);
 	  /* mark as delete */
 	  m->hook |= MULTIGRAM_DELETE;
@@ -717,6 +732,10 @@ multigram_update(PROCESS_LM *lm)
 	  lm->dfa = dfa_info_new();
 	  dfa_state_init(lm->dfa);
 	}
+	if (lm->lmvar == LM_DFA_GRAMMAR && lm->dfa_forward == NULL && m->dfa_forward != NULL) {
+	  lm->dfa_forward = dfa_info_new();
+	  dfa_state_init(lm->dfa_forward);
+	}
 	if (lm->winfo == NULL) {
 	  lm->winfo = word_info_new();
 	  winfo_init(lm->winfo);
@@ -731,7 +750,7 @@ multigram_update(PROCESS_LM *lm)
 	    m->hook |= MULTIGRAM_DELETE;
 	  }
 	} else {
-	  if (multigram_append_to_global(lm->dfa, lm->winfo, m) == FALSE) {
+	  if (multigram_append_to_global(lm->dfa, lm->winfo, lm->dfa_forward, m) == FALSE) {
 	    jlog("ERROR: multi-gram: failed to add grammar #%d to recognition network\n", m->id);
 	    /* mark as delete */
 	    m->hook |= MULTIGRAM_DELETE;
@@ -754,6 +773,10 @@ multigram_update(PROCESS_LM *lm)
 	  dfa_info_free(lm->dfa);
 	  lm->dfa = NULL;
 	}
+	if (lm->dfa_forward != NULL) {
+	  dfa_info_free(lm->dfa_forward);
+	  lm->dfa_forward = NULL;
+	}
 	if (lm->winfo != NULL) {
 	  word_info_free(lm->winfo);
 	  lm->winfo = NULL;
@@ -774,11 +797,11 @@ multigram_update(PROCESS_LM *lm)
 
 /** 
  * <JA>
- * dfaեdictեɤ߹ʸˡꥹȤɲä. 
+ * dfaファイルとdictファイルを読み込んで文法リストに追加する. 
  * 
- * @param dfa_file [in] dfa ե̾
- * @param dict_file [in] dict ե̾
- * @param lm [i/o] 󥹥
+ * @param dfa_file [in] dfa ファイル名
+ * @param dict_file [in] dict ファイル名
+ * @param lm [i/o] 言語処理インスタンス
  * </JA>
  * <EN>
  * Add grammar to the grammar list specified by dfa file and dict file.
@@ -793,6 +816,7 @@ multigram_read_file_and_add(char *dfa_file, char *dict_file, PROCESS_LM *lm)
 {
   WORD_INFO *new_winfo;
   DFA_INFO *new_dfa;
+  DFA_INFO *new_dfa_forward;
   char buf[MAXGRAMNAMELEN], *p, *q;
   boolean ret;
 
@@ -841,6 +865,18 @@ multigram_read_file_and_add(char *dfa_file, char *dict_file, PROCESS_LM *lm)
       dfa_info_free(new_dfa);
       return FALSE;
     }
+    /* read additional forward dfa if exists */
+    p = mymalloc(strlen(dfa_file) + 9);
+    strcpy(p, dfa_file);
+    strcat(p, ".forward");
+    new_dfa_forward = dfa_info_new();
+    if (init_dfa(new_dfa_forward, p) == TRUE) {
+      jlog("STAT: reading additional forward dfa [%s]\n", p);
+    } else {
+      dfa_info_free(new_dfa_forward);
+      new_dfa_forward = NULL;
+    }
+    free(p);
   }
 
   jlog("STAT: done\n");
@@ -860,7 +896,7 @@ multigram_read_file_and_add(char *dfa_file, char *dict_file, PROCESS_LM *lm)
   buf[p-q] = '\0';
   
   /* register the new grammar to multi-gram tree */
-  multigram_add(new_dfa, new_winfo, buf, lm);
+  multigram_add(new_dfa, new_winfo, buf, lm, new_dfa_forward);
 
   return TRUE;
 
@@ -869,9 +905,9 @@ multigram_read_file_and_add(char *dfa_file, char *dict_file, PROCESS_LM *lm)
 
 /** 
  * <JA>
- * ư˻ꤵ줿٤Ƥʸˡɤ. 
+ * 起動時に指定されたすべての文法をロードする. 
  * 
- * @param lm [i/o] 󥹥
+ * @param lm [i/o] 言語処理インスタンス
  * 
  * </JA>
  * <EN>
@@ -906,11 +942,11 @@ multigram_load_all_gramlist(PROCESS_LM *lm)
 
 /** 
  * <JA>
- * ߤʸˡο(active/inactiveȤ). 
+ * 現在ある文法の数を得る(active/inactiveとも). 
  * 
- * @param lm [i/o] 󥹥
+ * @param lm [i/o] 言語処理インスタンス
  * 
- * @return ʸˡο֤. 
+ * @return 文法の数を返す. 
  * </JA>
  * <EN>
  * Get the number of current grammars (both active and inactive).
@@ -936,12 +972,12 @@ multigram_get_all_num(PROCESS_LM *lm)
 
 /** 
  * <JA>
- * ñ쥫ƥ°ʸˡ. 
+ * 単語カテゴリの属する文法を得る. 
  * 
- * @param category ñ쥫ƥID
- * @param lm [i/o] 󥹥
+ * @param category 単語カテゴリID
+ * @param lm [i/o] 言語処理インスタンス
  * 
- * @return ñ쥫ƥ°ʸˡID֤. 
+ * @return 単語カテゴリの属する文法のIDを返す. 
  * </JA>
  * <EN>
  * Get which grammar the given category belongs to.
@@ -973,12 +1009,12 @@ multigram_get_gram_from_category(int category, PROCESS_LM *lm)
 
 /** 
  * <JA>
- * ñID°ʸˡ. 
+ * 単語IDから属する文法を得る. 
  * 
- * @param wid ñID
- * @param lm [i/o] 󥹥
+ * @param wid 単語ID
+ * @param lm [i/o] 言語処理インスタンス
  * 
- * @return ñ°ʸˡID֤. 
+ * @return 単語の属する文法のIDを返す. 
  * </JA>
  * <EN>
  * Get which grammar the given word belongs to.
@@ -1012,7 +1048,7 @@ multigram_get_gram_from_wid(WORD_ID wid, PROCESS_LM *lm)
 
 /** 
  * <JA>
- * ݻƤʸˡ򤹤٤Ʋ롣
+ * 保持している文法をすべて解放する。
  * 
  * @param root [in] root pointer of grammar list
  * </JA>
@@ -1044,7 +1080,7 @@ multigram_free_all(MULTIGRAM *root)
  * Return a grammar ID of the given grammar name.
  * </EN>
  * <JA>
- * LMʸˡ̾ǸʸˡID֤
+ * LM中の文法を名前で検索し，その文法IDを返す．
  * </JA>
  * 
  * @param lm [in] LM process instance
@@ -1077,7 +1113,7 @@ multigram_get_id_by_name(PROCESS_LM *lm, char *gramname)
  * Find a grammar in LM by its name.
  * </EN>
  * <JA>
- * LMʸˡ̾Ǹ. 
+ * LM中の文法を名前で検索する. 
  * </JA>
  * 
  * @param lm [in] LM process instance
@@ -1110,7 +1146,7 @@ multigram_get_grammar_by_name(PROCESS_LM *lm, char *gramname)
  * Find a grammar in LM by its ID number.
  * </EN>
  * <JA>
- * LMʸˡ ID ֹǸ. 
+ * LM中の文法を ID 番号で検索する. 
  * </JA>
  * 
  * @param lm [in] LM process instance
@@ -1150,14 +1186,14 @@ multigram_get_grammar_by_id(PROCESS_LM *lm, unsigned short id)
  * 
  * </EN>
  * <JA>
- * @brief  ñ콸ʸˡɲä롥
+ * @brief  単語集合を文法に追加する．
  *
- * ɲäñʸˡƥIDˤĤƤϡǤ˥󤵤ƤΤ
- * Τޤޥԡ롥äơϤδؿƤӽФˡ
- * ɲоݤʸˡ褦ꤵƤɬפ롥
- * ڹ¤Τ˺ƹۤ롥
+ * 追加する単語の文法カテゴリIDについては，すでにアサインされているものが
+ * そのままコピーされる．よって，それらはこの関数を呼び出す前に，
+ * 追加対象の文法で整合性が取れるよう正しく設定されている必要がある．
+ * 木構造化辞書全体が，後に再構築される．
  *
- * ñN-gramǥؤμɲäϸߥݡȤƤʤ
+ * 単語N-gram言語モデルへの辞書追加は現在サポートされていない．
  * 
  * </JA>
  * 
@@ -1208,9 +1244,9 @@ multigram_add_words_to_grammar(PROCESS_LM *lm, MULTIGRAM *m, WORD_INFO *winfo)
  * specified by its name.
  * </EN>
  * <JA>
- * @brief  ̾ǻꤵ줿ʸˡñ콸ɲä롥
+ * @brief  名前で指定された文法に単語集合を追加する．
  *
- * multigram_add_words_to_grammar() ʸˡ̾ǻꤷƼ¹Ԥ롥
+ * multigram_add_words_to_grammar() を文法名で指定して実行する．
  * 
  * </JA>
  * 
@@ -1239,9 +1275,9 @@ multigram_add_words_to_grammar_by_name(PROCESS_LM *lm, char *gramname, WORD_INFO
  * specified by its number.
  * </EN>
  * <JA>
- * @brief  ֹǻꤵ줿ʸˡñ콸ɲä롥
+ * @brief  番号で指定された文法に単語集合を追加する．
  *
- * multigram_add_words_to_grammar() ֹǻꤷƼ¹Ԥ롥
+ * multigram_add_words_to_grammar() を番号で指定して実行する．
  * 
  * </JA>
  * 
