@@ -2,17 +2,17 @@
  * @file   pass1.c
  * 
  * <JA>
- * @brief  1ѥե졼Ʊӡõ
+ * @brief  第1パス：フレーム同期ビーム探索
  *
- * Ūڹ¤Ѥơħ̥٥ȥФơJulius裱ѥ
- * Ǥե졼ƱӡõԤޤ. 
+ * 静的木構造辞書を用いて，入力特徴量ベクトル列に対して，Juliusの第１パス
+ * であるフレーム同期ビーム探索を行います. 
  *
- * ϥǡΤ餫ƤϡǷ׻
- * Ԥؿ get_back_trellis() ᥤ󤫤ƤФޤ. 饤ǧ
- * ξ realtime_1stpass.c 顤ե졼ऴȤη׻
- * λΤ줾줬ϤοʹԤˤ碌Ƹ̤˸ƤФޤ. 
+ * 入力データ全体があらかじめ得られている場合は，一括で計算を
+ * 行う関数 get_back_trellis() がメインから呼ばれます. オンライン認識
+ * の場合は realtime_1stpass.c から，初期化，フレームごとの計算，
+ * 終了処理のそれぞれが入力の進行にあわせて個別に呼ばれます. 
  *
- * ºݤθġǧ󥹥󥹤Ȥν beam.c ˵ҤƤޤ. 
+ * 実際の個々の認識処理インスタンスごとの処理は beam.c に記述されています. 
  *
  * </JA>
  * 
@@ -36,21 +36,21 @@
  * @author Akinobu Lee
  * @date   Fri Oct 12 23:14:13 2007
  *
- * $Revision: 1.9 $
+ * $Revision: 1.11 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
 #include <julius/julius.h>
 
 /********************************************************************/
-/* 裱ѥ¹Ԥᥤؿ                                     */
-/* Ϥѥץ饤 realtime_1stpass.c 򻲾ȤΤ */
+/* 第１パスを実行するメイン関数                                     */
+/* 入力をパイプライン処理する場合は realtime_1stpass.c を参照のこと */
 /* main function to execute 1st pass                                */
 /* the pipeline processing is not here: see realtime_1stpass.c      */
 /********************************************************************/
@@ -82,21 +82,21 @@
  * 
  * </EN>
  * <JA>
- * @brief  Ƥǧ󥹥󥹽1ե졼ʬʤ.
+ * @brief  全ての認識処理インスタンス処理を1フレーム分進める.
  *
- * Ƥǧ󥹥󥹤ˤĤơդƤMFCC׻󥹥
- *  mfcc->f 򥫥ȥե졼Ȥƽ1ե졼ʤ. 
+ * 全ての認識処理インスタンスについて，割り付けられているMFCC計算インスタンス
+ * の mfcc->f をカレントフレームとして処理を1フレーム進める. 
  *
- * ʤmfcc->invalid  TRUE ȤʤäƤ󥹥󥹤νϥå
- * . 
+ * なお，mfcc->invalid が TRUE となっている処理インスタンスの処理はスキップ
+ * される. 
  *
- * GMMη׻⤳ǸƤӽФ. GMM_VAD ϡGMM ˤ
- * ȯöֳϡλθФǹԤ. ޤGMMη׻̡
- * 뤤ǧΥ硼ȥݡơȽǥХ
- * ׵ˤꥻơ׵ᤵ줿ɤȽԤ. 
+ * GMMの計算もここで呼び出される. GMM_VAD 定義時は，GMM による
+ * 発話区間開始・終了の検出がここで行われる. また，GMMの計算結果，
+ * あるいは認識処理内のショートポーズセグメンテーション判定やデバイス・外部
+ * からの要求によりセグメンテーションが要求されたかどうかの判定も行う. 
  *
- * ե졼ñ̤ǸƤӽФ륳ХåϿƤϡ
- * ƽФԤ. 
+ * フレーム単位で呼び出されるコールバックが登録されている場合は，それらの
+ * 呼出しも行う. 
  * </JA>
  * 
  * @param recog [in] engine instance
@@ -152,12 +152,12 @@ decode_proceed(Recog *recog)
   }
 #endif
   if (recog->gmm != NULL && recog->gmmmfcc->valid) {
-    /* GMM ׻Ԥ */
+    /* GMM 計算を行う */
     if (recog->gmmmfcc->f == 0) {
-      /* GMM ׻ν */
+      /* GMM 計算の初期化 */
       gmm_prepare(recog);
     }
-    /* Υե졼ФGMM٤׻ */
+    /* このフレームに対するGMMの尤度を計算 */
     gmm_proceed(recog);
 #ifdef GMM_VAD
     /* Check for GMM-based VAD */
@@ -221,15 +221,15 @@ decode_proceed(Recog *recog)
     if (!p->live) continue;
     mfcc = p->am->mfcc;
     if (!mfcc->valid) {
-      /* Υե졼ν򥹥å */
+      /* このフレームの処理をスキップ */
       /* skip processing the frame */
       continue;
     }
 
-    /* mfcc-f Υե졼ˤĤǧ(ե졼Ʊӡõ)ʤ */
+    /* mfcc-f のフレームについて認識処理(フレーム同期ビーム探索)を進める */
     /* proceed beam search for mfcc->f */
     if (mfcc->f == 0) {
-      /* ǽΥե졼: õ */
+      /* 最初のフレーム: 探索処理を初期化 */
       /* initial frame: initialize search process */
       if (get_back_trellis_init(mfcc->param, p) == FALSE) {
 	jlog("ERROR: %02d %s: failed to initialize the 1st pass\n", p->config->id, p->config->name);
@@ -237,7 +237,7 @@ decode_proceed(Recog *recog)
       }
     }
     if (mfcc->f > 0 || p->am->hmminfo->multipath) {
-      /* 1ե졼õʤ */
+      /* 1フレーム探索を進める */
       /* proceed search for 1 frame */
       if (get_back_trellis_proceed(mfcc->f, mfcc->param, p, FALSE) == FALSE) {
 	mfcc->segmented = TRUE;
@@ -245,7 +245,7 @@ decode_proceed(Recog *recog)
       }
       if (p->config->successive.enabled) {
 	if (detect_end_of_segment(p, mfcc->f - 1)) {
-	  /* Ƚλ: 裱ѥ */
+	  /* セグメント終了検知: 第１パスここで中断 */
 	  mfcc->segmented = TRUE;
 	  break_decode = TRUE;
 	}
@@ -253,9 +253,9 @@ decode_proceed(Recog *recog)
     }
   }
 
-  /* Ȥ٤ɤǽŪȽԤ
-     ǥ١VAD뤤 spsegment ξ硤ʣ󥹥󥹴֤ OR
-     롥ޤGMMʤʣबϴ֤ AND 롥*/
+  /* セグメントすべきかどうか最終的な判定を行う．
+     デコーダベースVADあるいは spsegment の場合，複数インスタンス間で OR
+     を取る．また，GMMなど複数基準がある場合は基準間で AND を取る．*/
   /* determine whether to segment at here
      If multiple segmenter exists, take their AND */
   break_flag = FALSE;
@@ -268,21 +268,21 @@ decode_proceed(Recog *recog)
   }
 
   if (break_flag) {
-    /* õνλȯΤǤǧ򽪤. 
-       ǽΥե졼फ [f-1] ܤޤǤǧ줿Ȥˤʤ
+    /* 探索処理の終了が発生したのでここで認識を終える. 
+       最初のフレームから [f-1] 番目までが認識されたことになる
     */
     /* the recognition process tells us to stop recognition, so
        recognition should be terminated here.
        the recognized data are [0..f-1] */
 
-    /* ǽե졼 last_time ˥å */
+    /* 最終フレームを last_time にセット */
     /* set the last frame to last_time */
     for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
       mfcc->last_time = mfcc->f - 1;
     }
 
     if (! recog->jconf->decodeopt.segment) {
-      /* 硼ȥݡʳڤ줿硤ĤΥץǧ˼ΤƤ */
+      /* ショートポーズ以外で切れた場合，残りのサンプルは認識せずに捨てる */
       /* drop rest inputs if segmented by error */
       for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
 	mfcc->param->header.samplenum = mfcc->f;
@@ -349,17 +349,17 @@ power_reject(Recog *recog)
  * 
  * </EN>
  * <JA>
- * @brief  1ѥνλʥȻ
+ * @brief  第1パスの終了処理（セグメント時）
  * 
- * Ϥ餫λͳˤäǥȤ줿ˡ1ѥǧ
- * λƼƳ뤿νԤ. 
+ * 入力が何らかの事由によって途中でセグメントされた時に，第1パスの認識処理を
+ * 終了して次回再開するための処理を行う. 
  *
- * ޤǧ󥹥󥹤Фơñդ1ѥ
- * ǧ̤ȤƳǼ. ޤǧԡϴѤλϥ顼ơ
- * 줾쥻åȤ.
+ * まず，各認識処理インスタンスに対して，最尤単語系列を見付け，第1パスの
+ * 認識結果として格納する. また，認識失敗・入力棄却の時はエラーステータスをそ
+ * れぞれセットする.
  * 
- * ơǧǡΥȤǧ򡤸Ф줿
- * ֤Ƴ뤿ˡ֤ڤФƤƤ. 
+ * そして，次回の認識で，次のセグメントの認識を，検出された末尾雑音
+ * 区間から再開するために，その末尾雑音区間を切り出しておく処理を呼ぶ. 
  * 
  * </JA>
  * 
@@ -376,7 +376,7 @@ decode_end_segmented(Recog *recog)
   RecogProcess *p;
   int last_status;
 
-  /* rejectshort , ϤûФ1ѥ̤Ϥʤ */
+  /* rejectshort 指定時, 入力が短ければここで第1パス結果を出力しない */
   /* suppress 1st pass output if -rejectshort and input shorter than specified */
   ok_p = TRUE;
   if (recog->jconf->reject.rejectshortlen > 0) {
@@ -386,6 +386,13 @@ decode_end_segmented(Recog *recog)
       ok_p = FALSE;
     }
   }
+  if (recog->jconf->reject.rejectlonglen >= 0) {
+    mseclen = (float)recog->mfcclist->last_time * (float)recog->jconf->input.period * (float)recog->jconf->input.frameshift / 10000.0;
+    if (mseclen >= recog->jconf->reject.rejectlonglen) {
+      last_status = J_RESULT_STATUS_REJECT_LONG;
+      ok_p = FALSE;
+    }
+  }
 
 #ifdef POWER_REJECT
   if (ok_p) {
@@ -412,7 +419,7 @@ decode_end_segmented(Recog *recog)
   }
 
   if (recog->gmm != NULL) {
-    /* GMM ׻νλ */
+    /* GMM 計算の終了 */
     gmm_end(recog);
   }
 }
@@ -430,14 +437,14 @@ decode_end_segmented(Recog *recog)
  *
  * </EN>
  * <JA>
- * @brief  1ѥνλ
+ * @brief  第1パスの終了処理
  * 
- * ϤǸޤǽƽλȤˡ1ѥǧ
- * λ. 
+ * 入力が最後まで処理されて終了したときに，第1パスの認識処理を
+ * 終了させる. 
  *
- * ǧ󥹥󥹤ФơλǤ1ѥκñ
- * Ǽ. ޤǧԡϴѤλϥ顼ơ
- * 줾쥻åȤ.
+ * 各認識処理インスタンスに対して，その時点での第1パスの最尤単語
+ * 系列を格納する. また，認識失敗・入力棄却の時はエラーステータスをそ
+ * れぞれセットする.
  * 
  * </JA>
  * 
@@ -460,20 +467,20 @@ decode_end(Recog *recog)
   }
 
   if (recog->gmm != NULL) {
-    /* GMM ׻νλ */
+    /* GMM 計算の終了 */
     gmm_end(recog);
   }
 
 #ifdef GMM_VAD
-  /* ⤷ȥꥬʤޤϽλãΤʤ顤Τޤޥ顼λ */
+  /* もしトリガがかからないまま入力終了に達したのなら，そのままエラー終了 */
   if (recog->jconf->decodeopt.segment) {
     if (recog->gmm) {
       if (recog->gc->after_trigger == FALSE) {
 	for(p=recog->process_list;p;p=p->next) {
 	  p->result.status = J_RESULT_STATUS_ONLY_SILENCE;	/* reject by decoding */
 	}
-	/* 硼ȥݡơξ,
-	   ϥѥ᡼ʬʤɤκǽԤʤ */
+	/* ショートポーズセグメンテーションの場合,
+	   入力パラメータ分割などの最終処理も行なう */
 	/* When short-pause segmentation enabled */
 	finalize_segment(recog);
 	return;
@@ -482,7 +489,7 @@ decode_end(Recog *recog)
   }
 #endif
 
-  /* 裱ѥκǸΥե졼ǧԤ */
+  /* 第１パスの最後のフレームの認識処理を行う */
   /* finalize 1st pass */
   for(p=recog->process_list;p;p=p->next) {
     if (!p->live) continue;
@@ -497,7 +504,7 @@ decode_end(Recog *recog)
     }
   }
 
-  /* λ */
+  /* 終了処理 */
   for(p=recog->process_list;p;p=p->next) {
     if (!p->live) continue;
 
@@ -506,7 +513,7 @@ decode_end(Recog *recog)
     /* check rejection by no input */
     if (ok_p) {
       mfcc = p->am->mfcc;
-      /* Ĺǥ륿η׻˽ʬǤʤ硤̵Ȥ롥 */
+      /* 入力長がデルタの計算に十分でない場合，入力無しとする． */
       /* if input is short for compute all the delta coeff., terminate here */
       if (mfcc->f == 0) {
 	jlog("STAT: no input frame\n");
@@ -524,6 +531,13 @@ decode_end(Recog *recog)
 	  ok_p = FALSE;
 	}
       }
+      if (recog->jconf->reject.rejectlonglen >= 0) {
+	mseclen = (float)mfcc->param->samplenum * (float)recog->jconf->input.period * (float)recog->jconf->input.frameshift / 10000.0;
+	if (mseclen >= recog->jconf->reject.rejectlonglen) {
+	  last_status = J_RESULT_STATUS_REJECT_LONG;
+	  ok_p = FALSE;
+	}
+      }
     }
 
 #ifdef POWER_REJECT
@@ -557,8 +571,8 @@ decode_end(Recog *recog)
     }
   }
   if (recog->jconf->decodeopt.segment) {
-    /* 硼ȥݡơξ,
-       ϥѥ᡼ʬʤɤκǽԤʤ */
+    /* ショートポーズセグメンテーションの場合,
+       入力パラメータ分割などの最終処理も行なう */
     /* When short-pause segmentation enabled */
     finalize_segment(recog);
   }
@@ -567,18 +581,18 @@ decode_end(Recog *recog)
 
 /** 
  * <JA>
- * @brief  ե졼ƱӡõᥤؿʥХåѡ
+ * @brief  フレーム同期ビーム探索メイン関数（バッチ処理用）
  *
- * Ϳ줿ϥ٥ȥФ裱ѥ(ե졼Ʊӡõ)
- * Ԥη̤Ϥ. ޤե졼Ϥñ콪ü裲ѥ
- * Τñȥꥹ¤Τ˳Ǽ. 
+ * 与えられた入力ベクトル列に対して第１パス(フレーム同期ビーム探索)を
+ * 行い，その結果を出力する. また全フレームに渡る単語終端を，第２パス
+ * のために単語トレリス構造体に格納する. 
  * 
- * δؿϥ٥ȥ󤬤餫ƤѤ. 
- * 裱ѥϤ󤷤Ƽ¹Ԥ륪饤ǧξ硤
- * δؿѤ줺ˤΥեƤƥִؿ
- * ľ realtime-1stpass.c ⤫ƤФ. 
+ * この関数は入力ベクトル列があらかじめ得られている場合に用いられる. 
+ * 第１パスが入力と並列して実行されるオンライン認識の場合，
+ * この関数は用いられず，代わりにこのファイルで定義されている各サブ関数が
+ * 直接 realtime-1stpass.c 内から呼ばれる. 
  * 
- * @param recog [in] 󥸥󥤥󥹥
+ * @param recog [in] エンジンインスタンス
  * </JA>
  * <EN>
  * @brief  Frame synchronous beam search: the main (for batch mode)
@@ -653,7 +667,7 @@ get_back_trellis(Recog *recog)
       }
     }
     if (ok_p) {
-      /* ٤Ƥ MFCC ãΤǥ롼׽λ */
+      /* すべての MFCC が終わりに達したのでループ終了 */
       /* all MFCC has been processed, end of loop  */
       break;
     }
@@ -665,9 +679,9 @@ get_back_trellis(Recog *recog)
     case 0:			/* success */
       break;
     case 1:			/* segmented */
-      /* õ: 줿Ϥ 0  t-2 ޤ */
+      /* 探索中断: 処理された入力は 0 から t-2 まで */
       /* search terminated: processed input = [0..t-2] */
-      /* λ1ѥλ */
+      /* この時点で第1パスを終了する */
       /* end the 1st pass at this point */
       decode_end_segmented(recog);
       /* terminate 1st pass here */
@@ -701,7 +715,7 @@ get_back_trellis(Recog *recog)
     /* call frame-wise callback */
     callback_exec(CALLBACK_EVENT_PASS1_FRAME, recog);
 
-    /* 1ե졼ʤΤǥݥ󥿤ʤ */
+    /* 1フレーム処理が進んだのでポインタを進める */
     /* proceed frame pointer */
     for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
       if (!mfcc->valid) continue;
@@ -715,7 +729,7 @@ get_back_trellis(Recog *recog)
     }
   }
 
-  /* ǽե졼Ԥǧη̽ϤȽλԤ */
+  /* 最終フレーム処理を行い，認識の結果出力と終了処理を行う */
   decode_end(recog);
 
   return TRUE;
