@@ -2,51 +2,51 @@
  * @file   realtime-1stpass.c
  * 
  * <JA>
- * @brief  1ѥե졼Ʊӡõʼ»ֽǡ
+ * @brief  第1パス：フレーム同期ビーム探索（実時間処理版）
  *
- * 1ѥϳϤƱ˥ȤϤʿԤǧԤ
- * ؿƤ. 
+ * 第1パスを入力開始と同時にスタートし，入力と平行して認識処理を行うための
+ * 関数が定義されている. 
  * 
- * Хåξ硤Julius βǧϰʲμ
- * main_recognition_loop() Ǽ¹Ԥ. 
+ * バッチ処理の場合，Julius の音声認識処理は以下の手順で
+ * main_recognition_loop() 内で実行される. 
  *
- *  -#  adin_go()   ϲ speech[] ˳Ǽ
- *  -# ħ new_wav2mfcc() speechħѥ᡼ param ˳Ǽ
- *  -# 1ѥ¹ get_back_trellis() param ȥǥ뤫ñȥꥹ
- *  -# 2ѥ¹ wchmm_fbs()
- *  -# ǧ̽
+ *  -# 音声入力 adin_go()  → 入力音声が speech[] に格納される
+ *  -# 特徴量抽出 new_wav2mfcc() →speechから特徴パラメータを param に格納
+ *  -# 第1パス実行 get_back_trellis() →param とモデルから単語トレリスの生成
+ *  -# 第2パス実行 wchmm_fbs()
+ *  -# 認識結果出力
  *
- * 1ѥʿԽ硤嵭 1  3 ʿԤƹԤ. 
- * Julius Ǥϡ¹Խ򡤲ϤҤ뤿Ӥ
- * ǧ򤽤ʬŪ˿ʤ뤳ȤǼƤ. 
+ * 第1パスを平行処理する場合，上記の 1 〜 3 が平行して行われる. 
+ * Julius では，この並行処理を，音声入力の断片が得られるたびに
+ * 認識処理をその分だけ漸次的に進めることで実装している. 
  * 
- *  - ħФ1ѥ¹Ԥ򡤰ĤˤޤȤƥХåؿȤ. 
- *  - ϴؿ adin_go() ΥХåȤƾ嵭δؿͿ
+ *  - 特徴量抽出と第1パス実行を，一つにまとめてコールバック関数として定義. 
+ *  - 音声入力関数 adin_go() のコールバックとして上記の関数を与える
  *
- * ŪˤϡƤ RealTimePipeLine() ХåȤ
- * adin_go() Ϳ. adin_go() ϲϤȥꥬȤ줿
- * ҤȤ RealTimePipeLine() ƤӽФ. RealTimePipeLine() 줿
- * ʬˤĤħФ1ѥη׻ʤ. 
+ * 具体的には，ここで定義されている RealTimePipeLine() がコールバックとして
+ * adin_go() に与えられる. adin_go() は音声入力がトリガするとその得られた入力
+ * 断片ごとに RealTimePipeLine() を呼び出す. RealTimePipeLine() は得られた
+ * 断片分について特徴量抽出と第1パスの計算を進める. 
  *
- * CMN ˤĤդɬפǤ. CMN ̾ȯñ̤ǹԤ뤬
- * ޥϤͥåȥϤΤ褦ˡ1ѥʿԤǧԤ
- * ȯΤΥץȥʿѤ뤳ȤǤʤ. С 3.5
- * Ǥľȯ5ʬ(Ѥ줿Ϥ) CMN Τޤ޼ȯä
- * ήѤƤ3.5.1 ϡ嵭ľȯ CMN ͤȤ
- * ȯ CMN  MAP-CMN Ʒ׻褦ˤʤä. ʤ
- * ǽȯѤνCMN "-cmnload" Ϳ뤳ȤǤޤ
- * "-cmnnoupdate" ϤȤ CMN Ԥʤ褦ˤǤ. 
- * "-cmnnoupdate"  "-cmnload" Ȥ߹碌뤳Ȥ, ǽ˥Х
- * ץȥʿѤͿ˽ͤȤ MAP-CMN 뤳ȤǤ. 
+ * CMN について注意が必要である. CMN は通常発話単位で行われるが，
+ * マイク入力やネットワーク入力のように，第1パスと平行に認識を行う
+ * 処理時は発話全体のケプストラム平均を得ることができない. バージョン 3.5
+ * 以前では直前の発話5秒分(棄却された入力を除く)の CMN がそのまま次発話に
+ * 流用されていたが，3.5.1 からは，上記の直前発話 CMN を初期値として
+ * 発話内 CMN を MAP-CMN を持ちいて計算するようになった. なお，
+ * 最初の発話用の初期CMNを "-cmnload" で与えることもでき，また
+ * "-cmnnoupdate" で入力ごとの CMN 更新を行わないようにできる. 
+ * "-cmnnoupdate" と "-cmnload" と組み合わせることで, 最初にグローバルな
+ * ケプストラム平均を与え，それを常に初期値として MAP-CMN することができる. 
  *
- * פʴؿϰʲ̤Ǥ. 
+ * 主要な関数は以下の通りである. 
  *
- *  - RealTimeInit() - ưν
- *  - RealTimePipeLinePrepare() - ϤȤν
- *  - RealTimePipeLine() - 1ѥʿԽѥХåʾҡ
- *  - RealTimeResume() - 硼ȥݡơǧ
- *  - RealTimeParam() - ϤȤ1ѥλ
- *  - RealTimeCMNUpdate() - CMN ι
+ *  - RealTimeInit() - 起動時の初期化
+ *  - RealTimePipeLinePrepare() - 入力ごとの初期化
+ *  - RealTimePipeLine() - 第1パス平行処理用コールバック（上述）
+ *  - RealTimeResume() - ショートポーズセグメンテーション時の認識復帰
+ *  - RealTimeParam() - 入力ごとの第1パス終了処理
+ *  - RealTimeCMNUpdate() - CMN の更新
  *  
  * </JA>
  * 
@@ -127,13 +127,13 @@
 
 /** 
  * <JA>
- * MFCC׻󥹥ħѥ᡼٥ȥǼꥢ.
+ * MFCC計算インスタンス内に特徴パラメータベクトル格納エリアを準備する.
  * 
- * mfcc->para ξ˴ŤƥإåǼǼΰݤ. 
- * Ǽΰϡϻɬפ˱ƼưŪ˿ĹΤǡǤ
- * νԤ. Ǥ˳Ǽΰ褬ݤƤȤϤ򥭡פ. 
+ * mfcc->para の情報に基づいてヘッダ情報を格納し，初期格納領域を確保する. 
+ * 格納領域は，入力時に必要に応じて自動的に伸長されるので，ここでは
+ * その準備だけ行う. すでに格納領域が確保されているときはそれをキープする. 
  * 
- * /ǧ1󤴤Ȥ˷֤ƤФ.
+ * これは入力/認識1回ごとに繰り返し呼ばれる.
  * 
  * </JA>
  * <EN>
@@ -162,7 +162,7 @@ init_param(MFCCCalc *mfcc)
 
   para = mfcc->para;
 
-  /* 줫׻ѥ᡼ηإå */
+  /* これから計算されるパラメータの型をヘッダに設定 */
   /* set header types */
   mfcc->param->header.samptype = para->basetype;
   if (para->delta) mfcc->param->header.samptype |= F_DELTA;
@@ -176,28 +176,28 @@ init_param(MFCCCalc *mfcc)
   mfcc->param->header.sampsize = para->veclen * mfcc->splice * sizeof(VECT); /* not compressed */
   mfcc->param->veclen = para->veclen * mfcc->splice;
   
-  /* ǧ/λ˥åȤѿ:
-     param->parvec (ѥ᡼٥ȥ)
-     param->header.samplenum, param->samplenum (ե졼)
+  /* 認識処理中/終了後にセットされる変数:
+     param->parvec (パラメータベクトル系列)
+     param->header.samplenum, param->samplenum (全フレーム数)
   */
   /* variables that will be set while/after computation has been done:
      param->parvec (parameter vector sequence)
      param->header.samplenum, param->samplenum (total number of frames)
   */
-  /* MAP-CMN ν */
+  /* MAP-CMN の初期化 */
   /* Prepare for MAP-CMN */
   if (mfcc->para->cmn || mfcc->para->cvn) CMN_realtime_prepare(mfcc->cmn.wrk);
 }
 
 /** 
  * <JA>
- * @brief  1ѥʿǧν.
+ * @brief  第1パス平行認識処理の初期化.
  *
- * MFCC׻ΥꥢݤԤ. ޤɬפʾϡڥȥ븺Ѥ
- * ꥢΥڥȥΥɡCMNѤνץȥ
- * ʿѥǡΥɤʤɤԤ. 
+ * MFCC計算のワークエリア確保を行う. また必要な場合は，スペクトル減算用の
+ * ワークエリア準備，ノイズスペクトルのロード，CMN用の初期ケプストラム
+ * 平均データのロードなども行われる. 
  *
- * δؿϡƥ൯ư1ƤФ.
+ * この関数は，システム起動後1回だけ呼ばれる.
  * </JA>
  * <EN>
  * @brief  Initializations for the on-the-fly 1st pass decoding.
@@ -226,11 +226,11 @@ RealTimeInit(Recog *recog)
 
   r = &(recog->real);
 
-  /* ե졼Ĺϻֿ׻ */
+  /* 最大フレーム長を最大入力時間数から計算 */
   /* set maximum allowed frame length */
   r->maxframelen = MAXSPEECHLEN / recog->jconf->input.frameshift;
 
-  /* -ssload , SSѤΥΥڥȥե뤫ɤ߹ */
+  /* -ssload 指定時, SS用のノイズスペクトルをファイルから読み込む */
   /* if "-ssload", load noise spectrum for spectral subtraction from file */
   for(mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
     if (mfcc->frontend.ssload_filename && mfcc->frontend.ssbuf == NULL) {
@@ -253,14 +253,14 @@ RealTimeInit(Recog *recog)
   
     para = mfcc->para;
 
-    /* пͥ륮Τν */
+    /* 対数エネルギー正規化のための初期値 */
     /* set initial value for log energy normalization */
     if (para->energy && para->enormal) energy_max_init(&(mfcc->ewrk));
-    /* ǥ륿׻ΤΥХåեѰ */
+    /* デルタ計算のためのサイクルバッファを用意 */
     /* initialize cycle buffers for delta and accel coef. computation */
     if (para->delta) mfcc->db = WMP_deltabuf_new(para->baselen, para->delWin);
     if (para->acc) mfcc->ab = WMP_deltabuf_new(para->baselen * 2, para->accWin);
-    /* ǥ륿׻ΤΥꥢ */
+    /* デルタ計算のためのワークエリアを確保 */
     /* allocate work area for the delta computation */
     mfcc->tmpmfcc = (VECT *)mymalloc(sizeof(VECT) * para->vecbuflen);
     /* splice buffer */
@@ -268,10 +268,10 @@ RealTimeInit(Recog *recog)
       mfcc->splicedmfcc = (VECT *)mymalloc(sizeof(VECT) * para->veclen * mfcc->splice);
       mfcc->splicedlen = 0;
     }
-    /* MAP-CMN ѤνץȥʿѤɤ߹ǽ */
+    /* MAP-CMN 用の初期ケプストラム平均を読み込んで初期化する */
     /* Initialize the initial cepstral mean data from file for MAP-CMN */
     if (para->cmn || para->cvn) mfcc->cmn.wrk = CMN_realtime_new(para, mfcc->cmn.map_weight, mfcc->cmn.map_cmn);
-    /* -cmnload , CMNѤΥץȥʿѤνͤե뤫ɤ߹ */
+    /* -cmnload 指定時, CMN用のケプストラム平均の初期値をファイルから読み込む */
     /* if "-cmnload", load initial cepstral mean data from file for CMN */
     if (mfcc->cmn.load_filename) {
       if (para->cmn) {
@@ -285,10 +285,10 @@ RealTimeInit(Recog *recog)
     }
 
   }
-  /* Ĺ򥻥å */
+  /* 窓長をセット */
   /* set window length */
   r->windowlen = recog->jconf->input.framesize + 1;
-  /* 뤫ѥХåե */
+  /* 窓かけ用バッファを確保 */
   /* set window buffer */
   r->window = mymalloc(sizeof(SP16) * r->windowlen);
 
@@ -305,12 +305,12 @@ RealTimeInit(Recog *recog)
  * This function will be called before starting each input (segment).
  * </EN>
  * <JA>
- * MFCC׻. 
- * ĤΥꥢꥻåȤǧ. 
- * ޤǥ뤴ȤνϳΨ׻å. 
+ * MFCC計算を準備する. 
+ * いくつかのワークエリアをリセットして認識に備える. 
+ * また，音響モデルごとの出力確率計算キャッシュを準備する. 
  *
- * δؿϡϡʤ뤤ϥȡˤǧ
- * ϤޤɬƤФ. 
+ * この関数は，ある入力（あるいはセグメント）の認識が
+ * 始まる前に必ず呼ばれる. 
  * 
  * </JA>
  * 
@@ -325,16 +325,16 @@ reset_mfcc(Recog *recog)
   Value *para;
   MFCCCalc *mfcc;
 
-  /* ħХ⥸塼 */
+  /* 特徴抽出モジュールを初期化 */
   /* initialize parameter extraction module */
   for(mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
 
     para = mfcc->para;
 
-    /* пͥ륮Τνͤ򥻥å */
+    /* 対数エネルギー正規化のための初期値をセット */
     /* set initial value for log energy normalization */
     if (para->energy && para->enormal) energy_max_prepare(&(mfcc->ewrk), para);
-    /* ǥ륿׻ѥХåե */
+    /* デルタ計算用バッファを準備 */
     /* set the delta cycle buffer */
     if (para->delta) WMP_deltabuf_prepare(mfcc->db);
     if (para->acc) WMP_deltabuf_prepare(mfcc->ab);
@@ -345,11 +345,11 @@ reset_mfcc(Recog *recog)
 
 /** 
  * <JA>
- * @brief  1ѥʿǧν
+ * @brief  第1パス平行認識処理の準備
  *
- * ׻ѿꥻåȤƼǡ. 
- * δؿϡϡʤ뤤ϥȡˤǧ
- * Ϥޤ˸ƤФ. 
+ * 計算用変数をリセットし，各種データを準備する. 
+ * この関数は，ある入力（あるいはセグメント）の認識が
+ * 始まる前に呼ばれる. 
  * 
  * </JA>
  * <EN>
@@ -381,28 +381,28 @@ RealTimePipeLinePrepare(Recog *recog)
 
   r = &(recog->real);
 
-  /* ׻Ѥѿ */
+  /* 計算用の変数を初期化 */
   /* initialize variables for computation */
   r->windownum = 0;
   /* parameter check */
   for(mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
-    /* ѥ᡼ */
+    /* パラメータ初期化 */
     /* parameter initialization */
     if (recog->jconf->input.speech_input == SP_MFCMODULE) {
       if (mfc_module_set_header(mfcc, recog) == FALSE) return FALSE;
     } else {
       init_param(mfcc);
     }
-    /* ե졼ऴȤΥѥ᡼٥ȥ¸ΰ */
-    /* Ȥɬפ˱ƿĹ */
+    /* フレームごとのパラメータベクトル保存の領域を確保 */
+    /* あとで必要に応じて伸長される */
     if (param_alloc(mfcc->param, 1, mfcc->param->veclen) == FALSE) {
       j_internal_error("ERROR: segmented: failed to allocate memory for rest param\n");
     }
-    /* ե졼ꥻå */
+    /* フレーム数をリセット */
     /* reset frame count */
     mfcc->f = 0;
   }
-  /*  param ¤ΤΥǡΥѥ᡼򲻶ǥȥå */
+  /* 準備した param 構造体のデータのパラメータ型を音響モデルとチェックする */
   /* check type coherence between param and hmminfo here */
   if (recog->jconf->input.paramtype_check_flag) {
     for(am=recog->amlist;am;am=am->next) {
@@ -414,12 +414,12 @@ RealTimePipeLinePrepare(Recog *recog)
     }
   }
 
-  /* ׻ѤΥꥢ */
+  /* 計算用のワークエリアを準備 */
   /* prepare work area for calculation */
   if (recog->jconf->input.type == INPUT_WAVEFORM) {
     reset_mfcc(recog);
   }
-  /* ٷ׻ѥå */
+  /* 音響尤度計算用キャッシュを準備 */
   /* prepare cache area for acoustic computation of HMM states and mixtures */
   for(am=recog->amlist;am;am=am->next) {
     outprob_prepare(&(am->hmmwrk), r->maxframelen);
@@ -462,17 +462,17 @@ splice_mfcc(MFCCCalc *mfcc)
 
 /** 
  * <JA>
- * @brief  ȷѥ᡼٥ȥ׻.
+ * @brief  音声波形からパラメータベクトルを計算する.
  * 
- * ñ̤ǼФ줿ȷMFCC٥ȥ׻.
- * ׻̤ mfcc->tmpmfcc ¸. 
+ * 窓単位で取り出された音声波形からMFCCベクトルを計算する.
+ * 計算結果は mfcc->tmpmfcc に保存される. 
  * 
- * @param mfcc [i/o] MFCC׻󥹥
- * @param window [in] ñ̤ǼФ줿ȷǡ
- * @param windowlen [in] @a window Ĺ
+ * @param mfcc [i/o] MFCC計算インスタンス
+ * @param window [in] 窓単位で取り出された音声波形データ
+ * @param windowlen [in] @a window の長さ
  * 
- * @return ׻TRUE ֤. ǥ륿׻ˤϥե졼ब
- * ʤʤɡޤƤʤ FALSE ֤. 
+ * @return 計算成功時，TRUE を返す. デルタ計算において入力フレームが
+ * 少ないなど，まだ得られていない場合は FALSE を返す. 
  * </JA>
  * <EN>
  * @brief  Compute a parameter vector from a speech window.
@@ -503,7 +503,7 @@ RealTimeMFCC(MFCCCalc *mfcc, SP16 *window, int windowlen)
   tmpmfcc = mfcc->tmpmfcc;
   para = mfcc->para;
 
-  /* ȷ base MFCC ׻ (recog->mfccwrk ) */
+  /* 音声波形から base MFCC を計算 (recog->mfccwrk を利用) */
   /* calculate base MFCC from waveform (use recog->mfccwrk) */
   for (i=0; i < windowlen; i++) {
     mfcc->wrk->bf[i+1] = (float) window[i];
@@ -511,10 +511,10 @@ RealTimeMFCC(MFCCCalc *mfcc, SP16 *window, int windowlen)
   WMP_calc(mfcc->wrk, tmpmfcc, para);
 
   if (para->energy && para->enormal) {
-    /* пͥ륮 */
+    /* 対数エネルギー項を正規化する */
     /* normalize log energy */
-    /* ꥢ륿ϤǤȯäȤκ票ͥ륮ʤΤ
-       ľȯäΥѥѤ */
+    /* リアルタイム入力では発話ごとの最大エネルギーが得られないので
+       直前の発話のパワーで代用する */
     /* Since the maximum power of the whole input utterance cannot be
        obtained at real-time input, the maximum of last input will be
        used to normalize.
@@ -523,7 +523,7 @@ RealTimeMFCC(MFCCCalc *mfcc, SP16 *window, int windowlen)
   }
 
   if (para->delta) {
-    /* ǥ륿׻ */
+    /* デルタを計算する */
     /* calc delta coefficients */
     ret = WMP_deltabuf_proceed(mfcc->db, tmpmfcc);
 #ifdef RDEBUG
@@ -533,22 +533,22 @@ RealTimeMFCC(MFCCCalc *mfcc, SP16 *window, int windowlen)
     }
     printf(", nextstore=%d\n", mfcc->db->store);
 #endif
-    /* ret == FALSE ΤȤϤޤǥ쥤ʤΤǧϤ */
+    /* ret == FALSE のときはまだディレイ中なので認識処理せず次入力へ */
     /* if ret == FALSE, there is no available frame.  So just wait for
        next input */
     if (! ret) {
       return FALSE;
     }
 
-    /* db->vec ˸ߤθǡȥǥ륿äƤΤ tmpmfcc ˥ԡ */
+    /* db->vec に現在の元データとデルタ係数が入っているので tmpmfcc にコピー */
     /* now db->vec holds the current base and full delta, so copy them to tmpmfcc */
     memcpy(tmpmfcc, mfcc->db->vec, sizeof(VECT) * para->baselen * 2);
   }
 
   if (para->acc) {
-    /* Acceleration׻ */
+    /* Accelerationを計算する */
     /* calc acceleration coefficients */
-    /* base+delta 򤽤Τޤ */
+    /* base+delta をそのまま入れる */
     /* send the whole base+delta to the cycle buffer */
     ret = WMP_deltabuf_proceed(mfcc->ab, tmpmfcc);
 #ifdef RDEBUG
@@ -558,15 +558,15 @@ RealTimeMFCC(MFCCCalc *mfcc, SP16 *window, int windowlen)
     }
     printf(", nextstore=%d\n", mfcc->ab->store);
 #endif
-    /* ret == FALSE ΤȤϤޤǥ쥤ʤΤǧϤ */
+    /* ret == FALSE のときはまだディレイ中なので認識処理せず次入力へ */
     /* if ret == FALSE, there is no available frame.  So just wait for
        next input */
     if (! ret) {
       return FALSE;
     }
-    /* ab->vec ˤϡ(base+delta) ȤκʬäƤ. 
-       [base] [delta] [delta] [acc] νäƤΤ,
-       [base] [delta] [acc]  tmpmfcc ˥ԡ. */
+    /* ab->vec には，(base+delta) とその差分係数が入っている. 
+       [base] [delta] [delta] [acc] の順で入っているので,
+       [base] [delta] [acc] を tmpmfcc にコピーする. */
     /* now ab->vec holds the current (base+delta) and their delta coef. 
        it holds a vector in the order of [base] [delta] [delta] [acc], 
        so copy the [base], [delta] and [acc] to tmpmfcc.  */
@@ -581,15 +581,15 @@ RealTimeMFCC(MFCCCalc *mfcc, SP16 *window, int windowlen)
 #endif
 
   if (para->delta && (para->energy || para->c0) && para->absesup) {
-    /* ͥѥ */
+    /* 絶対値パワーを除去 */
     /* suppress absolute power */
     memmove(&(tmpmfcc[para->baselen-1]), &(tmpmfcc[para->baselen]), sizeof(VECT) * (para->vecbuflen - para->baselen));
   }
 
-  /* λ tmpmfcc ˸Ǥκǿħ٥ȥ뤬ǼƤ */
+  /* この時点で tmpmfcc に現時点での最新の特徴ベクトルが格納されている */
   /* tmpmfcc[] now holds the latest parameter vector */
 
-  /* CMN ׻ */
+  /* CMN を計算 */
   /* perform CMN */
   if (para->cmn || para->cvn) CMN_realtime(mfcc->cmn.wrk, tmpmfcc);
 
@@ -643,7 +643,7 @@ proceed_one_frame(Recog *recog)
       recog->triggered = TRUE;
     }
   }
-  /* ƥ󥹥󥹤ˤĤ mfcc->f ǧ1ե졼ʤ */
+  /* 各インスタンスについて mfcc->f の認識処理を1フレーム進める */
   switch (decode_proceed(recog)) {
   case -1: /* error */
     return -1;
@@ -651,11 +651,11 @@ proceed_one_frame(Recog *recog)
   case 0:			/* success */
     break;
   case 1:			/* segmented */
-    /* ǧΥ׵ǽäȤե饰˥å */
+    /* 認識処理のセグメント要求で終わったことをフラグにセット */
     /* set flag which indicates that the input has ended with segmentation request */
     r->last_is_segmented = TRUE;
     /* tell the caller to be segmented by this function */
-    /* ƤӽФˡϤڤ褦 */
+    /* 呼び出し元に，ここで入力を切るよう伝える */
     return 1;
   }
 #ifdef BACKEND_VAD
@@ -704,7 +704,7 @@ proceed_one_frame(Recog *recog)
 	  }
 	}
 	if (ok_p) {
-	  /* ٤Ƥ MFCC ãΤǥ롼׽λ */
+	  /* すべての MFCC が終わりに達したのでループ終了 */
 	  /* all MFCC has been processed, end of loop  */
 	  for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
 	    if (! mfcc->valid) continue;
@@ -712,7 +712,7 @@ proceed_one_frame(Recog *recog)
 	  }
 	  break;
 	}
-	/* ƥ󥹥󥹤ˤĤ mfcc->f ǧ1ե졼ʤ */
+	/* 各インスタンスについて mfcc->f の認識処理を1フレーム進める */
 	switch (decode_proceed(recog)) {
 	case -1: /* error */
 	  return -1;
@@ -742,33 +742,33 @@ proceed_one_frame(Recog *recog)
 
 /** 
  * <JA>
- * @brief  1ѥʿԲǧΥᥤ
+ * @brief  第1パス平行音声認識処理のメイン
  *
- * δؿǤϡŪħФ1ѥǧԤ. 
- * ϥǡФݤեȤԤMFCC׻Ԥʤ顤
- * ǧ1ե졼ऺ¹Ԥ. 
+ * この関数内では，漸次的な特徴量抽出および第1パスの認識が行われる. 
+ * 入力データに対して窓掛け・シフトを行いMFCC計算を行いながら，
+ * 音声認識を1フレームずつ並列実行する. 
  *
- * ǧdecode_proceed()ˤˤơֽλ׵ᤵ
- * Ȥ. ξ硤̤β¸1ѥλ
- * 褦ƽи׵᤹. 
+ * 認識処理（decode_proceed()）において，音声区間終了が要求される
+ * ことがある. この場合，未処理の音声を保存して第1パスを終了する
+ * よう呼出元に要求する. 
  *
- * SPSEGMENT_NAIST 뤤 GMM_VAD ʤɤΥХåVADϡǥ١
- * VAD ʲֳϸСˤȼǥǥ椬Ԥ. 
- * ȥꥬϡǧƤФ뤬ºݤˤϳƴؿǧ
- * ԤƤʤ. Ϥ򸡽ФδؿϤޤǤ줿
- * MFCCե졼Ĺʬᤷδᤷ褫̾ǧ
- * Ƴ. ʤʣ󥹥󥹴֤硤ϥȥꥬ
- * ɤ줫Υ󥹥󥹤ФƤγϤƱ. 
+ * SPSEGMENT_NAIST あるいは GMM_VAD などのバックエンドVAD定義時は，デコーダベースの
+ * VAD （音声区間開始検出）に伴うデコーディング制御が行われる. 
+ * トリガ前は，認識処理が呼ばれるが，実際には各関数内で認識処理は
+ * 行われていない. 開始を検出した時，この関数はそこまでに得られた
+ * MFCC列を一定フレーム長分巻戻し，その巻戻し先から通常の認識処理を
+ * 再開する. なお，複数処理インスタンス間がある場合，開始トリガは
+ * どれかのインスタンスが検出した時点で全ての開始が同期される. 
  * 
- * δؿϡϥ롼ΥХåȤƸƤФ.
- * ǡο饵ץϿȤˤδؿƤӽФ. 
+ * この関数は，音声入力ルーチンのコールバックとして呼ばれる.
+ * 音声データの数千サンプル録音ごとにこの関数が呼び出される. 
  * 
- * @param Speech [in] ǡؤΥХåեؤΥݥ
- * @param nowlen [in] ǡĹ
+ * @param Speech [in] 音声データへのバッファへのポインタ
+ * @param nowlen [in] 音声データの長さ
  * @param recog [i/o] engine instance
  * 
- * @return 顼 -1  0 ֤. ޤ1ѥ
- * λ褦ƽи׵᤹Ȥ 1 ֤. 
+ * @return エラー時に -1 を，正常時に 0 を返す. また，第1パスを
+ * 終了するよう呼出元に要求するときは 1 を返す. 
  * </JA>
  * <EN>
  * @brief  Main function of the on-the-fly 1st pass decoding
@@ -824,14 +824,14 @@ RealTimePipeLine(SP16 *Speech, int nowlen, Recog *recog) /* Speech[0...nowlen] =
   adin_cut_callback_store_buffer(Speech, nowlen, recog);
 #endif
 
-  /* window[0..windownum-1] θƤӽФǻĤäǡǼƤ */
+  /* window[0..windownum-1] は前回の呼び出しで残った音声データが格納されている */
   /* window[0..windownum-1] are speech data left from previous call */
 
-  /* ѥݥ󥿤 */
+  /* 処理用ポインタを初期化 */
   /* initialize pointer for local processing */
   now = 0;
   
-  /* ǧ׵ǽäΤɤΥե饰ꥻå */
+  /* 認識処理がセグメント要求で終わったのかどうかのフラグをリセット */
   /* reset flag which indicates whether the input has ended with segmentation request */
   r->last_is_segmented = FALSE;
 
@@ -840,7 +840,7 @@ RealTimePipeLine(SP16 *Speech, int nowlen, Recog *recog) /* Speech[0...nowlen] =
 #endif
 
   while (now < nowlen) {	/* till whole input is processed */
-    /* Ĺ maxframelen ã餳Ƕλ */
+    /* 入力長が maxframelen に達したらここで強制終了 */
     /* if input length reaches maximum buffer size, terminate 1st pass here */
     for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
       if (mfcc->f >= r->maxframelen) {
@@ -848,12 +848,12 @@ RealTimePipeLine(SP16 *Speech, int nowlen, Recog *recog) /* Speech[0...nowlen] =
 	return(1);
       }
     }
-    /* Хåե */
+    /* 窓バッファを埋められるだけ埋める */
     /* fill window buffer as many as possible */
     for(i = min(r->windowlen - r->windownum, nowlen - now); i > 0 ; i--)
       r->window[r->windownum++] = (float) Speech[now++];
-    /* ⤷Хåեޤʤ, ΥȤνϤǽ. 
-       ʤäץ (window[0..windownum-1]) ϼ˻ۤ. */
+    /* もし窓バッファが埋まらなければ, このセグメントの処理はここで終わる. 
+       処理されなかったサンプル (window[0..windownum-1]) は次回に持ち越し. */
     /* if window buffer was not filled, end processing here, keeping the
        rest samples (window[0..windownum-1]) in the window buffer. */
     if (r->windownum < r->windowlen) break;
@@ -865,7 +865,7 @@ RealTimePipeLine(SP16 *Speech, int nowlen, Recog *recog) /* Speech[0...nowlen] =
 
     for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
       mfcc->valid = FALSE;
-      /* βȷħ̤׻ r->tmpmfcc ˳Ǽ  */
+      /* 窓内の音声波形から特徴量を計算して r->tmpmfcc に格納  */
       /* calculate a parameter vector from current waveform windows
 	 and store to r->tmpmfcc */
       if ((*(recog->calc_vector))(mfcc, r->window, r->windowlen)) {
@@ -878,7 +878,7 @@ RealTimePipeLine(SP16 *Speech, int nowlen, Recog *recog) /* Speech[0...nowlen] =
 	/* call post-process plugin if exist */
 	plugin_exec_vector_postprocess(mfccvec, mfcc->param->veclen, mfcc->f);
 #endif
-	/* MFCCϿ */
+	/* MFCC完成，登録 */
   	mfcc->valid = TRUE;
 	/* now get the MFCC vector of current frame, now store it to param */
 	if (param_alloc(mfcc->param, mfcc->f + 1, mfcc->param->veclen) == FALSE) {
@@ -892,13 +892,13 @@ RealTimePipeLine(SP16 *Speech, int nowlen, Recog *recog) /* Speech[0...nowlen] =
       }
     }
 
-    /* 1ե졼ʤ */
+    /* 処理を1フレーム進める */
     /* proceed one frame */
     ret = proceed_one_frame(recog);
 
     if (ret == 1 && recog->jconf->decodeopt.segment) {
-      /* 硼ȥݡơ: Хåե˻ĤäƤǡ
-	 ̤ݻơκǽ˽ */
+      /* ショートポーズセグメンテーション: バッファに残っているデータを
+	 別に保持して，次回の最初に処理する */
       /* short pause segmentation: there is some data left in buffer, so
 	 we should keep them for next processing */
       r->rest_len = nowlen - now;
@@ -916,21 +916,21 @@ RealTimePipeLine(SP16 *Speech, int nowlen, Recog *recog) /* Speech[0...nowlen] =
     }
     if (ret != 0) return ret;
 
-    /* 1ե졼ʤΤǥݥ󥿤ʤ */
+    /* 1フレーム処理が進んだのでポインタを進める */
     /* proceed frame pointer */
     for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
       if (!mfcc->valid) continue;
       mfcc->f++;
     }
 
-    /* Хåեäʬե */
+    /* 窓バッファを処理が終わった分シフト */
     /* shift window */
     memmove(r->window, &(r->window[recog->jconf->input.frameshift]), sizeof(SP16) * (r->windowlen - recog->jconf->input.frameshift));
     r->windownum -= recog->jconf->input.frameshift;
   }
 
-  /* Ϳ줿ȤФǧƽλ
-     ƤӽФ, Ϥ³褦 */
+  /* 与えられた音声セグメントに対する認識処理が全て終了
+     呼び出し元に, 入力を続けるよう伝える */
   /* input segment is fully processed
      tell the caller to continue input */
   return(0);			
@@ -938,18 +938,18 @@ RealTimePipeLine(SP16 *Speech, int nowlen, Recog *recog) /* Speech[0...nowlen] =
 
 /** 
  * <JA>
- * @brief  ȤǧƳ
+ * @brief  セグメントの認識再開処理
  *
- * δؿϥǥ١VAD䥷硼ȥݡơˤä
- * ϤȤڤ줿ˡθǧκƳ˴ؤԤ. 
- * ŪˤϡϤǧ򳫻ϤˡϥȤˤ
- * ᤷʬMFCC󤫤ǧ򳫻Ϥ. ˡΥơ
- * ̤äĤβץ뤬Ф.
+ * この関数はデコーダベースVADやショートポーズセグメンテーションによって
+ * 入力がセグメントに切られた場合に，その後の認識の再開に関する処理を行う. 
+ * 具体的には，入力の認識を開始する前に，前回の入力セグメントにおける
+ * 巻戻し分のMFCC列から認識を開始する. さらに，前回のセグメンテーション時に
+ * 未処理だった残りの音声サンプルがあればそれも処理する.
  *
- * @param recog [i/o] 󥸥󥤥󥹥
+ * @param recog [i/o] エンジンインスタンス
  * 
- * @return 顼 -1 0 ֤. ޤҤν
- * ʸϤζڤ꤬ĤäȤ1ѥ򤳤Ǥ뤿 1 ֤. 
+ * @return エラー時 -1，正常時 0 を返す. また，この入力断片の処理中に
+ * 文章の区切りが見つかったときは第1パスをここで中断するために 1 を返す. 
  * </JA>
  * </JA>
  * <EN>
@@ -982,18 +982,18 @@ RealTimeResume(Recog *recog)
 
   r = &(recog->real);
 
-  /* ׻ѤΥꥢ */
+  /* 計算用のワークエリアを準備 */
   /* prepare work area for calculation */
   if (recog->jconf->input.type == INPUT_WAVEFORM) {
     reset_mfcc(recog);
   }
-  /* ٷ׻ѥå */
+  /* 音響尤度計算用キャッシュを準備 */
   /* prepare cache area for acoustic computation of HMM states and mixtures */
   for(am=recog->amlist;am;am=am->next) {
     outprob_prepare(&(am->hmmwrk), r->maxframelen);
   }
 
-  /* param ˤѥ᡼ */
+  /* param にある全パラメータを処理する準備 */
   /* prepare to process all data in param */
   for(mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
     if (mfcc->param->samplenum == 0) mfcc->valid = FALSE;
@@ -1001,10 +1001,10 @@ RealTimeResume(Recog *recog)
 #ifdef RDEBUG
     printf("Resume: %02d: f=%d\n", mfcc->id, mfcc->mfcc->param->samplenum-1);
 #endif
-    /* ե졼ꥻå */
+    /* フレーム数をリセット */
     /* reset frame count */
     mfcc->f = 0;
-    /* MAP-CMN ν */
+    /* MAP-CMN の初期化 */
     /* Prepare for MAP-CMN */
     if (mfcc->para->cmn || mfcc->para->cvn) CMN_realtime_prepare(mfcc->cmn.wrk);
   }
@@ -1025,7 +1025,7 @@ RealTimeResume(Recog *recog)
   }
 #endif
 
-  /* param ե졼ˤĤǧʤ */
+  /* param 内の全フレームについて認識処理を進める */
   /* proceed recognition for all frames in param */
 
   while(1) {
@@ -1040,12 +1040,12 @@ RealTimeResume(Recog *recog)
       }
     }
     if (ok_p) {
-      /* ٤Ƥ MFCC ãΤǥ롼׽λ */
+      /* すべての MFCC が終わりに達したのでループ終了 */
       /* all MFCC has been processed, end of loop  */
       break;
     }
 
-    /* ƥ󥹥󥹤ˤĤ mfcc->f ǧ1ե졼ʤ */
+    /* 各インスタンスについて mfcc->f の認識処理を1フレーム進める */
     switch (decode_proceed(recog)) {
     case -1: /* error */
       return -1;
@@ -1074,7 +1074,7 @@ RealTimeResume(Recog *recog)
     /* call frame-wise callback */
     callback_exec(CALLBACK_EVENT_PASS1_FRAME, recog);
 
-    /* 1ե졼ʤΤǥݥ󥿤ʤ */
+    /* 1フレーム処理が進んだのでポインタを進める */
     /* proceed frame pointer */
     for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
       if (!mfcc->valid) continue;
@@ -1082,13 +1082,13 @@ RealTimeResume(Recog *recog)
     }
 
   }
-  /* ΥȻϤ򥷥եȤƤʤʬ򥷥եȤ */
+  /* 前回のセグメント時に入力をシフトしていない分をシフトする */
   /* do the last shift here */
   if (recog->jconf->input.type == INPUT_WAVEFORM) {
     memmove(r->window, &(r->window[recog->jconf->input.frameshift]), sizeof(SP16) * (r->windowlen - recog->jconf->input.frameshift));
     r->windownum -= recog->jconf->input.frameshift;
-    /* ǺƳνäΤ,ޤνǻĤäƤǡ
-        */
+    /* これで再開の準備が整ったので,まずは前回の処理で残っていた音声データから
+       処理する */
     /* now that the search status has been prepared for the next input, we
        first process the rest unprocessed samples at the last session */
     if (r->rest_len > 0) {
@@ -1096,7 +1096,7 @@ RealTimeResume(Recog *recog)
     }
   }
 
-  /* ϤФǧ³ */
+  /* 新規の入力に対して認識処理は続く… */
   /* the recognition process will continue for the newly incoming samples... */
   return 0;
 
@@ -1105,19 +1105,19 @@ RealTimeResume(Recog *recog)
 
 /** 
  * <JA>
- * @brief  1ѥʿǧνλԤ.
+ * @brief  第1パス平行認識処理の終了処理を行う.
  *
- * δؿ1ѥλ˸ƤФ졤Ĺꤷȡ
- * decode_end() ʥȤǽλȤ decode_end_segmented()ˤ
- * ƤӽФ1ѥλԤ. 
+ * この関数は第1パス終了時に呼ばれ，入力長を確定したあと，
+ * decode_end() （セグメントで終了したときは decode_end_segmented()）を
+ * 呼び出して第1パス終了処理を行う. 
  *
- * ⤷ϥȥ꡼νλˤäǧäʥեϤ
- * üãʤɡˤϡǥ륿Хåե̤ϤĤäƤΤǡ
- * 򤳤ǽ. 
+ * もし音声入力ストリームの終了によって認識が終わった場合（ファイル入力で
+ * 終端に達した場合など）は，デルタバッファに未処理の入力が残っているので，
+ * それをここで処理する. 
  *
- * @param recog [i/o] 󥸥󥤥󥹥
+ * @param recog [i/o] エンジンインスタンス
  * 
- * @return  TRUE, 顼 FALSE ֤. 
+ * @return 処理成功時 TRUE, エラー時 FALSE を返す. 
  * </JA>
  * <EN>
  * @brief  Finalize the 1st pass on-the-fly decoding.
@@ -1155,9 +1155,9 @@ RealTimeParam(Recog *recog)
 
   if (r->last_is_segmented) {
 
-    /* RealTimePipeLine ǧ¦ͳˤǧǤ,
-       ֤MFCC׻ǡ򤽤Τޤ޼ݻɬפΤ,
-       MFCC׻λԤ鷺裱ѥη̤Τ߽Ϥƽ. */
+    /* RealTimePipeLine で認識処理側の理由により認識が中断した場合,
+       現状態のMFCC計算データをそのまま次回へ保持する必要があるので,
+       MFCC計算終了処理を行わずに第１パスの結果のみ出力して終わる. */
     /* When input segmented by recognition process in RealTimePipeLine(),
        we have to keep the whole current status of MFCC computation to the
        next call.  So here we only output the 1st pass result. */
@@ -1167,7 +1167,7 @@ RealTimeParam(Recog *recog)
     }
     decode_end_segmented(recog);
 
-    /* ζ֤ param ǡ裲ѥΤ֤ */
+    /* この区間の param データを第２パスのために返す */
     /* return obtained parameter for 2nd pass */
     return(TRUE);
   }
@@ -1178,12 +1178,12 @@ RealTimeParam(Recog *recog)
       mfcc->param->header.samplenum = mfcc->f;
       mfcc->param->samplenum = mfcc->f;
     }
-    /* ǽե졼Ԥǧη̽ϤȽλԤ */
+    /* 最終フレーム処理を行い，認識の結果出力と終了処理を行う */
     decode_end(recog);
     return TRUE;
   }
 
-  /* MFCC׻νλԤ: Ǹٱե졼ʬ */
+  /* MFCC計算の終了処理を行う: 最後の遅延フレーム分を処理 */
   /* finish MFCC computation for the last delayed frames */
   for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
     if (mfcc->para->delta || mfcc->para->acc) {
@@ -1379,7 +1379,7 @@ RealTimeParam(Recog *recog)
     mfcc->param->header.samplenum = mfcc->f;
     mfcc->param->samplenum = mfcc->f;
   }
-  /* ǽե졼Ԥǧη̽ϤȽλԤ */
+  /* 最終フレーム処理を行い，認識の結果出力と終了処理を行う */
   decode_end(recog);
 
   return(TRUE);
@@ -1387,11 +1387,11 @@ RealTimeParam(Recog *recog)
 
 /** 
  * <JA>
- * ץȥʿѤι. 
- * ǧơϥǡCMNѤΥץȥʿѤ򹹿. 
+ * ケプストラム平均の更新. 
+ * 次回の認識に備えて，入力データからCMN用のケプストラム平均を更新する. 
  * 
- * @param mfcc [i/o] ׻оݤ MFCC׻󥹥
- * @param recog [i/o] 󥸥󥤥󥹥
+ * @param mfcc [i/o] 計算対象の MFCC計算インスタンス
+ * @param recog [i/o] エンジンインスタンス
  *
  * </JA>
  * <EN>
@@ -1451,9 +1451,9 @@ RealTimeCMNUpdate(MFCCCalc *mfcc, Recog *recog)
 
 /** 
  * <JA>
- * 1ѥʿǧǤ. 
+ * 第1パス平行認識処理を中断する. 
  *
- * @param recog [i/o] 󥸥󥤥󥹥
+ * @param recog [i/o] エンジンインスタンス
  * </JA>
  * <EN>
  * Terminate the 1st pass on-the-fly decoding.
@@ -1471,7 +1471,7 @@ RealTimeTerminate(Recog *recog)
     mfcc->param->samplenum = mfcc->f;
   }
 
-  /* ǽե졼Ԥǧη̽ϤȽλԤ */
+  /* 最終フレーム処理を行い，認識の結果出力と終了処理を行う */
   decode_end(recog);
 }
 
@@ -1480,7 +1480,7 @@ RealTimeTerminate(Recog *recog)
  * Free the whole work area for 1st pass on-the-fly decoding
  * </EN>
  * <JA>
- * 1ѥ¹ԽΤΥꥢ
+ * 第1パス並行処理のためのワークエリアを開放する
  * </JA>
  * 
  * @param recog [in] engine instance
@@ -1564,7 +1564,7 @@ mfcc_go(Recog *recog, int (*ad_check)(Recog *))
       plugin_exec_vector_postprocess(recog->mfcclist->param->parvec[recog->mfcclist->f], recog->mfcclist->param->veclen, recog->mfcclist->f);
 #endif
 
-      /* 1ե졼ʤ */
+      /* 処理を1フレーム進める */
       /* proceed one frame */
       
       switch(proceed_one_frame(recog)) {
@@ -1576,7 +1576,7 @@ mfcc_go(Recog *recog, int (*ad_check)(Recog *))
 	return 2;
       }
 
-      /* 1ե졼ʤΤǥݥ󥿤ʤ */
+      /* 1フレーム処理が進んだのでポインタを進める */
       /* proceed frame pointer */
       for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
 	if (!mfcc->valid) continue;
@@ -1594,8 +1594,8 @@ mfcc_go(Recog *recog, int (*ad_check)(Recog *))
       return 1;
     }
   }
-  /* Ϳ줿ȤФǧƽλ
-     ƤӽФ, Ϥ³褦 */
+  /* 与えられた音声セグメントに対する認識処理が全て終了
+     呼び出し元に, 入力を続けるよう伝える */
   /* input segment is fully processed
      tell the caller to continue input */
   return(1);
