@@ -2,15 +2,15 @@
  * @file   wchmm.c
  * 
  * <JA>
- * @brief  ڹ¤ι
+ * @brief  木構造化辞書の構築
  *
- * ǤϡͿ줿ñ켭, HMMӸ󤫤ڹ¤
- * ۤؿƤޤ. ڹ¤ϵư˹ۤ졤
- * 1ѥǧѤޤ. ڹ¤Ͼñ̤ǹ졤
- * ƾ֤HMMϳΨ¾õΤ͡ʾޤߤޤ. 
+ * ここでは，与えられた単語辞書, HMM定義および言語制約から木構造化辞書を
+ * 構築する関数が定義されています. 木構造化辞書は起動時に構築され，
+ * 第1パスの認識に用いられます. 木構造化辞書は状態単位で構成され，
+ * 各状態はHMM出力確率と遷移先の他，および探索のための様々な情報を含みます. 
  *
- * ȯηа޾塤Ǥڹ¤ wchmm (word-conjunction HMM) 
- * ɽƤޤ. 
+ * 開発の経緯上，ソース内では木構造化辞書は wchmm (word-conjunction HMM) と
+ * も表現されています. 
  * 
  * </JA>
  * 
@@ -54,9 +54,9 @@
 
 /** 
  * <JA>
- * ڹ¤¤Τ򿷵˳դ. 
+ * 木構造化辞書構造体を新規に割り付ける. 
  * 
- * @return ˥˳դ줿ڹ¤¤ΤؤΥݥ󥿤֤. 
+ * @return 新たにメモリ上に割り付けられた木構造化辞書構造体へのポインタを返す. 
  * </JA>
  * <EN>
  * Allocate a new tree lexicon structure.
@@ -75,6 +75,7 @@ wchmm_new()
   w->lmvar  = LM_UNDEF;
   w->ngram = NULL;
   w->dfa = NULL;
+  w->dfa_forward = NULL;
   w->winfo = NULL;
   w->malloc_root = NULL;
 #ifdef PASS1_IWCD
@@ -90,9 +91,9 @@ wchmm_new()
 
 /** 
  * <JA>
- * ڹ¤Ƥ. 
+ * 木構造化辞書の内容を初期化する. 
  * 
- * @param wchmm [out] ڹ¤ؤΥݥ
+ * @param wchmm [out] 木構造化辞書へのポインタ
  * </JA>
  * <EN>
  * Initialize content of a lexicon tree.
@@ -149,9 +150,9 @@ wchmm_init(WCHMM_INFO *wchmm)
 
 /** 
  * <JA>
- * ڹ¤ξֳǼΰ MAXWCNSTEP ʬĹ. 
+ * 木構造化辞書の状態格納領域を MAXWCNSTEP 分だけ伸長する. 
  * 
- * @param wchmm [i/o] ڹ¤
+ * @param wchmm [i/o] 木構造化辞書
  * </JA>
  * <EN>
  * Expand state-related area in a tree lexicon by MAXWCNSTEP.
@@ -176,9 +177,9 @@ wchmm_extend(WCHMM_INFO *wchmm)
 
 /** 
  * <JA>
- * ڹ¤ñƬΡɳǼΰ STARTNODE_STEPʬĹ.  (multipath)
+ * 木構造化辞書の単語先頭ノード格納領域を STARTNODE_STEP分だけ伸長する.  (multipath)
  * 
- * @param wchmm [i/o] ڹ¤
+ * @param wchmm [i/o] 木構造化辞書
  * </JA>
  * <EN>
  * Expand word-start nodes area in a tree lexicon by STARTNODE_STEP. (multipath)
@@ -198,9 +199,9 @@ wchmm_extend_startnode(WCHMM_INFO *wchmm)
 
 /** 
  * <JA>
- * ڹ¤񤪤ӤγեƲ. 
+ * 木構造化辞書およびその内部の割付メモリを全て解放する. 
  * 
- * @param w [in] ڹ¤
+ * @param w [in] 木構造化辞書
  * </JA>
  * <EN>
  * Free all data in a tree lexicon.
@@ -266,12 +267,12 @@ wchmm_free(WCHMM_INFO *w)
 
 /** 
  * <JA>
- * ñǤΤʤӤǥȤqsort_reentrantؿ
+ * 単語を音素のならびでソートするqsort_reentrant関数
  * 
- * @param widx1 [in] ñID 1 ؤΥݥ
- * @param widx2 [in] ñID 2 ؤΥݥ
+ * @param widx1 [in] 単語ID 1 へのポインタ
+ * @param widx2 [in] 単語ID 2 へのポインタ
  * 
- * @return ñwidx2ñwidx1ΰǤ 1, ñwidx1ñwidx2ΰǤ -1, Ʊ¤ӤǤ 0 ֤. 
+ * @return 単語widx2が単語widx1の一部か昇順であれば 1, 単語widx1が単語widx2の一部か昇順であれば -1, 全く同じ音素並びであれば 0 を返す. 
  * </JA>
  * <EN>
  * qsort_reentrant function to sort words by their phoneme sequence.
@@ -315,12 +316,12 @@ compare_wseq(WORD_ID *widx1, WORD_ID *widx2, WORD_INFO *winfo)
 
 /** 
  * <JA>
- * ñIDν windex[bgn..bgn+len-1] ñβǤʤӤǥȤ. 
+ * 単語IDの集合 windex[bgn..bgn+len-1] を単語の音素ならびでソートする. 
  * 
- * @param winfo [in] ñ켭
- * @param windex [i/o] ñIDΥǥåǥȤ
- * @param bgn [in] @a windex Υȳ
- * @param len [in] @a windex  @a bgn ΥȤǿ
+ * @param winfo [in] 単語辞書
+ * @param windex [i/o] 単語IDのインデックス列（内部でソートされる）
+ * @param bgn [in] @a windex のソート開始点
+ * @param len [in] @a windex の @a bgn からのソートする要素数
  * </JA>
  * <EN>
  * Sort word IDs in windex[bgn..bgn+len-1] by their phoneme sequence order.
@@ -339,10 +340,10 @@ wchmm_sort_idx_by_wseq(WORD_INFO *winfo, WORD_ID *windex, WORD_ID bgn, WORD_ID l
 
 /** 
  * <JA>
- * ñ򥫥ƥIDǥȤqsortؿ. 
+ * 単語をカテゴリIDでソートするqsort関数. 
  * 
- * @param widx1 [in] 1ؤΥݥ
- * @param widx2 [in] 2ؤΥݥ
+ * @param widx1 [in] 要素1へのポインタ
+ * @param widx2 [in] 要素2へのポインタ
  * 
  * @return 
  * </JA>
@@ -366,11 +367,11 @@ compare_category(WORD_ID *widx1, WORD_ID *widx2, WORD_INFO *winfo)
 
 /** 
  * <JA>
- * ñID windex[0..len-1] 򥫥ƥIDǥȤ. 
+ * 単語ID集合 windex[0..len-1] をカテゴリIDでソートする. 
  * 
- * @param winfo [in] ñ켭
- * @param windex [i/o] ñIDΥǥåǥȤ
- * @param len [in] @a windex ǿ
+ * @param winfo [in] 単語辞書
+ * @param windex [i/o] 単語IDのインデックス列（内部でソートされる）
+ * @param len [in] @a windex の要素数
  * </JA>
  * <EN>
  * Sort word IDs in windex[0..len-1] by their category ID.
@@ -393,13 +394,13 @@ wchmm_sort_idx_by_category(WORD_INFO *winfo, WORD_ID *windex, WORD_ID len)
 
 /** 
  * <JA>
- * ñ֤ǡñƬƱǶͭǽʲǤοĴ٤. 
+ * ２単語間で，単語の先頭から同一で共有可能な音素の数を調べる. 
  * 
- * @param winfo [in] ñ켭
- * @param i [in] ñ죱
- * @param j [in] ñ죲
+ * @param winfo [in] 単語辞書
+ * @param i [in] 単語１
+ * @param j [in] 単語２
  * 
- * @return ͭǽƬβǿ֤. 
+ * @return 共有可能な先頭からの音素数を返す. 
  * </JA>
  * <EN>
  * Compare two words from word head per phoneme to see how many phones
@@ -432,7 +433,7 @@ wchmm_check_match(WORD_INFO *winfo, int i, int j)
  * Initialize transition information on a node.
  * </EN>
  * <JA>
- * Ρɤܾ. 
+ * ノードの遷移情報を初期化する. 
  * </JA>
  * 
  * @param wchmm [i/o] tree lexicon
@@ -453,8 +454,8 @@ acc_init(WCHMM_INFO *wchmm, int node)
  * This function is for transition other than self and next node.
  * </EN>
  * <JA>
- * Ρɤܤɲä. 
- * δؿϼܡ٤ؤܰʳξ˻Ѥ. 
+ * ノードに遷移を追加する. 
+ * この関数は自己遷移・隣への遷移以外の場合に使用される. 
  * </JA>
  * 
  * @param wchmm [i/o] tree lexicon
@@ -484,12 +485,12 @@ add_ac(WCHMM_INFO *wchmm, int node, LOGPROB a, int arc)
 
 /** 
  * <JA>
- * ڹ¤ΤΡɤˡ̤ΥΡɤؤܤɲä
+ * 木構造化辞書のあるノードに，別のノードへの遷移を追加する
  * 
- * @param wchmm [i/o] ڹ¤
- * @param node [in] Ρֹ
- * @param a [in] ܳΨп
- * @param arc [in] ΥΡֹ
+ * @param wchmm [i/o] 木構造化辞書
+ * @param node [in] ノード番号
+ * @param a [in] 遷移確率（対数）
+ * @param arc [in] 遷移先のノード番号
  * </JA>
  * <EN>
  * Add a transition arc between two nodes on the tree lexicon
@@ -514,16 +515,16 @@ add_wacc(WCHMM_INFO *wchmm, int node, LOGPROB a, int arc)
 
 /**
  * <JA>
- * ñΤ֤βǤñüγؽФܤΥꥹȤ. (multipath) 
+ * ある単語のある位置の音素から単語末端の外へ出る遷移のリストを得る. (multipath) 
  * 
- * @param wchmm [in] ڹ¤
- * @param w [in] ñID
- * @param pos [in] ǰ
- * @param node [out] Ρñüؤܤľ֤Υꥹ
- * @param a [out] @a node γǤܳΨ
- * @param num [out] @a node ǿ. ȯä. 
- * @param maxnum [in] @a node γǼǽʺ
- * @param insert_sp [in] ñ콪üǤ sp ߹ߤθʤTRUE
+ * @param wchmm [in] 木構造化辞書
+ * @param w [in] 単語ID
+ * @param pos [in] 音素位置
+ * @param node [out] 音素内の，単語末端外への遷移を持つ状態のリスト
+ * @param a [out] @a node の各要素の遷移確率
+ * @param num [out] @a node の要素数. 発見数だけ増加される. 
+ * @param maxnum [in] @a node の格納可能な最大数
+ * @param insert_sp [in] 単語終端での sp 挟み込みを考慮するならTRUE
  * </JA>
  * <EN>
  * Make outgoing transition list for given phone position of a word. (multipath)
@@ -608,12 +609,12 @@ get_outtrans_list(WCHMM_INFO *wchmm, WORD_ID w, int pos, int *node, LOGPROB *a,
 
 /** 
  * <JA>
- * 벻Ǥξ֤顤벻ǤƬ֤ؤܤɲä. 
+ * ある音素の末尾の状態から，ある音素の先頭状態への遷移を追加する. 
  * 
- * @param wchmm [i/o] ڹ¤
- * @param from_node [in] 벻Ǥξ
- * @param to_node [in] 벻ǤƬ
- * @param tinfo [in] @a from_node °벻HMMܳΨ
+ * @param wchmm [i/o] 木構造化辞書
+ * @param from_node [in] ある音素の末尾の状態
+ * @param to_node [in] ある音素の先頭状態
+ * @param tinfo [in] @a from_node の属する音素HMMの遷移確率行列
  * </JA>
  * <EN>
  * Add a transition from end node of a phone to start node of another phone.
@@ -663,13 +664,13 @@ wchmm_link_hmm(WCHMM_INFO *wchmm, int from_node, int to_node, HTK_HMM_Trans *tin
 
 /** 
  * <JA>
- * ڹ¤ΣñΤ벻Ǵ֤³. 
+ * 木構造化辞書中の２単語中のある音素間を接続する. 
  * 
- * @param wchmm [i/o] ڹ¤
- * @param from_word [in] ܸñID
- * @param from_seq [in] ܸñ³벻Ǥΰ
- * @param to_word [in] ñID
- * @param to_seq [in] ñ³벻Ǥΰ
+ * @param wchmm [i/o] 木構造化辞書
+ * @param from_word [in] 遷移元の単語のID
+ * @param from_seq [in] 遷移元の単語中の接続する音素の位置
+ * @param to_word [in] 遷移先の単語のID
+ * @param to_seq [in] 遷移先の単語中の接続する音素の位置
  * </JA>
  * <EN>
  * Connect two phonemes in tree lexicon.
@@ -700,12 +701,12 @@ wchmm_link_subword(WCHMM_INFO *wchmm, int from_word, int from_seq, int to_word,
 /**
  * @note
  * <JA>
- * Ʊ:
- * ڹ¤ˤƤ٤ƤñΩǽ֤ɬפ뤿ᡤ
- * Ʊտɬפ. Τᡤǽڹ¤ۤ, 
- * ̤ñȴ˶ͭ줿ñ(Ʊ), 뤤̤ñΰȤ
- * ޤƤޤäƤñȯȤȤ, κǽΡɤ
- * ԡƿñ콪üΡɤɬפ. 
+ * 同音語処理:
+ * 木構造化辞書においてすべての単語は独立した最終状態を持つ必要があるため，
+ * 同音語は注意深く扱う必要がある. このため，最初の木構造化辞書を構築した後, 
+ * 別の単語と完全に共有された単語(同音語), あるいは別の単語の一部として
+ * 埋め込まれてしまっている単語を発見するとともに, その最終ノードを
+ * コピーして新たな単語終端ノードを作る必要がある. 
  * </JA>
  * <EN>
  * Homophones:
@@ -719,12 +720,12 @@ wchmm_link_subword(WCHMM_INFO *wchmm, int from_word, int from_seq, int to_word,
 
 /** 
  * <JA>
- * ñ콪ü֤ΩͿ줿ñνüΡɤ򥳥ԡơ
- * ˤñκǽ֤Ȥ. 
+ * 単語終端状態の独立化：与えられた単語の終端ノードをコピーして，
+ * 新たにある単語の最終状態として定義する. 
  * 
- * @param wchmm [i/o] ڹ¤
- * @param node [in] ƱνüΡֹ
- * @param word [in] Ͽñ
+ * @param wchmm [i/o] 木構造化辞書
+ * @param node [in] 同音語の終端ノード番号
+ * @param word [in] 新たに登録する単語
  * </JA>
  * <EN>
  * Isolation of word-end nodes for homophones: duplicate the word-end state,
@@ -854,10 +855,10 @@ wchmm_duplicate_state(WCHMM_INFO *wchmm, int node, int word) /* source node, new
 
 /** 
  * <JA>
- * ڹ¤Τơ٤ƤƱˤĤñ콪ü֤Ω
- * Ԥ. 
+ * 木構造化辞書全体を走査して，すべての同音語について単語終端状態の独立化
+ * を行う. 
  * 
- * @param wchmm [i/o] ڹ¤
+ * @param wchmm [i/o] 木構造化辞書
  * </JA>
  * <EN>
  * Scan the whole lexicon tree to find already registered homophones, and
@@ -932,15 +933,15 @@ wchmm_duplicate_leafnode(WCHMM_INFO *wchmm)
 
 /** 
  * <JA>
- * ڹ¤˿ñɲä. ɲþξȤơߤڹ¤
- * ǺǤ⤽ñƬɤޥåñ졤ӤΥޥåĹ
- * ꤹ. 
+ * 木構造化辞書に新たに単語を追加する. 追加場所の情報として，現在の木構造化
+ * 辞書内で最もその単語と先頭から良くマッチする単語，およびそのマッチする長さ
+ * を指定する. 
  * 
- * @param wchmm [i/o] ڹ¤
- * @param word [in] ɲä뼭ñID
- * @param matchlen [in] @a word  @a matchword Ƭޥå벻Ĺ
- * @param matchword [in] ¸ڹ¤ @a word ȺǤޥåñ
- * @param enable_iwsp [in] ñ֥硼ȥݡǽѻTRUE
+ * @param wchmm [i/o] 木構造化辞書
+ * @param word [in] 追加する辞書単語のID
+ * @param matchlen [in] @a word と @a matchword の先頭からマッチする音素長
+ * @param matchword [in] 既存の木構造化辞書中で @a word と最もマッチする単語
+ * @param enable_iwsp [in] 単語間ショートポーズ機能使用時TRUEを指定
  * </JA>
  * <EN>
  * Add a new word to the lexicon tree.  The longest matched word in the current
@@ -1389,10 +1390,10 @@ wchmm_add_word(WCHMM_INFO *wchmm, int word, int matchlen, int matchword, boolean
 
 /** 
  * <JA>
- * ڹ¤ñνü֤鳰ؤμܳΨΥꥹȤ. 
+ * 木構造化辞書を走査し，単語の終端状態から外への次遷移確率のリストを作成する. 
  * (non multipath)
  * 
- * @param wchmm [i/o] ڹ¤
+ * @param wchmm [i/o] 木構造化辞書
  * </JA>
  * <EN>
  * Scan the lexicon tree to make list of emission probability from the word end
@@ -1423,12 +1424,12 @@ wchmm_calc_wordend_arc(WCHMM_INFO *wchmm)
 
 /** 
  * <JA>
- * unigramΨǥȤ뤿 qsort Хåؿ. 
+ * unigram確率でソートするための qsort コールバック関数. 
  * 
- * @param a [in] 1
- * @param b [in] 2
+ * @param a [in] 要素1
+ * @param b [in] 要素2
  * 
- * @return 黻η̤֤. 
+ * @return 演算の結果の符合を返す. 
  * </JA>
  * <EN>
  * qsort callback function to sort unigram values.
@@ -1449,12 +1450,12 @@ compare_prob(LOGPROB *a, LOGPROB *b)
 
 /** 
  * <JA>
- * 1-gramξ N ܤͤ. 
+ * 1-gramスコアの上位 N 番目の値を求める. 
  * 
- * @param winfo [in] ñ켭
- * @param n [in] 
+ * @param winfo [in] 単語辞書
+ * @param n [in] 求める順位
  * 
- * @return  N ܤ uni-gram Ψ֤ͤ. 
+ * @return 上位 N 番目の uni-gram 確率の値を返す. 
  * </JA>
  * <EN>
  * Get the Nth-best unigram probability from all words.
@@ -1518,12 +1519,12 @@ get_nbest_uniprob(WCHMM_INFO *wchmm, int n)
 
 /** 
  * <JA>
- * Ϳ줿ñ켭ȸǥ뤫ڹ¤ۤ. δؿ
- * ٤Julian"-oldtree"ץΤ߻Ѥޤ. ץ
- * JuliusǤ build_wchmm2() Ѥޤ. 
+ * 与えられた単語辞書と言語モデルから木構造化辞書を構築する. この関数は
+ * 処理が遅く，Julianで"-oldtree"オプション指定時のみ使用されます. オプション
+ * 非指定時およびJuliusでは代わりに build_wchmm2() が用いられます. 
  * 
- * @param wchmm [i/o] ڹ¤
- * @param lmconf [in] ǥ(LM)ѥ᡼
+ * @param wchmm [i/o] 木構造化辞書
+ * @param lmconf [in] 言語モデル(LM)設定パラメータ
  * </JA>
  * <EN>
  * Build a tree lexicon from given word dictionary and language model.
@@ -1562,8 +1563,8 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
   ok_p = TRUE;
   
 #ifdef SEPARATE_BY_UNIGRAM
-  /* [separate_wnum]ܤ1-gram */
-  /* 1-gramͰʾΤΤڤʬ */
+  /* 上位[separate_wnum]番目の1-gramスコアを求める */
+  /* 1-gramスコアがこの値以上のものは木から分ける */
   separate_thres = get_nbest_uniprob(wchmm, lmconf->separate_wnum);
 #endif
 
@@ -1571,7 +1572,7 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
 #ifndef USE_OLD_IWCD
   if (wchmm->category_tree) {
     if (wchmm->ccd_flag) {
-      /* ƤΥƥIDդ lcd_set  */
+      /* 全てのカテゴリID付き lcd_set を作成 */
       lcdset_register_with_category_all(wchmm);
     }
   }
@@ -1579,10 +1580,10 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
 #endif /* PASS1_IWCD */
   
 
-  /* wchmm */
+  /* wchmmを初期化 */
   wchmm_init(wchmm);
 
-  /* 󥿥ꥻå */
+  /* カウンタリセット */
   wchmm->separated_word_count=0;
 
   jlog("STAT: wchmm: Building HMM lexicon tree (left-to-right)\n");
@@ -1590,9 +1591,9 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
 
     if (wchmm->lmtype == LM_PROB) {
       if (i == wchmm->winfo->head_silwid || i == wchmm->winfo->tail_silwid) {
-	/* Ƭ/̵ǥڹ¤
-	 * Ƭ̵ñƬؤܡñܤϺʤ*/
-	/* sharelen=0ǤΤޤ */
+	/* 先頭/末尾の無音モデルは木構造化せず，
+	 * 先頭の無音単語の先頭への遷移，末尾単語の末尾からの遷移は作らない*/
+	/* sharelen=0でそのまま */
 	if (wchmm_add_word(wchmm, i, 0, 0, lmconf->enable_iwsp) == FALSE) {
 	  jlog("ERROR: wchmm: failed to add word #%d to lexicon tree\n");
 	  ok_p = FALSE;
@@ -1601,8 +1602,8 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
       }
 #ifndef NO_SEPARATE_SHORT_WORD
       if (wchmm->winfo->wlen[i] <= SHORT_WORD_LEN) {
-	/* Ĺûñڹ¤ʤ(Ǥ1) */
-	/* sharelen=0ǤΤޤ */
+	/* 長さの短い単語を木構造化しない(ここでは1音節) */
+	/* sharelen=0でそのまま */
 	if (wchmm_add_word(wchmm, i, 0, 0, lmconf->enable_iwsp) == FALSE) {
 	  jlog("ERROR: wchmm: failed to add word #%d to lexicon tree\n");
 	  ok_p = FALSE;
@@ -1625,8 +1626,8 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
 	p = (*(wchmm->uni_prob_user))(wchmm->winfo, i, p);
       }
       if (p >= separate_thres && wchmm->separated_word_count < lmconf->separate_wnum) {
-	/* ٤ι⤤ñڹ¤ʤ */
-	/* separate_thres Ͼseparate_wnumܤΥ */
+	/* 頻度の高い単語を木構造化しない */
+	/* separate_thres は上位separate_wnum番目のスコア */
 	if (wchmm_add_word(wchmm, i, 0, 0, lmconf->enable_iwsp) == FALSE) {
 	  jlog("ERROR: wchmm: failed to add word #%d to lexicon tree\n");
 	  ok_p = FALSE;
@@ -1637,7 +1638,7 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
 #endif
     }
 
-    /* ǤĹǤͭñõ */
+    /* 最も長く音素を共有出来る単語を探す */
     maxsharelen=0;
     for (j=0;j<i;j++) {
       if (wchmm->category_tree  && wchmm->lmtype == LM_DFA) {
@@ -1645,8 +1646,8 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
       }
       sharelen = wchmm_check_match(wchmm->winfo, i, j);
       if (sharelen == wchmm->winfo->wlen[i] && sharelen == wchmm->winfo->wlen[j]) {
-       /* word Ʊ줬¸ߤ */
-       /* ɬĹǤꡤʣȤ򤱤뤿ᤳȴ */
+       /* word に同音語が存在する */
+       /* 必ず最大の長さであり，重複カウントを避けるためここで抜ける */
        maxsharelen = sharelen;
        matchword = j;
        break;
@@ -1663,7 +1664,7 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
   }
 
 #if 0
-  /* ڹ¤ʤ */
+  /* 木構造を作らない */
   for (i=0;i<wchmm->winfo->num;i++) {
     if (wchmm_add_word(wchmm, i, 0, 0, lmconf->enable_iwsp) == FALSE) {
       jlog("ERROR: wchmm: failed to add word #%d to lexicon tree\n");
@@ -1674,23 +1675,23 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
   jlog("STAT:  %5d words ended     (%6d nodes)\n",i,wchmm->n);
 
   if (! wchmm->hmminfo->multipath) {
-    /* Ʊ첻ǷñƱΤ leaf node 2Ųƶ̤ */
+    /* 同一音素系列を持つ単語同士の leaf node を2重化して区別する */
     num_duplicated = wchmm_duplicate_leafnode(wchmm);
     jlog("STAT:  %d leaf nodes are made unshared\n", num_duplicated);
     
-    /* ñνü鳰ؤܳΨƤ */
+    /* 単語の終端から外への遷移確率を求めておく */
     wchmm_calc_wordend_arc(wchmm);
   }
 
-  /* wchmmå */
+  /* wchmmの整合性をチェックする */
   check_wchmm(wchmm);
 
-  /* factoringѤ˳ƾ֤˸³ñΥꥹȤղä */
+  /* factoring用に各状態に後続単語のリストを付加する */
   if (!wchmm->category_tree) {
 
 #ifdef UNIGRAM_FACTORING
     if (wchmm->lmtype == LM_PROB) {
-      /* Ʊäfactoringͤ׻ */
+      /* 同時に前もってfactoring値を計算 */
       make_successor_list_unigram_factoring(wchmm);
       jlog("STAT:  1-gram factoring values has been pre-computed\n");
     } else {
@@ -1701,13 +1702,13 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
 #endif /* UNIGRAM_FACTORING */
     
     if (wchmm->hmminfo->multipath) {
-      /* ۤ줿 factoring 򥹥åܤʸƬʸˡΡɤ˥ԡ */
+      /* 構築された factoring 情報をスキップ遷移および文頭文法ノードにコピー */
       adjust_sc_index(wchmm);
     }
     
 #ifdef UNIGRAM_FACTORING
     if (wchmm->lmtype == LM_PROB) {
-      /* ñLMå夬ɬפʥΡɤΥꥹȤ */
+      /* 単語間LMキャッシュが必要なノードのリストを作る */
       make_iwcache_index(wchmm);
     }
 #endif /* UNIGRAM_FACTORING */
@@ -1721,14 +1722,14 @@ build_wchmm(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
 
 /** 
  * <JA>
- * Ϳ줿ñ켭ȸǥ뤫ڹ¤ۤ. 
- * δؿ bulid_wchmm() ƱԤޤ
- * ǽñǥȤƲλñ¤٤뤿ᡤ
- * ®ڹ¤ԤȤǤ. Ȥ˥ץ򤷤ʤ
- * ¤ꡤJulius/JulianǤϤ餬Ѥ. 
+ * 与えられた単語辞書と言語モデルから木構造化辞書を構築する. 
+ * この関数は bulid_wchmm() と同じ処理を行いますが，
+ * 最初に単語を音素列でソートして音素列の似た順に単語を並べるため，
+ * より高速に木構造化を行うことができる. とくにオプション指定をしない
+ * 限り，Julius/Julianではこちらが用いられる. 
  * 
- * @param wchmm [i/o] ڹ¤
- * @param lmconf [in] ǥ(LM)ѥ᡼
+ * @param wchmm [i/o] 木構造化辞書
+ * @param lmconf [in] 言語モデル(LM)設定パラメータ
  * </JA>
  * <EN>
  * Build a tree lexicon from given word dictionary and language model.
@@ -2065,9 +2066,9 @@ build_wchmm2(WCHMM_INFO *wchmm, JCONF_LM *lmconf)
 
 /** 
  * <JA>
- * ڹ¤ΥʤɤξɸϤ˽Ϥ. 
+ * 木構造化辞書のサイズなどの情報を標準出力に出力する. 
  * 
- * @param wchmm [in] ڹ¤
+ * @param wchmm [in] 木構造化辞書
  * </JA>
  * <EN>
  * Output some specifications of the tree lexicon (size etc.) to stdout.
