@@ -2,13 +2,13 @@
  * @file   adin_mic_linux.c
  *
  * <JA>
- * @brief  ޥ (Linux) - ǥեȥǥХ
+ * @brief  マイク入力 (Linux) - デフォルトデバイス
  *
- * ޥϤΤ٥ؿǤ
- * 󥿥եꤷʤ (-input mic) ˸ƤФޤ
- * ALSA, PulesAudio, OSS, ESD νǺǽ˸ĤäΤѤޤ
- * 줾 API Ū˻ꤷ "-input" ˤ줾
- * "alsa", "oss", "pulseaudio", "esd" ꤷƤ
+ * マイク入力のための低レベル関数です．
+ * インタフェースを明示指定しない (-input mic) 場合に呼ばれます．
+ * ALSA, PulesAudio, OSS, ESD の順で最初に見つかったものが使用されます．
+ * それぞれの API を明示的に指定したい場合は "-input" にそれぞれ
+ * "alsa", "oss", "pulseaudio", "esd" を指定してください。
  * </JA>
  * <EN>
  * @brief  Microphone input on Linux - default device
@@ -23,13 +23,13 @@
  * @author Akinobu LEE
  * @date   Sun Feb 13 16:18:26 2005
  *
- * $Revision: 1.8 $
+ * $Revision: 1.10 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -136,6 +136,38 @@ adin_mic_read(SP16 *buf, int sampnum)
 #endif
 }
 
+/** 
+ * Function to pause audio input (wait for buffer flush)
+ * 
+ * @return TRUE on success, FALSE on failure.
+ */
+boolean
+adin_mic_pause()
+{
+  return TRUE;
+}
+
+/** 
+ * Function to terminate audio input (disgard buffer)
+ * 
+ * @return TRUE on success, FALSE on failure.
+ */
+boolean
+adin_mic_terminate()
+{
+  return TRUE;
+}
+/** 
+ * Function to resume the paused / terminated audio input
+ * 
+ * @return TRUE on success, FALSE on failure.
+ */
+boolean
+adin_mic_resume()
+{
+  return TRUE;
+}
+
 /** 
  * 
  * Function to return current input source device name
