@@ -2,15 +2,15 @@
  * @file   adin_mic_o2.c
  * 
  * <JA>
- * @brief  ޥ (SGI IRIX)
+ * @brief  マイク入力 (SGI IRIX)
  *
- * SGI IRIX ΥޥϤѤ٥벻ϴؿǤ
- * IRIXޥǤϥǥեȤǤ줬Ѥޤ
+ * SGI IRIX のマイク入力を使用する低レベル音声入力関数です．
+ * IRIXマシンではデフォルトでこれが使用されます．
  *
- * SGI O2 Workstation (IRIX6.3) ưǧ򤷤Ƥޤ
+ * SGI O2 Workstation (IRIX6.3) で動作確認をしています．
  *
- * ư奪ǥϤϥޥ˼ưŪڤؤޤ
- * ܥ塼ϼưĴᤵޤapanelޥɤĴᤷƤ 
+ * 起動後オーディオ入力はマイクに自動的に切り替わりますが，
+ * ボリュームは自動調節されません．apanelコマンドで別途調節してください． 
  * </JA>
  * <EN>
  * @brief  Microphone input on SGI IRIX machine
@@ -29,7 +29,7 @@
  * @author Akinobu LEE
  * @date   Sun Feb 13 18:42:22 2005
  *
- * $Revision: 1.7 $
+ * $Revision: 1.8 $
  * 
  */
 /*
@@ -175,6 +175,38 @@ adin_mic_read(SP16 *buf, int sampnum)
   return cnt;
 }
 
+/** 
+ * Function to pause audio input (wait for buffer flush)
+ * 
+ * @return TRUE on success, FALSE on failure.
+ */
+boolean
+adin_mic_pause()
+{
+  return TRUE;
+}
+
+/** 
+ * Function to terminate audio input (disgard buffer)
+ * 
+ * @return TRUE on success, FALSE on failure.
+ */
+boolean
+adin_mic_terminate()
+{
+  return TRUE;
+}
+/** 
+ * Function to resume the paused / terminated audio input
+ * 
+ * @return TRUE on success, FALSE on failure.
+ */
+boolean
+adin_mic_resume()
+{
+  return TRUE;
+}
+
 /** 
  * 
  * Function to return current input source device name
