@@ -2,27 +2,27 @@
  * @file   adin_portaudio.c
  * 
  * <JA>
- * @brief  ޥ (portaudio饤֥)
+ * @brief  マイク入力 (portaudioライブラリ)
  *
- * portaudioo饤֥ѤޥϤΤ٥ؿǤ
- * Ѥˤ configure  "--with-mictype=portaudio" ꤷƲ
- * Linux  Win32 ǻѲǽǤWin32⡼ɤǤϤ줬
- * ǥեȤȤʤޤ
+ * portaudiooライブラリを使用したマイク入力のための低レベル関数です．
+ * 使用するには configure 時に "--with-mictype=portaudio" を指定して下さい．
+ * Linux および Win32 で使用可能です．Win32モードではこれが
+ * デフォルトとなります．
  *
- * ϿǥХ WASAPI -> ASIO -> DirectSound -> MME ν򤵤ޤ
- * ѤǥХꤷϡĶѿ PORTAUDIO_DEV ǥǥХ̾
- * Ƭʬޥåˤꤹ뤫PORTAUDIO_DEV_NUM ǥǥХֹ
- * ꤷƤѲǽʥǥХ̾ȥǥХֹϵư˽Ϥޤ
+ * 録音デバイスは WASAPI -> ASIO -> DirectSound -> MME の順で選択されます。
+ * 使用するデバイスを指定したい場合は、環境変数 PORTAUDIO_DEV でデバイス名
+ * （先頭から部分マッチ）を指定するか、PORTAUDIO_DEV_NUM でデバイス番号を
+ * 指定してください。使用可能なデバイス名とデバイス番号は起動時に出力されます。
  *
- * JuliusϥߥǥХڹԤޤϿǥХ
- * ʥޥ/饤ˤϿܥ塼ĴWindows
- * ֥ܥ塼ॳȥ  Linux  xmixer ʤɡ¾Υġ
- * ԤʤäƲ
+ * Juliusはミキサーデバイスの設定を一切行いません．録音デバイスの
+ * 選択（マイク/ライン）や録音ボリュームの調節はWindowsの
+ * 「ボリュームコントロール」 や Linux の xmixer など，他のツールで
+ * 行なって下さい．
  *
- * portaudio ϥե꡼ǥץåȥۡΥǥϥ饤֥
- * Ǥ libsent/src/adin/pa/ ˴ޤޤƤޤΥץǤ
- * åɤѤcallback Ѥϲ󥰥Хåե˼
- * ޤ
+ * portaudio はフリーでクロスプラットホームのオーディオ入出力ライブラリ
+ * です．ソースは libsent/src/adin/pa/ に含まれています．このプログラムでは
+ * スレッドを利用したcallback を利用して入力音声をリングバッファに取り込んで
+ * います．
  *
  * @sa http://www.portaudio.com/
  * </JA>
@@ -56,12 +56,12 @@
  * @author Akinobu LEE
  * @date   Mon Feb 14 12:03:48 2005
  *
- * $Revision: 1.19 $
+ * $Revision: 1.21 $
  * 
  */
 /*
  * Copyright (c) 2004-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -109,7 +109,7 @@
 #endif
 
 /* temporal buffer */
-static SP16 *speech;		///< cycle buffer for incoming speech data
+static SP16 *speech = NULL;	///< cycle buffer for incoming speech data
 static int current;		///< writing point
 static int processed;		///< reading point
 static boolean buffer_overflowed = FALSE; ///< TRUE if buffer overflowed
@@ -397,6 +397,7 @@ adin_mic_open(char *arg)
 
   /* allocate and init */
   current = processed = 0;
+  if (speech) free(speech);
   speech = (SP16 *)mymalloc(sizeof(SP16) * cycle_buffer_len);
   buffer_overflowed = FALSE;
 
@@ -661,6 +662,60 @@ adin_mic_read(SP16 *buf, int sampnum)
   return len;
 }
 
+/** 
+ * Function to pause audio input (wait for buffer flush)
+ * 
+ * @return TRUE on success, FALSE on failure.
+ */
+boolean
+adin_mic_pause()
+{
+  PaError err;
+
+  err = Pa_StopStream(stream);
+  if (err != paNoError) {
+    jlog("Error: adin_portaudio: failed to pause stream: %s\n", Pa_GetErrorText(err));
+    return FALSE;
+  }
+  return TRUE;
+}
+
+/** 
+ * Function to terminate audio input (disgard buffer)
+ * 
+ * @return TRUE on success, FALSE on failure.
+ */
+boolean
+adin_mic_terminate()
+{
+  PaError err;
+
+  err = Pa_AbortStream(stream);
+  if (err != paNoError) {
+    jlog("Error: adin_portaudio: failed to terminate stream: %s\n", Pa_GetErrorText(err));
+    return FALSE;
+  }
+  return TRUE;
+}
+
+/** 
+ * Function to resume the paused / terminated audio input
+ * 
+ * @return TRUE on success, FALSE on failure.
+ */
+boolean
+adin_mic_resume()
+{
+  PaError err;
+
+  err = Pa_StartStream(stream);
+  if (err != paNoError) {
+    jlog("Error: adin_portaudio: failed to resume stream: %s\n", Pa_GetErrorText(err));
+    return FALSE;
+  }
+  return TRUE;
+}
+
 /** 
  * 
  * Function to return current input source device name
