@@ -2,9 +2,9 @@
  * @file   cpair.c
  * 
  * <JA>
- * @brief  ƥؤΥؿӥ
+ * @brief  カテゴリ対制約へのアクセス関数およびメモリ管理
  *
- * ƥΥݡӥƥ֤³βݤ֤ؿǤ
+ * カテゴリ対制約のメモリ確保，およびカテゴリ間の接続の可否を返す関数です．
  * </JA>
  * 
  * <EN>
@@ -18,13 +18,13 @@
  * @author Akinobu LEE
  * @date   Tue Feb 15 13:54:44 2005
  *
- * $Revision: 1.6 $
+ * $Revision: 1.7 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -274,6 +274,14 @@ void
 init_dfa_cp(DFA_INFO *dfa)
 {
   dfa->cp = NULL;
+  dfa->cplen = NULL;
+  dfa->cpalloclen = NULL;
+  dfa->cp_begin = NULL;
+  dfa->cp_begin_len = 0;
+  dfa->cp_begin_alloclen = 0;
+  dfa->cp_end = NULL;
+  dfa->cp_end_len = 0;
+  dfa->cp_end_alloclen = 0;
 }
 
 /** 
@@ -413,6 +421,8 @@ dfa_cp_output_rawdata(FILE *fp, DFA_INFO *dfa)
 {
   int i, j;
 
+  if (dfa->cp == NULL) return;
+
   for(i=0;i<dfa->term_num;i++) {
     fprintf(fp, "%d:", i);
     for(j=0;j<dfa->cplen[i];j++) {
@@ -438,6 +448,12 @@ dfa_cp_count_size(DFA_INFO *dfa, unsigned long *size_ret, unsigned long *allocsi
   int i;
   unsigned long size, allocsize;
 
+  if (dfa->cp == NULL) {
+    *size_ret = 0;
+    *allocsize_ret = 0;
+    return;
+  }
+
   size = 0;
   allocsize = 0;
   for(i=0;i<dfa->term_num;i++) {
