@@ -5,14 +5,18 @@
  * All rights reserved
  */
 
-#if defined(__AVX__) || defined(__SSE__) || defined(__FMA__)
-#include <immintrin.h>
+
+/* define this to test disabling expsum computation at softmax */
+#undef NO_SUM_COMPUTATION
+
 #ifdef _WIN32
 #include <intrin.h>
 #else
+#if defined(__arm__) || TARGET_OS_IPHONE || defined(__aarch64__)
+#else
 #include <cpuid.h>
+#endif
 #endif	/* _WIN32 */
-#endif	/* __AVX__ || __SSE__ || __FMA__ */
 
 #include <sent/stddefs.h>
 #include <sent/htk_hmm.h>
@@ -20,12 +24,11 @@
 #include <sent/hmm.h>
 #include <sent/hmm_calc.h>
 
-#ifdef USE_ARM_NEON
-#include <arm_neon.h>
-#endif
-
-#if defined(__FMA__) || defined(__AVX__) || defined(__SSE__) || defined(USE_ARM_NEON)
+#if defined(HAS_SIMD_FMA) || defined(HAS_SIMD_AVX) || defined(HAS_SIMD_SSE) || defined(HAS_SIMD_NEON) || defined(HAS_SIMD_NEONV2)
 #define SIMD_ENABLED
+#ifdef _OPENMP
+#include <omp.h>
+#endif /* _OPENMP */
 #endif
 
 static int use_simd = USE_SIMD_NONE;
@@ -40,16 +43,20 @@ static void cpu_id_check()
   int cpuinfo[4];
   boolean sse = FALSE, avx = FALSE, fma = FALSE;
 
-#ifdef __arm__
+  use_simd = USE_SIMD_NONE;
+
+#if defined(__arm__) || TARGET_OS_IPHONE
   /* on ARM NEON */
 
-#ifdef USE_ARM_NEON
+#if defined(HAS_SIMD_NEONV2)
+  use_simd = USE_SIMD_NEONV2;
+#elif defined(HAS_SIMD_NEON)
   use_simd = USE_SIMD_NEON;
 #else
   use_simd = USE_SIMD_NONE;
 #endif
 
-#else  /* ~USE_ARM_NEON */
+#else  /* ~__arm__ */
 
 #ifdef _WIN32
   __cpuid(cpuinfo, 0x00000001);
@@ -78,33 +85,28 @@ static void cpu_id_check()
   }
 #endif	/* _WIN32 */
 
-#ifdef __FMA__
+#ifdef HAS_SIMD_FMA
   if (fma == TRUE) {
     use_simd = USE_SIMD_FMA;
-  } else if (avx == TRUE) {
-    use_simd = USE_SIMD_AVX;
-  } else if (sse == TRUE) {
-    use_simd = USE_SIMD_SSE;
-  } else {
-    use_simd = USE_SIMD_NONE;
-  }
-#elif __AVX__
-  if (avx == TRUE) {
-    use_simd = USE_SIMD_AVX;
-  } else if (sse == TRUE) {
-    use_simd = USE_SIMD_SSE;
-  } else {
-    use_simd = USE_SIMD_NONE;
-  }
-#elif __SSE__
-  if (sse == TRUE) {
-    use_simd = USE_SIMD_SSE;
-  } else {
-    use_simd = USE_SIMD_NONE;
+    return;
   }
 #endif
 
-#endif  /* ~USE_ARM_NEON */
+#ifdef HAS_SIMD_AVX
+  if (avx == TRUE) {
+    use_simd = USE_SIMD_AVX;
+    return;
+  }
+#endif
+
+#ifdef HAS_SIMD_SSE
+  if (sse == TRUE) {
+    use_simd = USE_SIMD_SSE;
+    return;
+  }
+#endif
+
+#endif  /* ~__arm__ */
 
 }
 
@@ -119,6 +121,7 @@ static void *mymalloc_simd_aligned(size_t size)
     break;
   case USE_SIMD_SSE:
   case USE_SIMD_NEON:
+  case USE_SIMD_NEONV2:
     ptr = mymalloc_aligned(size, 16);
     break;
   default:
@@ -136,6 +139,7 @@ static void myfree_simd_aligned(void *ptr)
   case USE_SIMD_AVX:
   case USE_SIMD_SSE:
   case USE_SIMD_NEON:
+  case USE_SIMD_NEONV2:
     if (ptr != NULL) myfree_aligned(ptr);
     break;
   default:
@@ -150,16 +154,19 @@ void get_builtin_simd_string(char *buf)
 {
   buf[0] = '\0';
 
-#ifdef USE_ARM_NEON
+#ifdef HAS_SIMD_NEON
   strcat(buf, " NEON");
 #endif
-#ifdef __SSE__
+#ifdef HAS_SIMD_NEONV2
+  strcat(buf, " NEONv2");
+#endif
+#ifdef HAS_SIMD_SSE
   strcat(buf, " SSE");
 #endif
-#ifdef __AVX__
+#ifdef HAS_SIMD_AVX
   strcat(buf, " AVX");
 #endif
-#ifdef __FMA__
+#ifdef HAS_SIMD_FMA
   strcat(buf, " FMA");
 #endif
 }
@@ -174,18 +181,26 @@ int check_avail_simd()
 
 static void output_use_simd()
 {
-#ifdef USE_ARM_NEON
+#ifdef SIMD_ENABLED
+#ifdef HAS_SIMD_NEON
   jlog("Stat: calc_dnn: ARM NEON instructions built-in\n");
-#elif __FMA__
-  jlog("Stat: calc_dnn: FMA/AVX/SSE instructions built-in\n");
-#elif __AVX__
-  jlog("Stat: calc_dnn: AVX/SSE instructions built-in\n");
-#elif __SSE__
+#endif
+#ifdef HAS_SIMD_NEONV2
+  jlog("Stat: calc_dnn: ARM NEONv2 instructions built-in\n");
+#endif
+#ifdef HAS_SIMD_FMA
+  jlog("Stat: calc_dnn: FMA instructions built-in\n");
+#endif
+#ifdef HAS_SIMD_AVX
+  jlog("Stat: calc_dnn: AVX instructions built-in\n");
+#endif
+#ifdef HAS_SIMD_SSE
   jlog("Stat: calc_dnn: SSE instructions built-in\n");
-#else
+#endif
+#else  /* ~SIMD_ENABLED */
   jlog("Warning: NO built-in SIMD support, DNN computation may be too slow!\n");
   return;
-#endif
+#endif  /* ~SIMD_ENABLED */
 
 #ifdef SIMD_ENABLED
   if (use_simd == USE_SIMD_SSE) {
@@ -196,6 +211,8 @@ static void output_use_simd()
     jlog("Stat: clac_dnn: use FMA SIMD instruction (256bit)\n");
   } else if (use_simd == USE_SIMD_NEON) {
     jlog("Stat: use ARM NEON instruction\n");
+  } else if (use_simd == USE_SIMD_NEONV2) {
+    jlog("Stat: use ARM NEONv2 instruction\n");
   } else {
     jlog("Warning: clac_dnn: no SIMD support, DNN computation may be too slow!\n");
   }
@@ -268,7 +285,7 @@ static boolean load_npy(float *array, char *filename, int x, int y)
   }
 #ifdef WORDS_BIGENDIAN
   swap_bytes(&header_len, 2, 1);
-#endif  
+#endif
   header = (char *)mymalloc(header_len + 1);
   if ((len = myfread(header, 1, header_len, fp)) < header_len) {
     jlog("Error: load_npy: failed to read header (%d bytes): %s\n", header_len, filename);
@@ -292,15 +309,17 @@ static boolean load_npy(float *array, char *filename, int x, int y)
     fortran_order = FALSE;
   }
 
-  char buf[100];
-  sprintf(buf, "'shape': (%d, %d)", x, y);
-  if (strstr(header, buf) == NULL) {
-    sprintf(buf, "'shape': (%d, %d)", y, x);
+  {
+    char buf[100];
+    sprintf(buf, "'shape': (%d, %d)", x, y);
     if (strstr(header, buf) == NULL) {
-      jlog("Error: load_npy: not a (%d, %d) array? %s\n", x, y, filename);
-      free(header);
-      fclose_readfile(fp);
-      return FALSE;
+      sprintf(buf, "'shape': (%d, %d)", y, x);
+      if (strstr(header, buf) == NULL) {
+	jlog("Error: load_npy: not a (%d, %d) array? %s\n", x, y, filename);
+	free(header);
+	fclose_readfile(fp);
+	return FALSE;
+      }
     }
   }
   free(header);
@@ -333,7 +352,7 @@ static void logistic_table_build()
   int i;
   double d;
   double x;
-  
+
   for (i = 0; i <= LOGISTIC_TABLE_MAX; i++) {
     x = (double)i / (double)LOGISTIC_TABLE_FACTOR - 8.0;
     d = 1.0 / (1.0 + exp(-x));
@@ -356,10 +375,19 @@ static void dnn_layer_init(DNNLayer *l)
   l->b = NULL;
   l->in = 0;
   l->out = 0;
+#ifdef _OPENMP
+  l->begin = NULL;
+  l->end = NULL;
+#endif /* _OPENMP */
+#ifdef __NVCC__
+  l->dw = NULL;
+  l->db = NULL;
+#endif /* __NVCC__ */
+
 }
 
 /* load dnn layer parameter from files */
-static boolean dnn_layer_load(DNNLayer *l, int in, int out, char *wfile, char *bfile)
+static boolean dnn_layer_load(DNNLayer *l, int in, int out, char *wfile, char *bfile, int thread_num)
 {
   l->in = in;
   l->out = out;
@@ -383,6 +411,25 @@ static boolean dnn_layer_load(DNNLayer *l, int in, int out, char *wfile, char *b
   if (! load_npy(l->b, bfile, l->out, 1)) return FALSE;
   jlog("Stat: dnn_layer_load: loaded %s\n", bfile);
 
+#ifdef _OPENMP
+  /* divide into thread chunks */
+  if (l->begin == NULL) {
+    l->begin = (int *)mymalloc(sizeof(int) * thread_num);
+  }
+  if (l->end == NULL) {
+    l->end = (int *)mymalloc(sizeof(int) * thread_num);
+  }
+  int num = l->out / thread_num;
+  /* padding base chunk size to factor of 4 for better SIMD processing */
+  num = ((num + 3) / 4) * 4;
+  int i;
+  for (i = 0; i < thread_num; i++) {
+    l->begin[i] = num * i;
+    l->end[i] = num * i + num;
+    if (l->end[i] > l->out) l->end[i] = l->out;
+  }
+#endif /* _OPENMP */
+
   return TRUE;
 }
 
@@ -396,6 +443,13 @@ static void dnn_layer_clear(DNNLayer *l)
   if (l->w != NULL) free(l->w);
   if (l->b != NULL) free(l->b);
 #endif	/* SIMD_ENABLED */
+#ifdef _OPENMP
+  if (l->begin != NULL) free(l->begin);
+  if (l->end != NULL) free(l->end);
+#endif /* _OPENMP */
+#ifdef __NVCC__
+  cuda_layer_free(l);
+#endif /* __NVCC__ */
   dnn_layer_init(l);
 }
 
@@ -414,12 +468,17 @@ void dnn_clear(DNNData *dnn)
 {
   int i;
 
+#ifdef __NVCC__
+  cuda_dnn_clear(dnn);
+#endif /* __NVCC__ */
+
   if (dnn->h) {
     for (i = 0; i < dnn->hnum; i++) {
       dnn_layer_clear(&(dnn->h[i]));
     }
     free(dnn->h);
   }
+  dnn_layer_clear(&(dnn->o));
   if (dnn->state_prior) free(dnn->state_prior);
   for (i = 0; i < dnn->hnum; i++) {
     if (dnn->work[i]) {
@@ -446,104 +505,6 @@ void dnn_free(DNNData *dnn)
 }
 
 /************************************************************************/
-#ifdef USE_ARM_NEON
-static void
-sub1_neon(float *dst, float *src, float *w, float *b, int out, int in, float *fstore)
-{
-  float *s;
-  int i, j;
-
-  int n = in / 4;
-  for (i = 0; i < out; i++) {
-    float32x4_t x = vdupq_n_f32(0);
-    s = src;
-    for (j = 0; j < n; j++) {
-      float32x4_t v1 = vld1q_f32(w);
-      float32x4_t v2 = vld1q_f32(s);
-      x = vmlaq_f32(x, v1, v2);
-      w += 4;
-      s += 4;
-    }
-    vst1q_f32(fstore, x);
-    *(dst++) = fstore[0] + fstore[1] + fstore[2] + fstore[3] + *(b++);
-  }
-}
-#endif
-
-
-#ifdef __FMA__
-static void
-sub1_fma(float *dst, float *src, float *w, float *b, int out, int in, float *fstore)
-{
-  float *s;
-  int i, j;
-
-  int n = in / 8;
-  for (i = 0; i < out; i++) {
-    __m256 x = _mm256_setzero_ps();
-    s = src;
-    for (j = 0; j < n; j++) {
-      __m256 v1 = _mm256_load_ps(w);
-      __m256 v2 = _mm256_load_ps(s);
-      x = _mm256_fmadd_ps(v1, v2, x);
-      w += 8;
-      s += 8;
-    }
-    _mm256_store_ps(fstore, x);
-    *(dst++) = fstore[0] + fstore[1] + fstore[2] + fstore[3] + fstore[4] + fstore[5] + fstore[6] + fstore[7] + *(b++);
-  }
-}
-#endif	/* __FMA__ */
-
-#ifdef __AVX__
-static void
-sub1_avx(float *dst, float *src, float *w, float *b, int out, int in, float *fstore)
-{
-  float *s;
-  int i, j;
-
-  int n = in / 8;
-  for (i = 0; i < out; i++) {
-    __m256 x = _mm256_setzero_ps();
-    s = src;
-    for (j = 0; j < n; j++) {
-      __m256 v1 = _mm256_load_ps(w);
-      __m256 v2 = _mm256_load_ps(s);
-      v2 = _mm256_mul_ps(v1, v2);
-      x = _mm256_add_ps(x, v2);
-      w += 8;
-      s += 8;
-    }
-    _mm256_store_ps(fstore, x);
-    *(dst++) = fstore[0] + fstore[1] + fstore[2] + fstore[3] + fstore[4] + fstore[5] + fstore[6] + fstore[7] + *(b++);
-  }
-}
-#endif	/* __AVX__ */
-
-#ifdef __SSE__
-static void
-sub1_sse(float *dst, float *src, float *w, float *b, int out, int in, float *fstore)
-{
-  float *s;
-  int i, j;
-
-  int n = in / 4;
-  for (i = 0; i < out; i++) {
-    __m128 x = _mm_setzero_ps();
-    s = src;
-    for (j = 0; j < n; j++) {
-      __m128 v1 = _mm_load_ps(w);
-      __m128 v2 = _mm_load_ps(s);
-      v2 = _mm_mul_ps(v1, v2);
-      x = _mm_add_ps(x, v2);
-      w += 4;
-      s += 4;
-    }
-    _mm_store_ps(fstore, x);
-    *(dst++) = fstore[0] + fstore[1] + fstore[2] + fstore[3] + *(b++);
-  }
-}
-#endif	/* __SSE__ */
 
 static void
 sub1(float *dst, float *src, float *w, float *b, int out, int in, float *fstore)
@@ -564,7 +525,7 @@ sub1(float *dst, float *src, float *w, float *b, int out, int in, float *fstore)
 /************************************************************************/
 
 /* initialize dnn */
-boolean dnn_setup(DNNData *dnn, int veclen, int contextlen, int inputnodes, int outputnodes, int hiddennodes, int hiddenlayernum, char **wfile, char **bfile, char *output_wfile, char *output_bfile, char *priorfile, float prior_factor, int batchsize)
+boolean dnn_setup(DNNData *dnn, int veclen, int contextlen, int inputnodes, int outputnodes, int hiddennodes, int hiddenlayernum, char **wfile, char **bfile, char *output_wfile, char *output_bfile, char *priorfile, float prior_factor, boolean state_prior_log10nize, int batchsize, int num_threads, char *cuda_mode)
 {
   int i;
 
@@ -589,19 +550,104 @@ boolean dnn_setup(DNNData *dnn, int veclen, int contextlen, int inputnodes, int
   dnn->hiddennodenum = hiddennodes;
   dnn->outputnodenum = outputnodes;
   dnn->prior_factor = prior_factor;
-
-  /* check for input length */
-  int inputlen = veclen * contextlen;
-  if (inputnodes != inputlen) {
-    jlog("Error: dnn_init: veclen(%d) * contextlen(%d) != inputnodes(%d)\n", veclen, contextlen, inputnodes);
+  dnn->num_threads = num_threads;
+#ifdef __NVCC__
+  dnn->blocksize1 = 0;
+  dnn->blocksize2 = 0;
+  if (cuda_mode == NULL) {
+    dnn->use_cuda = TRUE;
+    dnn->use_cuda_shared = FALSE;
+  } else if (strmatch(cuda_mode, "disable")) {
+    dnn->use_cuda = FALSE;
+    dnn->use_cuda_shared = FALSE;
+  } else if (strnmatch(cuda_mode, "global", 6)) {
+    dnn->use_cuda = TRUE;
+    dnn->use_cuda_shared = FALSE;
+    if (strlen(cuda_mode) > 6) {
+      char *buf = strdup(cuda_mode + 6);
+      char *p, *save;
+      int n = 0;
+      for (p = mystrtok_safe(buf, ",", &save); p; p = mystrtok_safe(NULL, ",", &save)) {
+        switch(n) {
+        case 0:
+          dnn->blocksize1 = atoi(p);
+          break;
+        default:
+          jlog("Error: dnn_init: too many CUDA mode parameter: %s\n", cuda_mode);
+          return FALSE;
+        }
+        n++;
+      }
+      free(buf);
+    }
+  } else if (strnmatch(cuda_mode, "shared", 6)) {
+    dnn->use_cuda = TRUE;
+    dnn->use_cuda_shared = TRUE;
+    if (strlen(cuda_mode) > 6) {
+#if 1
+      jlog("Error: dnn_init: CUDA shared mode block parameters are fixed to 16x8, remove the parameters: %s\n", cuda_mode);
+      return FALSE;
+#else
+      char *buf = strdup(cuda_mode + 6);
+      char *p, *save;
+      int n = 0;
+      for (p = mystrtok_safe(buf, ",", &save); p; p = mystrtok_safe(NULL, ",", &save)) {
+        switch(n) {
+        case 0:
+          dnn->blocksize1 = atoi(p);
+          break;
+        case 1:
+          dnn->blocksize2 = atoi(p);
+          break;
+        default:
+          jlog("Error: dnn_init: too many CUDA mode parameter: %s\n", cuda_mode);
+          return FALSE;
+        }
+        n++;
+      }
+      free(buf);
+#endif
+    }
+  }
+#else
+  if (cuda_mode != NULL && strmatch(cuda_mode, "disable") == FALSE) {
+    jlog("Error: dnn_init: CUDA mode specified as \"%s\" but no CUDA support is built-in\n", cuda_mode);
     return FALSE;
   }
+#endif /* __NVCC__ */
+#ifdef _OPENMP
+  /* set number of threads */
+  int max_num_threads = omp_get_max_threads();
+  if (dnn->num_threads > max_num_threads) {
+    jlog("Warning: dnn_init: %d threads requested but available max is %d\n", dnn->num_threads, max_num_threads);
+    dnn->num_threads = max_num_threads;
+  }
+  jlog("Stat: dnn_init: use %d threads for DNN computation (max %d cores)\n", dnn->num_threads, max_num_threads);
+#endif /* OPENMP */
+
+#ifdef __NVCC__
+  // copy logistic_table to GPU
+  if (dnn->use_cuda) {
+    cuda_copy_logistic_table(logistic_table, LOGISTIC_TABLE_MAX + 1);
+    jlog("Stat: dnn_init: logistic table copied to GPU\n");
+  }
+
+#endif /* __NVCC__ */
+
+  /* check for input length */
+  {
+    int inputlen = veclen * contextlen;
+    if (inputnodes != inputlen) {
+      jlog("Error: dnn_init: veclen(%d) * contextlen(%d) != inputnodes(%d)\n", veclen, contextlen, inputnodes);
+      return FALSE;
+    }
+
+    jlog("Stat: dnn_init: input: vec %d * context %d = %d dim\n", veclen, contextlen, inputlen);
+    jlog("Stat: dnn_init: input layer: %d dim\n", inputnodes);
+    jlog("Stat: dnn_init: %d hidden layer(s): %d dim\n", hiddenlayernum, hiddennodes);
+    jlog("Stat: dnn_init: output layer: %d dim\n", outputnodes);
+  }
 
-  jlog("Stat: dnn_init: input: vec %d * context %d = %d dim\n", veclen, contextlen, inputlen);
-  jlog("Stat: dnn_init: input layer: %d dim\n", inputnodes);
-  jlog("Stat: dnn_init: %d hidden layer(s): %d dim\n", hiddenlayernum, hiddennodes);
-  jlog("Stat: dnn_init: output layer: %d dim\n", outputnodes);
-  
   /* initialize layers */
   dnn->hnum = hiddenlayernum;
   dnn->h = (DNNLayer *)mymalloc(sizeof(DNNLayer) * dnn->hnum);
@@ -611,11 +657,23 @@ boolean dnn_setup(DNNData *dnn, int veclen, int contextlen, int inputnodes, int
   dnn_layer_init(&(dnn->o));
 
   /* load layer parameters */
-  if (dnn_layer_load(&(dnn->h[0]), inputnodes, hiddennodes, wfile[0], bfile[0]) == FALSE) return FALSE;
+  if (dnn_layer_load(&(dnn->h[0]), inputnodes, hiddennodes, wfile[0], bfile[0], dnn->num_threads) == FALSE) return FALSE;
   for (i = 1; i < dnn->hnum; i++) {
-    if (dnn_layer_load(&(dnn->h[i]), hiddennodes, hiddennodes, wfile[i], bfile[i]) == FALSE) return FALSE;
+    if (dnn_layer_load(&(dnn->h[i]), hiddennodes, hiddennodes, wfile[i], bfile[i], dnn->num_threads) == FALSE) return FALSE;
   }
-  if (dnn_layer_load(&(dnn->o), hiddennodes, outputnodes, output_wfile, output_bfile) == FALSE) return FALSE;
+  if (dnn_layer_load(&(dnn->o), hiddennodes, outputnodes, output_wfile, output_bfile, dnn->num_threads) == FALSE) return FALSE;
+
+#ifdef __NVCC__
+  // load DNN layer definitions to GPU
+  if (dnn->use_cuda) {
+    for (i = 0; i < dnn->hnum; i++) {
+      cuda_layer_load(&(dnn->h[i]));
+      jlog("Stat: dnn_init: layer #%d loaded to GPU\n", i);
+    }
+    cuda_layer_load(&(dnn->o));
+    jlog("Stat: dnn_init: output layer loaded to GPU\n");
+  }
+#endif /* __NVCC__ */
 
   /* load state prior */
   {
@@ -639,8 +697,10 @@ boolean dnn_setup(DNNData *dnn, int veclen, int contextlen, int inputnodes, int
 	return FALSE;
       }
       dnn->state_prior[id] = val * prior_factor;
-      // log10-nize prior
-      dnn->state_prior[id] = log10(dnn->state_prior[id]);
+      if (state_prior_log10nize) {
+	// log10-nize prior
+	dnn->state_prior[id] = log10(dnn->state_prior[id]);
+      }
     }
     fclose(fp);
     jlog("Stat: dnn_init: state prior loaded: %s\n", priorfile);
@@ -657,35 +717,45 @@ boolean dnn_setup(DNNData *dnn, int veclen, int contextlen, int inputnodes, int
   }
 #ifdef SIMD_ENABLED
   dnn->invec = (float *)mymalloc_simd_aligned(sizeof(float) * inputnodes);
+#ifdef _OPENMP
+  dnn->accum = (float *)mymalloc_simd_aligned(32 * dnn->num_threads);
+#else
   dnn->accum = (float *)mymalloc_simd_aligned(32);
+#endif /* OPENMP */
 #endif
 
+#ifdef __NVCC__
+  if (dnn->use_cuda) cuda_dnn_setup(dnn);
+  if (dnn->use_cuda) {
+    if (dnn->use_cuda_shared) {
+      jlog("Stat: dnn_init: CUDA mode: shared, block size = %d x %d\n", dnn->blocksize1, dnn->blocksize2);
+    } else {
+      jlog("Stat: dnn_init: CUDA mode: global, block size = %d\n", dnn->blocksize1);
+    }
+  } else {
+    jlog("Stat: dnn_init: disabled CUDA support for DNN computation\n");
+  }
+#else
+  jlog("Stat: dnn_init: no CUDA support is built in, CUDA will not be used\n");
+#endif /* __NVCC__ */
+
   /* choose sub function */
 #ifdef SIMD_ENABLED
   switch(use_simd) {
   case USE_SIMD_FMA:
-#ifdef __FMA__
-    dnn->subfunc = sub1_fma;
-#endif
+    dnn->subfunc = calc_dnn_fma;
     break;
   case USE_SIMD_AVX:
-#ifdef __AVX__
-    dnn->subfunc = sub1_avx;
-#endif
+    dnn->subfunc = calc_dnn_avx;
     break;
   case USE_SIMD_SSE:
-#ifdef __SSE__
-    dnn->subfunc = sub1_sse;
-#endif
+    dnn->subfunc = calc_dnn_sse;
     break;
   case USE_SIMD_NEON:
-#ifdef __arm__
-#ifdef USE_ARM_NEON
-    dnn->subfunc = sub1_neon;
-#else
-    dnn->subfunc = sub1;
-#endif
-#endif
+    dnn->subfunc = calc_dnn_neon;
+    break;
+  case USE_SIMD_NEONV2:
+    dnn->subfunc = calc_dnn_neonv2;
     break;
   default:
     dnn->subfunc = sub1;
@@ -703,10 +773,21 @@ boolean dnn_setup(DNNData *dnn, int veclen, int contextlen, int inputnodes, int
 
 void dnn_calc_outprob(HMMWork *wrk)
 {
-  int hidx, i, n;
-  float *src, *dst;
-  DNNLayer *h;
+  float *src;
   DNNData *dnn = wrk->OP_dnn;
+#ifndef _OPENMP
+  int n = 0;
+  int hidx, i;
+  float *dst;
+  DNNLayer *h;
+#endif
+
+#ifdef __NVCC__
+  if (dnn->use_cuda) {
+    cuda_calc_outprob(wrk);
+    return;
+  }
+#endif
 
   /* frame = wrk->OP_time */
   /* param = wrk->OP_param */
@@ -714,13 +795,47 @@ void dnn_calc_outprob(HMMWork *wrk)
   /* store state outprob to wrk->last_cache[]  */
 
   /* feed forward through hidden layers by standard logistic function */
-  n = 0;
+
 #ifdef SIMD_ENABLED
   memcpy(dnn->invec, &(wrk->OP_param->parvec[wrk->OP_time][0]), sizeof(float) * dnn->inputnodenum);
   src = dnn->invec;
 #else
   src = &(wrk->OP_param->parvec[wrk->OP_time][0]);
 #endif	/* SIMD_ENABLED */
+
+#ifdef _OPENMP
+#pragma omp parallel num_threads(dnn->num_threads)
+{
+  int n = 0;
+  int hidx, i;
+  float *lsrc, *dst;
+  DNNLayer *h;
+  int id = omp_get_thread_num();
+  int j;
+
+  dst = dnn->work[n];
+  lsrc = src;
+  for (hidx = 0; hidx < dnn->hnum; hidx++) {
+    h = &(dnn->h[hidx]);
+    (*dnn->subfunc)(dst + h->begin[id] , lsrc, h->w + h->begin[id] * h->in, h->b + h->begin[id], h->end[id] - h->begin[id], h->in, dnn->accum + id * 8);
+    for (j = h->begin[id] ; j < h->end[id]; j++) {
+      if (dst[j] <= -8.0f)
+	dst[j] = LOGISTIC_MIN;
+      else if (dst[j] >=  8.0f)
+	dst[j] = LOGISTIC_MAX;
+      else
+	dst[j] = logistic_table[(int)((dst[j] + 8.0f) * LOGISTIC_TABLE_FACTOR + 0.5)];
+    }
+#pragma omp barrier
+    lsrc = dst;
+    dst = dnn->work[++n];
+  }
+  /* compute output layer */
+  (*dnn->subfunc)(wrk->last_cache + dnn->o.begin[id] , lsrc, dnn->o.w + dnn->o.begin[id] * dnn->o.in, dnn->o.b + dnn->o.begin[id], dnn->o.end[id] - dnn->o.begin[id], dnn->o.in, dnn->accum + id * 8);
+}
+
+#else /* ~_OPENMP */
+
   dst = dnn->work[n];
   for (hidx = 0; hidx < dnn->hnum; hidx++) {
     h = &(dnn->h[hidx]);
@@ -729,16 +844,28 @@ void dnn_calc_outprob(HMMWork *wrk)
       dst[i] = logistic_func(dst[i]);
     }
     src = dst;
-    //if (++n > 1) n = 0;
     dst = dnn->work[++n];
   }
-  /* output layer */
+  /* compute output layer */
   (*dnn->subfunc)(wrk->last_cache, src, dnn->o.w, dnn->o.b, dnn->o.out, dnn->o.in, dnn->accum);
+#endif /* _OPENMP */
+
 
   /* do softmax */
   /* INV_LOG_TEN * (x - addlogarray(x)) - log10(state_prior)) */
-  float logprob = addlog_array(wrk->last_cache, wrk->statenum);
+#ifdef NO_SUM_COMPUTATION
+  /* not compute sum */
   for (i = 0; i < wrk->statenum; i++) {
-    wrk->last_cache[i] = INV_LOG_TEN * (wrk->last_cache[i] - logprob) - dnn->state_prior[i];
+    wrk->last_cache[i] = INV_LOG_TEN * wrk->last_cache[i] - dnn->state_prior[i];
   }
+#else
+  /* compute sum */
+  {
+    int i;
+    float logprob = addlog_array(wrk->last_cache, wrk->statenum);
+    for (i = 0; i < wrk->statenum; i++) {
+      wrk->last_cache[i] = INV_LOG_TEN * (wrk->last_cache[i] - logprob) - dnn->state_prior[i];
+    }
+  }
+#endif /* NO_SUM_COMPUTATION */
 }
