@@ -2,11 +2,11 @@
  * @file   wav2mfcc-pipe.c
  * 
  * <JA>
- * @brief  ȷ MFCC ħ̤Ѵ (ե졼ñ)
+ * @brief  音声波形から MFCC 特徴量へ変換する (フレーム単位)
  *
- * Ǥ wav2mfcc.c δؿե졼Ʊ˽뤿Ѵ
- * ؿǼƤޤǧϤʿԤƹԤ硤
- * ؿѤޤ
+ * ここでは wav2mfcc.c の関数をフレーム同期に処理するために変換した
+ * 関数が納められています．認識処理を音声入力と平行して行う場合，こちらの
+ * 関数が用いられます．
  * </JA>
  * 
  * <EN>
@@ -278,6 +278,7 @@ CMN_realtime_new(Value *para, float weight, boolean map)
   c->loaded_from_file = FALSE;
 
   c->do_map = map;
+  c->static_cvn_only = FALSE;
 
   if (c->var) {
     for(i = 0; i < c->veclen; i++) c->all.mfcc_var[i] = 0.0;
