@@ -6,13 +6,13 @@
  * </EN>
  * 
  * <JA>
- * @brief  ħϥץ饰ΤҤʷ
+ * @brief  特徴量入力プラグインのひな形
  * </JA>
  * 
  * @author Akinobu Lee
  * @date   Mon Aug 11 17:05:17 2008
  * 
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
  * 
  */
 
@@ -63,11 +63,11 @@
  * This function is OPTIONAL.
  * </EN>
  * <JA>
- * @brief  ɤ߹߻νǤա
+ * @brief  読み込み時の初期化（任意）
  *
- * ưJulius Υץ饰ɤ߹ݤ˺ǽ˸ƤФ롥
- * -1 ֤ȡΥץ饰Τɤ߹ޤʤʤ롥
- * ¹ԲǽΥå˻Ȥ롥
+ * 起動時，Julius がこのプラグインを読み込む際に最初に呼ばれる．
+ * -1 を返すと，このプラグイン全体が読み込まれなくなる．
+ * 実行可能性のチェックに使える．
  *
  * </JA>
  * 
@@ -101,19 +101,19 @@ initialize()
  * 
  * </EN>
  * <JA>
- * @brief  ץ饰ɬܡ
+ * @brief  プラグイン情報取得（必須）
  *
- * Υץ饰˴ؤ֤Ϳ줿 opcode ˤäư롥
- *  - 0 ξ硤Υץ饰ե̾ΤͿ줿Хåե˳Ǽ
+ * このプラグインに関する情報を返す．与えられた opcode によって動作する．
+ *  - 0 の場合，このプラグインファイルの名称を与えられたバッファに格納する
  *
- * δؿϡJulius Υץ饰ɤ߹ľ˸ƤФ롥
+ * この関数は，Julius がこのプラグインを読み込んだ直後に呼ばれる．
  * 
- * @param opcode [in] ׵ư ( 0 Τ߼)
- * @param buf [out] ͤǼХåե
- * @param buflen [in] buf κĹ
+ * @param opcode [in] 要求動作コード (現在 0 のみ実装)
+ * @param buf [out] 値を格納するバッファ
+ * @param buflen [in] buf の最大長
  * 
- * @return 顼 -1,  0 ֤顼Ȥ -1 ֤硤
- * Υץ饰Τɤ߹ޤʤ
+ * @return エラー時 -1, 成功時 0 を返す．エラーとして -1 を返した場合，
+ * このプラグイン全体は読み込まれない．
  * </JA>
  * 
  */
@@ -148,17 +148,17 @@ get_plugin_info(int opcode, char *buf, int buflen)
  * @param buflen [in] maximum length of buf
  * </EN>
  * <JA>
- * @brief  ѤΥץʸ֤ɬܡ
+ * @brief  入力選択用のオプション文字列を返す（必須）
  *
- * Υץ饰ϤȤ򤹤ݤˡ"-input" ץǻꤹ
- * ٤ʸǼ֤֤ʸϡƥˤǤˤΤ䡤
- * ¾Υץ饰󤬻ѤƤΤƱǤʤȡ
- * ʤ⤷Ʊä祷ƥ¦ͥ褵
+ * このプラグインを入力として選択する際に，"-input" オプションで指定す
+ * べき文字列を格納して返す．返す文字は，システムにすでにあるものや，
+ * 他のプラグインが使用しているものと同じでないこと．
+ * （もし同じだった場合システム側が優先される）
  *
- * δؿϡưΥץϻ˲٤ƤФ롥
+ * この関数は，起動時のオプション解析時に何度か呼ばれる．
  *
- * @param buf [out] ͤǼ֤Хåե
- * @param buflen [in] buf κĹ
+ * @param buf [out] 値を格納して返すバッファ
+ * @param buflen [in] buf の最大長
  * </JA>
  * 
  */
@@ -184,29 +184,34 @@ fvin_get_optname(char *buf, int buflen)
  * checking the input parameter type against acousitc model, and
  * you can disable the checking by returning "0xffff" to this opcode.
  * 
+ * When opcode = 3, should return 0 if the input vector is feature
+ * vector, and 1 if the input is outprob vector.
+ * 
  * @param opcode [in] requested operation code
  * 
  * @return values required for the opcode as described.
  * </EN>
  * 
  * <JA>
- * @brief  ħ̤Υѥ᡼֤ɬܡ
+ * @brief  特徴量のパラメータを返す（必須）
  *
- * ϥץ饰JuliusϤħ̤˴ؤѥ᡼֤
- * Ϳ줿ʲ opcode Ȥˡ֤ͤ
+ * この入力プラグインがJuliusに渡す特徴量に関するパラメータを返す．
+ * 与えられた以下の opcode ごとに，値を返す．
  *
- * opcode = 0: ٥ȥμ
- * opcode = 1: ե졼ढλñ̡ߥá
- * opcode = 2: ѥ᡼η
+ * opcode = 0: ベクトルの次元数
+ * opcode = 1: １フレームあたりの時間幅（単位：ミリ秒）
+ * opcode = 2: パラメータの型
  *
- * opcode = 2 Υѥ᡼ηϡǥħ̤Ȥη
- * å˻Ȥ롥ͤϡHTK ħ̥եΥإå
- * 󥳡ɤ줿֤ͤåԤʤϡ
- * 0xffff ֤ȡ
+ * opcode = 2 のパラメータの型は，音響モデルの特徴量との型整合性
+ * チェックに使われる．値は，HTK の特徴量ファイルのヘッダ形式で
+ * エンコードされた値を返す．型チェックを行わない場合は，
+ * 0xffff を返すこと．
  *
- * @param opcode [in] ׵ư ( 0 Τ߼)
+ * opcode =3 のとき特徴量ベクトル入力なら 0, 出力確率ベクトルなら1を返す．
+ *
+ * @param opcode [in] 要求動作コード (現在 0 のみ実装)
  * 
- * @return opcode Ȥ׵ᤵ줿֤ͤ
+ * @return opcode ごとに要求された値を返す．
  * </JA>
  */
 int
@@ -220,6 +225,8 @@ fvin_get_configuration(int opcode)
   case 2:/* return parameter type specification in HTK format */
     /* return 0xffff to disable checking */
     return(0xffff);
+  case 3:/* return 0 if feature vector input, 1 if outprob vector input */
+    return(0);
   }
 }
 
@@ -239,16 +246,16 @@ fvin_get_configuration(int opcode)
  * @return TRUE on success, FALSE on failure.
  * </EN>
  * <JA>
- * @brief  ǥХɬܡ
+ * @brief  デバイスを初期化する（必須）
  *
- * δؿϵư˰ƤФ롥Ǥϥեν
- * åȤѰդȤäϤΤνԤΤ˻Ȥ
+ * この関数は起動時に一回だけ呼ばれる．ここでは入力ファイルの準備や
+ * ソケットの用意といった，入力のための準備を行うのに使う．
  *
- * FALSE ֤硤Julius Ͻλ롥
+ * FALSE を返した場合，Julius は終了する．
  * 
- * JuliusLib: δؿ j_adin_init() ǸƤФ롥
+ * JuliusLib: この関数は j_adin_init() で呼ばれる．
  *
- * @return  TRUEԻ FALSE ֤
+ * @return 成功時 TRUE，失敗時 FALSE を返す．
  * </JA>
  */
 boolean
@@ -274,16 +281,16 @@ fvin_standby()
  * @return TRUE on success, FALSE on failure.
  * </EN>
  * <JA>
- * @brief  Ϥ򳫤ɬܡ
+ * @brief  入力を開く（必須）
  *
- * Ϥ򿷵˳եΥץ󡤥ͥåȥ饤Ȥ
- * ³ʤɤϤǹԤ
+ * 入力を新規に開く．ファイルのオープン，ネットワーククライアントからの
+ * 接続などはここで行う．
  *
- * FALSE ֤ȤJulius ǧ롼פȴ롥
+ * FALSE を返したとき，Julius は認識ループを抜ける．
  * 
- * JuliusLib: δؿ j_open_stream() ǸƤФ롥
+ * JuliusLib: この関数は j_open_stream() 内で呼ばれる．
  * 
- * @return  TRUEԻ FALSE ֤
+ * @return 成功時 TRUE，失敗時 FALSE を返す．
  * </JA>
  */
 boolean
@@ -317,30 +324,30 @@ fvin_open()
  * request segmentation to Julius, or ADIN_ERROR on error.
  * </EN>
  * <JA>
- * @brief Ϥ٥ȥɤ߹ɬܡ
+ * @brief 入力からベクトルを読み込む（必須）
  *
- * δؿϤ٥ȥ򣱤Ĥɤ߹ࡥδؿ
- * ե졼ऴȤ˸ƤФ졤ɤ߹ޤ줿٥ȥϤΤȤǧ졤
- * ޤΥե졼ΥǡɤिˤδؿƤФ롥
+ * この関数は入力からベクトルを１つだけ読み込む．この関数は
+ * フレームごとに呼ばれ，読み込まれたベクトルはこのあとすぐに認識処理され，
+ * また次のフレームのデータを読むためにこの関数が呼ばれる．
  *
- * ϤüޤãȤADIN_EOF ֤ΤȤJulius ϸ
- * ǧλϤĤ롥
+ * 入力が終端まで達したとき，ADIN_EOF を返す．このとき，Julius は現在
+ * の認識処理を終了させ，入力を閉じる．
  *
- * ADIN_ERROR Ϥδؿǿʥ顼֤줬֤
- * 줿硤Julius Ϥξǰ۾ｪλ롥
+ * ADIN_ERROR はこの関数内で深刻なエラーが生じた場合に返す．これが返さ
+ * れた場合，Julius はその場で異常終了する．
  *
- * ADIN_SEGMENT ֤ȤǡJulius ˸ߤǧ򸽻Ƕڤ뤳
- * ׵᤹뤳ȤǤ롥ߤǧϤλǤäڤ졤
- * ޤǤǧ̤ꡦϤ줿ȡǧϤޤꤳ
- * ؿƤФ롥ADIN_SEGMENT  ADIN_EOF ưƤ뤬
- * ADIN_EOF  adin_close(), adin_open() ƤϤλ
- * ΤФơADIN_SEGMENT ϤƤФϤ³Ԥ롥
+ * ADIN_SEGMENT を返すことで，Julius に現在の認識を現時点で区切ること
+ * を要求することができる．現在の認識処理はこの時点でいったん区切られ，
+ * そこまでの認識結果が確定・出力されたあと，次の認識処理が始まりこの
+ * 関数が呼ばれる．ADIN_SEGMENT は ADIN_EOF と動作が似ているが，
+ * ADIN_EOF が adin_close(), adin_open() を呼んで入力を終了させ
+ * るのに対して，ADIN_SEGMENT はこれらを呼ばずに入力を続行する．
  * 
- * @param vecbuf [out] 줿٥ȥǼХåե
- * @param veclen [in] ٥ȥĹ
+ * @param vecbuf [out] 得られたベクトルを格納するバッファ
+ * @param veclen [in] ベクトル長
  * 
- * @return  0 뤤 end of stream  ADIN_EOF, Julius ˶
- * ڤ׵ФȤˤ ADIN_SEGMENT, 顼ADIN_ERROR ֤
+ * @return 成功時 0 あるいは end of stream 時に ADIN_EOF, Julius に区
+ * 切り要求を出すときには ADIN_SEGMENT, エラー時はADIN_ERROR を返す．
  * </JA>
  */
 int
@@ -372,19 +379,19 @@ fvin_read(float *vecbuf, int veclen)
  * @return TRUE on success, FALSE on failure.
  * </EN>
  * <JA>
- * @brief  ϤĤɬܡ
+ * @brief  入力を閉じる（必須）
  *
- * ߤϤĤ롥δؿϡϤüEOFˤãȤʤ
- *  fvin_read()  ADIN_EOF ֤Ȥˤ˸ƤФ롥̾Ǥ
- * եĤ롤ͥåȥ³ǤʤɤνԤ
+ * 現在の入力を閉じる．この関数は，入力が終端（EOF）に達したとき（すな
+ * わち fvin_read() が ADIN_EOF を返したとき）に呼ばれる．通常，ここでは
+ * ファイルを閉じる，ネットワーク接続を切断するなどの処理を行う．
  *
- * ｪλȤTRUE֤ȤJulius  adin_open() ä
- * ¾Υȥ꡼򳫤Ȥ롥 FALSE ֤ȤϡJulius 
- * ǧ롼פȴ롥
+ * 正常終了としてTRUEを返したとき，Julius は adin_open() に戻って
+ * 他のストリームを開こうとする． FALSE を返したときは，Julius は
+ * 認識ループを抜ける．
  * 
- * JuliusLib: δؿ j_recognize_stream() κǸǸƤФ롥
+ * JuliusLib: この関数は j_recognize_stream() の最後で呼ばれる．
  * 
- * @return  TRUEԻ FALSE ֤
+ * @return 成功時 TRUE，失敗時 FALSE を返す．
  * </JA>
  */
 boolean
@@ -417,26 +424,26 @@ fvin_close()
  * @return TRUE on success, FALSE on failure.
  * </EN>
  * <JA>
- * @brief  ׵ѥեåǤա
+ * @brief  中断要求用フック（任意）
  *
- * δؿȡJulius ׵äݤˤδؿƤӽФ
- * ȤäơJulius ǡƳƱƱ뤳Ȥ
- * Ǥ롥㡧Ф׵Фʤɡ
+ * この関数を定義すると，Julius は中断要求を受け取った際にこの関数を呼び出す．
+ * これを使って，Julius の中断・再開と同期した入力同期処理を実装することが
+ * できる．（例：入力送信元に対して送信中断要求を出すなど）
  *
- * ׵ϡJulius ץꥱ䥯饤Ȥ
- * ǧǤ׵Ǥ롥ŪˤϡJulius ⥸塼⡼ɤư
- *  TERMINATE ޥɤ򥯥饤ȤäȤ䡤
- * JuliusLibȤ߹ץꥱ j_request_terminate() 
- * ƤȤȯ롥
+ * 中断要求は，Julius がアプリケーションやクライアントより受け取る
+ * 認識中断の要求である．具体的には，Julius がモジュールモードで動作して
+ * いる時に TERMINATE コマンドをクライアントから受け取ったときや，
+ * JuliusLibを組み込んだアプリケーションが j_request_terminate() を
+ * 呼んだときに発生する．
  *
- * ׵ȡJulius ϸߤǧǤ롥
- * ǧǤä硤Ϥ˴¨Ǥ롥
- * κƳϡRESUME ޥɤ j_request_resume() θƤӽФǹԤ롥
+ * 中断要求を受け取ると，Julius は現在の認識処理を中断する．
+ * 認識途中であった場合，その入力を破棄して即時中断する．
+ * 処理の再開は，RESUME コマンドか j_request_resume() の呼び出しで行われる．
  *
- * δؿ׵ Julius äǸƤФ롥
- * ºݤ˽ǤǸƤФΤǤϤʤȤդ줿
+ * この関数は中断要求を Julius が受け取った時点で呼ばれる．
+ * 実際に処理が中断した後で呼ばれるのではないことに注意されたい．
  * 
- * @return  TRUE, 顼 FALSE ֤
+ * @return 成功時 TRUE, エラー時 FALSE を返す．
  * </JA>
  * 
  */
@@ -469,30 +476,30 @@ fvin_terminate()
  * @return TRUE on success, FALSE on failure.
  * </EN>
  * <JA>
- * @brief  ׵ѥեåǤա
+ * @brief  停止要求用フック（任意）
  *
- * δؿȡJulius ׵äݤˤδؿƤӽФ
- * ȤäơJulius ǡƳƱƱ뤳Ȥ
- * Ǥ롥㡧Ф׵Фʤɡ
+ * この関数を定義すると，Julius は停止要求を受け取った際にこの関数を呼び出す．
+ * これを使って，Julius の中断・再開と同期した入力同期処理を実装することが
+ * できる．（例：入力送信元に対して送信中断要求を出すなど）
  *
- * ׵ϡJulius ץꥱ䥯饤Ȥ롤
- * ǧΰߤ׵Ǥ롥ŪˤϡJulius ⥸塼⡼ɤư
- *  PAUSE ޥɤ򥯥饤ȤäȤ䡤
- * JuliusLibȤ߹ץꥱ j_request_pause() 
- * ƤȤȯ롥
+ * 停止要求は，Julius がアプリケーションやクライアントより受け取る，
+ * 認識の一時停止の要求である．具体的には，Julius がモジュールモードで動作して
+ * いる時に PAUSE コマンドをクライアントから受け取ったときや，
+ * JuliusLibを組み込んだアプリケーションが j_request_pause() を
+ * 呼んだときに発生する．
  *
- * ׵ȡJulius ϸߤǧǤ롥
- * ǧǤä硤ǧޤԤäƤǤ롥
- * κƳϡRESUME ޥɤ j_request_resume() θƤӽФǹԤ롥
+ * 停止要求を受け取ると，Julius は現在の認識処理を中断する．
+ * 認識途中であった場合，その認識が終わるまで待ってから中断する．
+ * 処理の再開は，RESUME コマンドか j_request_resume() の呼び出しで行われる．
  * 
- * ׵ (fvin_terminate) Ȥΰ㤤ϡǧ׵Ȥư
- * ۤʤ롥׵Ǥ϶Ǥ뤬׵ǤϤǧޤ
- * ԤäƤߤ롥
+ * 中断要求 (fvin_terminate) との違いは，認識途中に要求を受けたときの動作が
+ * 異なる．中断要求では強制中断するが，停止要求ではその認識が終わるまで
+ * 待ってから停止する．
  *
- * δؿ׵ Julius äǸƤФ롥
- * ºݤ˽ߤǸƤФΤǤϤʤȤդ줿
+ * この関数は停止要求を Julius が受け取った時点で呼ばれる．
+ * 実際に処理が停止した後で呼ばれるのではないことに注意されたい．
  * 
- * @return  TRUE, 顼 FALSE ֤
+ * @return 成功時 TRUE, エラー時 FALSE を返す．
  * </JA>
  * 
  */
@@ -524,22 +531,22 @@ fvin_pause()
  * @return TRUE on success, FALSE on failure.
  * </EN>
  * <JA>
- * @brief  ǧƳ׵ѥեåǤա
+ * @brief  認識再開要求用フック（任意）
  *
- * δؿȡJulius ߾֤ǧƳ׵κݤ
- * δؿƤӽФ
+ * この関数を定義すると，Julius は停止状態からの認識再開要求の際に
+ * この関数を呼び出す．
  *
- * ǧƳ׵ϡJulius ⥸塼⡼ɤư RESUME ޥɤ
- * 饤ȤäȤ䡤JuliusLibȤ߹ץꥱ
- *  j_request_resume() ƤȤȯ롥κƳ׵᤬ȯ
- * ȡJulius ߤƤǧƳ롥
+ * 認識再開要求は，Julius がモジュールモードで動作して RESUME コマンドを
+ * クライアントから受け取ったときや，JuliusLibを組み込んだアプリケーション
+ * が j_request_resume() を呼んだときに発生する．この再開要求が発生
+ * すると，Julius は停止していた認識を再開する．
  *
- * աδؿϡºݤߤȤ˸ƤФΤǤϤʤJulius 
- * ׵äǡΤӤ˸ƤФ롥ʣƤФ뤳Ȥ䡤
- * ǤưǤˤˤΥޥɤäȤˤƤ
- * 뤳Ȥ뤳Ȥդ줿
+ * 注意：この関数は，実際に停止したときに呼ばれるのではなく，Julius が
+ * 要求を受け取った時点で，そのたびに呼ばれる．複数回呼ばれることや，
+ * すでに動作中である場合にさらにこのコマンドを受け取ったときにも呼ば
+ * れることがあることに注意されたい．
  * 
- * @return  TRUE, 顼 FALSE ֤
+ * @return 成功時 TRUE, エラー時 FALSE を返す．
  * </JA>
  * 
  */
@@ -559,9 +566,9 @@ fvin_resume()
  * @return pointer to the device name string
  * </EN>
  * <JA>
- * @brief  ϥե롦ǥХ֤̾ؿǤա
+ * @brief  入力ファイル・デバイス名を返す関数（任意）
  *
- * @return ϥե뤢뤤ϥǥХ̾ʸؤΥݥ
+ * @return 入力ファイルあるいはデバイス名の文字列へのポインタ
  * </JA>
  * 
  */
